# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in New Hampshire."""


BELKNAP = "001"
CARROLL = "003"
CHESHIRE = "005"
COOS = "007"
GRAFTON = "009"
HILLSBOROUGH = "011"
MERRIMACK = "013"
ROCKINGHAM = "015"
STRAFFORD = "017"
SULLIVAN = "019"
