# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Michigan."""


ADDISON_VILLAGE = "00380"
ADRIAN_CITY = "00440"
ADVANCE_CDP = "00480"
AHMEEK_VILLAGE = "00620"
AKRON_VILLAGE = "00700"
ALANSON_VILLAGE = "00860"
ALBA_CDP = "00900"
ALBION_CITY = "00980"
ALDEN_CDP = "01060"
ALGONAC_CITY = "01180"
ALLEGAN_CITY = "01260"
ALLEN_PARK_CITY = "01380"
ALLEN_VILLAGE = "01300"
ALLENDALE_CDP = "01340"
ALMA_CITY = "01540"
ALMONT_VILLAGE = "01660"
ALPENA_CITY = "01740"
ALPHA_VILLAGE = "01800"
AMASA_CDP = "01960"
ANN_ARBOR_CITY = "03000"
APPLEGATE_VILLAGE = "03200"
ARCADIA_CDP = "03300"
ARGENTINE_CDP = "03400"
ARMADA_VILLAGE = "03520"
ASHLEY_VILLAGE = "03740"
ATHENS_VILLAGE = "03880"
ATLANTA_CDP = "03920"
ATLANTIC_MINE_CDP = "03960"
ATTICA_CDP = "04020"
AU_GRES_CITY = "04120"
AU_SABLE_CDP = "04280"
AUBURN_HILLS_CITY = "04105"
AUBURN_CITY = "04080"
AUGUSTA_VILLAGE = "04160"
BAD_AXE_CITY = "04740"
BALDWIN_VILLAGE = "04940"
BANCROFT_VILLAGE = "05080"
BANGOR_CITY = "05140"
BARAGA_VILLAGE = "05320"
BARNES_LAKE_CDP = "05466"
BARODA_VILLAGE = "05500"
BARRYTON_VILLAGE = "05580"
BARTON_HILLS_VILLAGE = "05660"
BATH_CDP = "05880"
BATTLE_CREEK_CITY = "05920"
BAY_CITY_CITY = "06020"
BAY_PORT_CDP = "06120"
BAY_SHORE_CDP = "06180"
BAY_VIEW_CDP = "06260"
BEAL_CITY_CDP = "06360"
BEAR_LAKE_CDP = "06430"
BEAR_LAKE_VILLAGE = "06460"
BEAVERTON_CITY = "06660"
BEECHER_CDP = "06820"
BEECHWOOD_CDP = "06880"
BELDING_CITY = "06900"
BELLAIRE_VILLAGE = "06980"
BELLEVILLE_CITY = "07020"
BELLEVUE_VILLAGE = "07060"
BENDON_CDP = "07220"
BENTON_HARBOR_CITY = "07520"
BENTON_HEIGHTS_CDP = "07540"
BENZONIA_VILLAGE = "07580"
BERGLAND_CDP = "07620"
BERKLEY_CITY = "07660"
BERRIEN_SPRINGS_VILLAGE = "07860"
BESSEMER_CITY = "07960"
BEULAH_VILLAGE = "08100"
BEVERLY_HILLS_VILLAGE = "08160"
BIG_BAY_CDP = "08180"
BIG_RAPIDS_CITY = "08300"
BINGHAM_FARMS_VILLAGE = "08460"
BIRCH_RUN_VILLAGE = "08540"
BIRMINGHAM_CITY = "08640"
BLISSFIELD_VILLAGE = "09000"
BLOOMFIELD_HILLS_CITY = "09180"
BLOOMINGDALE_VILLAGE = "09220"
BOON_CDP = "09560"
BOYNE_CITY_CITY = "09820"
BOYNE_FALLS_VILLAGE = "09840"
BRECKENRIDGE_VILLAGE = "10160"
BREEDSVILLE_VILLAGE = "10180"
BRETHREN_CDP = "10300"
BRIDGEPORT_CDP = "10440"
BRIDGMAN_CITY = "10580"
BRIGHTON_CITY = "10620"
BRIMLEY_CDP = "10680"
BRITTON_VILLAGE = "10760"
BRONSON_CITY = "10860"
BROOKLYN_VILLAGE = "11000"
BROWN_CITY_CITY = "11180"
BROWNLEE_PARK_CDP = "11200"
BRUCE_CROSSING_CDP = "11320"
BRUTUS_CDP = "11380"
BUCHANAN_CITY = "11400"
BUCKLEY_VILLAGE = "11480"
BUENA_VISTA_CDP = "11555"
BURLINGTON_VILLAGE = "11800"
BURR_OAK_VILLAGE = "11920"
BURT_CDP = "12000"
BURTON_CITY = "12060"
BYRON_CENTER_CDP = "12280"
BYRON_VILLAGE = "12260"
CABERFAE_CDP = "12290"
CADILLAC_CITY = "12320"
CALEDONIA_VILLAGE = "12480"
CALUMET_VILLAGE = "12580"
CAMBRIA_CDP = "12680"
CAMDEN_VILLAGE = "12760"
CANADA_CREEK_RANCH_CDP = "12980"
CANADIAN_LAKES_CDP = "13010"
CANNONSBURG_CDP = "13100"
CAPAC_VILLAGE = "13140"
CARLETON_VILLAGE = "13220"
CARNEY_VILLAGE = "13400"
CARO_CITY = "13420"
CARP_LAKE_CDP = "13480"
CARSON_CITY_CITY = "13600"
CARSONVILLE_VILLAGE = "13620"
CASEVILLE_CITY = "13760"
CASNOVIA_VILLAGE = "13820"
CASPIAN_CITY = "13860"
CASS_CITY_VILLAGE = "13880"
CASSOPOLIS_VILLAGE = "13900"
CEDAR_CDP = "14020"
CEDAR_SPRINGS_CITY = "14200"
CEMENT_CITY_VILLAGE = "14260"
CENTER_LINE_CITY = "14320"
CENTRAL_LAKE_VILLAGE = "14400"
CENTREVILLE_VILLAGE = "14460"
CHARLEVOIX_CITY = "14780"
CHARLOTTE_CITY = "14820"
CHASSELL_CDP = "14900"
CHATHAM_VILLAGE = "14940"
CHEBOYGAN_CITY = "15000"
CHELSEA_CITY = "15020"
CHESANING_VILLAGE = "15140"
CHUMS_CORNER_CDP = "15715"
CLARE_CITY = "15920"
CLARKSVILLE_VILLAGE = "16140"
CLAWSON_CITY = "16160"
CLAYTON_VILLAGE = "16280"
CLIFFORD_VILLAGE = "16420"
CLIMAX_VILLAGE = "16440"
CLINTON_VILLAGE = "16480"
CLIO_CITY = "16620"
COLDWATER_CITY = "17020"
COLEMAN_CITY = "17100"
COLOMA_CITY = "17320"
COLON_VILLAGE = "17360"
COLUMBIAVILLE_VILLAGE = "17460"
COMSTOCK_NORTHWEST_CDP = "17690"
COMSTOCK_PARK_CDP = "17700"
CONCORD_VILLAGE = "17740"
CONSTANTINE_VILLAGE = "17840"
CONWAY_CDP = "17900"
COOPERSVILLE_CITY = "18020"
COPEMISH_VILLAGE = "18040"
COPPER_CITY_VILLAGE = "18080"
COPPER_HARBOR_CDP = "18100"
CORUNNA_CITY = "18300"
COVINGTON_CDP = "18580"
CROSS_VILLAGE_CDP = "18880"
CROSWELL_CITY = "18920"
CRYSTAL_CDP = "19060"
CRYSTAL_DOWNS_COUNTRY_CLUB_CDP = "19135"
CRYSTAL_FALLS_CITY = "19140"
CRYSTAL_MOUNTAIN_CDP = "19195"
CUSTER_VILLAGE = "19420"
CUTLERVILLE_CDP = "19500"
DAGGETT_VILLAGE = "19560"
DANSVILLE_VILLAGE = "19780"
DAVISON_CITY = "19880"
DE_TOUR_VILLAGE_VILLAGE = "21780"
DEWITT_CITY = "22120"
DEARBORN_HEIGHTS_CITY = "21020"
DEARBORN_CITY = "21000"
DECATUR_VILLAGE = "21040"
DECKERVILLE_VILLAGE = "21100"
DEERFIELD_VILLAGE = "21180"
DELTON_CDP = "21560"
DETROIT_BEACH_CDP = "22040"
DETROIT_CITY = "22000"
DEXTER_CITY = "22160"
DIMONDALE_VILLAGE = "22380"
DODGEVILLE_CDP = "22500"
DOLLAR_BAY_CDP = "22520"
DORR_CDP = "22660"
DOUGLAS_CITY = "22740"
DOWAGIAC_CITY = "22880"
DOWLING_CDP = "22900"
DRYDEN_VILLAGE = "23140"
DUNDEE_VILLAGE = "23380"
DURAND_CITY = "23500"
EAGLE_HARBOR_CDP = "23600"
EAGLE_RIVER_CDP = "23740"
EAGLE_VILLAGE = "23560"
EAST_GRAND_RAPIDS_CITY = "23980"
EAST_JORDAN_CITY = "24020"
EAST_LANSING_CITY = "24120"
EAST_TAWAS_CITY = "24420"
EASTLAKE_VILLAGE = "24060"
EASTPOINTE_CITY = "24290"
EASTPORT_CDP = "24300"
EASTWOOD_CDP = "24500"
EATON_RAPIDS_CITY = "24540"
EAU_CLAIRE_VILLAGE = "24580"
ECORSE_CITY = "24740"
EDGEMONT_PARK_CDP = "24880"
EDMORE_VILLAGE = "25000"
EDWARDSBURG_VILLAGE = "25040"
ELBERTA_VILLAGE = "25180"
ELK_RAPIDS_VILLAGE = "25320"
ELKTON_VILLAGE = "25360"
ELLSWORTH_VILLAGE = "25420"
ELM_HALL_CDP = "25580"
ELSIE_VILLAGE = "25780"
EMMETT_VILLAGE = "25940"
EMPIRE_VILLAGE = "25980"
ESCANABA_CITY = "26360"
ESSEXVILLE_CITY = "26420"
ESTRAL_BEACH_VILLAGE = "26460"
EUREKA_CDP = "26500"
EVART_CITY = "26640"
EWEN_CDP = "26820"
FAIR_PLAIN_CDP = "27160"
FAIRGROVE_VILLAGE = "27080"
FALMOUTH_CDP = "27320"
FARMINGTON_HILLS_CITY = "27440"
FARMINGTON_CITY = "27380"
FARWELL_VILLAGE = "27500"
FENNVILLE_CITY = "27740"
FENTON_CITY = "27760"
FERNDALE_CITY = "27880"
FERRYSBURG_CITY = "27960"
FIFE_LAKE_VILLAGE = "28000"
FILER_CITY_CDP = "28060"
FLAT_ROCK_CITY = "28360"
FLINT_CITY = "29000"
FLUSHING_CITY = "29200"
FOREST_HILLS_CDP = "29580"
FORESTVILLE_VILLAGE = "29660"
FOSTORIA_CDP = "29920"
FOUNTAIN_VILLAGE = "29940"
FOWLER_VILLAGE = "30040"
FOWLERVILLE_VILLAGE = "30060"
FRANKENMUTH_CITY = "30200"
FRANKFORT_CITY = "30260"
FRANKLIN_VILLAGE = "30340"
FRASER_CITY = "30420"
FREE_SOIL_VILLAGE = "30600"
FREELAND_CDP = "30540"
FREEPORT_VILLAGE = "30580"
FREMONT_CITY = "30700"
FRUITPORT_VILLAGE = "31000"
FULTON_CDP = "31120"
GAASTRA_CITY = "31160"
GAGETOWN_VILLAGE = "31180"
GAINES_VILLAGE = "31200"
GALESBURG_CITY = "31260"
GALIEN_VILLAGE = "31300"
GARDEN_CITY_CITY = "31420"
GARDEN_VILLAGE = "31380"
GAYLORD_CITY = "31720"
GIBRALTAR_CITY = "32020"
GLADSTONE_CITY = "32300"
GLADWIN_CITY = "32320"
GLEN_ARBOR_CDP = "32360"
GOBLES_CITY = "32640"
GOODRICH_VILLAGE = "32980"
GRAND_BEACH_VILLAGE = "33260"
GRAND_BLANC_CITY = "33280"
GRAND_HAVEN_CITY = "33340"
GRAND_LEDGE_CITY = "33420"
GRAND_MARAIS_CDP = "33440"
GRAND_RAPIDS_CITY = "34000"
GRANDVILLE_CITY = "34160"
GRANT_CITY = "34360"
GRASS_LAKE_VILLAGE = "34480"
GRAWN_CDP = "34620"
GRAYLING_CITY = "34640"
GREENLAND_CDP = "34980"
GREENVILLE_CITY = "35100"
GREILICKVILLE_CDP = "35300"
GROSSE_POINTE_FARMS_CITY = "35520"
GROSSE_POINTE_PARK_CITY = "35540"
GROSSE_POINTE_WOODS_CITY = "35580"
GROSSE_POINTE_CITY = "35480"
GWINN_CDP = "35760"
HAMTRAMCK_CITY = "36280"
HANCOCK_CITY = "36300"
HANOVER_VILLAGE = "36380"
HARBOR_BEACH_CITY = "36460"
HARBOR_SPRINGS_CITY = "36560"
HARDWOOD_ACRES_CDP = "36585"
HARING_CDP = "36590"
HARPER_WOODS_CITY = "36700"
HARRIETTA_VILLAGE = "36720"
HARRISON_CITY = "36800"
HARRISVILLE_CITY = "36860"
HART_CITY = "36920"
HARTFORD_CITY = "36960"
HARTLAND_CDP = "37020"
HARVEY_CDP = "37080"
HASLETT_CDP = "37100"
HASTINGS_CITY = "37120"
HAZEL_PARK_CITY = "37420"
HEMLOCK_CDP = "37600"
HENDERSON_CDP = "37620"
HERMANSVILLE_CDP = "37760"
HERSEY_VILLAGE = "37820"
HESPERIA_VILLAGE = "37860"
HICKORY_CORNERS_CDP = "37960"
HIGHLAND_PARK_CITY = "38180"
HILLMAN_VILLAGE = "38380"
HILLSDALE_CITY = "38460"
HOLLAND_CITY = "38640"
HOLLY_VILLAGE = "38700"
HOLT_CDP = "38780"
HOMER_VILLAGE = "38920"
HONOR_VILLAGE = "39080"
HOPKINS_VILLAGE = "39180"
HORTON_BAY_CDP = "39340"
HOUGHTON_LAKE_CDP = "39400"
HOUGHTON_CITY = "39360"
HOWARD_CITY_VILLAGE = "39500"
HOWELL_CITY = "39540"
HUBBARD_LAKE_CDP = "39634"
HUBBARDSTON_VILLAGE = "39660"
HUBBELL_CDP = "39680"
HUDSON_CITY = "39720"
HUDSONVILLE_CITY = "39800"
HUNTINGTON_WOODS_CITY = "40000"
HURONTOWN_CDP = "40160"
IDA_CDP = "40240"
IMLAY_CITY_CITY = "40320"
INDIAN_RIVER_CDP = "40480"
INKSTER_CITY = "40680"
INTERLOCHEN_CDP = "40800"
IONIA_CITY = "40860"
IRON_MOUNTAIN_CITY = "40960"
IRON_RIVER_CITY = "40980"
IRONTON_CDP = "41040"
IRONWOOD_CITY = "41060"
ISHPEMING_CITY = "41220"
ITHACA_CITY = "41340"
JACKSON_CITY = "41420"
JASPER_CDP = "41540"
JENISON_CDP = "41680"
JENNINGS_CDP = "41720"
JONESVILLE_CITY = "41920"
K_I_SAWYER_CDP = "43558"
KALAMAZOO_CITY = "42160"
KALEVA_VILLAGE = "42240"
KALKASKA_VILLAGE = "42260"
KEEGO_HARBOR_CITY = "42460"
KENT_CITY_VILLAGE = "42780"
KENTWOOD_CITY = "42820"
KINCHELOE_CDP = "43180"
KINDE_VILLAGE = "43220"
KINGSFORD_CITY = "43300"
KINGSLEY_VILLAGE = "43340"
KINGSTON_VILLAGE = "43380"
LANSE_VILLAGE = "45540"
LAINGSBURG_CITY = "44200"
LAKE_ANGELUS_CITY = "44440"
LAKE_ANN_VILLAGE = "44460"
LAKE_CITY_CITY = "44480"
LAKE_FENTON_CDP = "44520"
LAKE_GOGEBIC_CDP = "44620"
LAKE_ISABELLA_VILLAGE = "44715"
LAKE_LEANN_CDP = "44752"
LAKE_LEELANAU_CDP = "44760"
LAKE_LINDEN_VILLAGE = "44780"
LAKE_MICHIGAN_BEACH_CDP = "44820"
LAKE_ODESSA_VILLAGE = "44880"
LAKE_ORION_VILLAGE = "44940"
LAKE_VICTORIA_CDP = "45190"
LAKEPORT_CDP = "45000"
LAKES_OF_THE_NORTH_CDP = "45144"
LAKEVIEW_VILLAGE = "45240"
LAKEWOOD_CLUB_VILLAGE = "45340"
LAMBERTVILLE_CDP = "45420"
LAMONT_CDP = "45440"
LANSING_CITY = "46000"
LAPEER_CITY = "46040"
LATHRUP_VILLAGE_CITY = "46320"
LAURIUM_VILLAGE = "46360"
LAWRENCE_VILLAGE = "46440"
LAWTON_VILLAGE = "46500"
LE_ROY_VILLAGE = "47100"
LELAND_CDP = "46800"
LENNON_VILLAGE = "46880"
LEONARD_VILLAGE = "46940"
LESLIE_CITY = "47180"
LEVEL_PARK_OAK_PARK_CDP = "47230"
LEVERING_CDP = "47240"
LEWISTON_CDP = "47260"
LEXINGTON_VILLAGE = "47280"
LINCOLN_PARK_CITY = "47800"
LINCOLN_VILLAGE = "47560"
LINDEN_CITY = "47820"
LITCHFIELD_CITY = "47980"
LIVONIA_CITY = "49000"
LOOMIS_CDP = "49400"
LOST_LAKE_WOODS_CDP = "49450"
LOWELL_CITY = "49540"
LUDINGTON_CITY = "49640"
LUNA_PIER_CITY = "49700"
LUPTON_CDP = "49720"
LUTHER_VILLAGE = "49740"
LYONS_VILLAGE = "49900"
MACKINAC_ISLAND_CITY = "50280"
MACKINAW_CITY_VILLAGE = "50320"
MADISON_HEIGHTS_CITY = "50560"
MANCELONA_VILLAGE = "50620"
MANCHESTER_VILLAGE = "50660"
MANISTEE_LAKE_CDP = "50755"
MANISTEE_CITY = "50720"
MANISTIQUE_CITY = "50760"
MANITOU_BEACH_DEVILS_LAKE_CDP = "50830"
MANTON_CITY = "50880"
MAPLE_CITY_CDP = "50920"
MAPLE_GROVE_CDP = "50970"
MAPLE_RAPIDS_VILLAGE = "51200"
MARCELLUS_VILLAGE = "51460"
MARENISCO_CDP = "51540"
MARINE_CITY_CITY = "51600"
MARION_VILLAGE = "51660"
MARLETTE_CITY = "51820"
MARQUETTE_CITY = "51900"
MARSHALL_CITY = "51940"
MARTIN_VILLAGE = "51980"
MARYSVILLE_CITY = "52080"
MASON_CITY = "52180"
MASS_CITY_CDP = "52280"
MATTAWAN_VILLAGE = "52380"
MAYBEE_VILLAGE = "52440"
MAYVILLE_VILLAGE = "52540"
MCBAIN_CITY = "49980"
MCBRIDE_VILLAGE = "50000"
MEARS_CDP = "52720"
MECOSTA_VILLAGE = "52760"
MELVIN_VILLAGE = "52920"
MELVINDALE_CITY = "52940"
MEMPHIS_CITY = "52960"
MENDON_VILLAGE = "52980"
MENOMINEE_CITY = "53020"
MERRILL_VILLAGE = "53180"
MESICK_VILLAGE = "53320"
METAMORA_VILLAGE = "53340"
MICHIANA_VILLAGE = "53500"
MICHIGAMME_CDP = "53520"
MICHIGAN_CENTER_CDP = "53580"
MIDDLETOWN_CDP = "53730"
MIDDLEVILLE_VILLAGE = "53760"
MIDLAND_CITY = "53780"
MILAN_CITY = "53920"
MILFORD_VILLAGE = "53960"
MILLBURG_CDP = "54025"
MILLERS_LAKE_CDP = "54132"
MILLERSBURG_VILLAGE = "54120"
MILLINGTON_VILLAGE = "54220"
MINDEN_CITY_VILLAGE = "54560"
MIO_CDP = "54660"
MOHAWK_CDP = "54820"
MONROE_CITY = "55020"
MONTAGUE_CITY = "55100"
MONTGOMERY_VILLAGE = "55220"
MONTROSE_CITY = "55280"
MORENCI_CITY = "55500"
MORLEY_VILLAGE = "55540"
MORRICE_VILLAGE = "55560"
MOUNT_CLEMENS_CITY = "55820"
MOUNT_MORRIS_CITY = "55960"
MOUNT_PLEASANT_CITY = "56020"
MUIR_VILLAGE = "56080"
MULLIKEN_VILLAGE = "56140"
MUNISING_CITY = "56200"
MUSKEGON_HEIGHTS_CITY = "56360"
MUSKEGON_CITY = "56320"
NAPOLEON_CDP = "56620"
NASHVILLE_VILLAGE = "56680"
NAUBINWAY_CDP = "56760"
NEGAUNEE_CITY = "56860"
NESSEN_CITY_CDP = "56960"
NEW_BALTIMORE_CITY = "57100"
NEW_BUFFALO_CITY = "57220"
NEW_ERA_VILLAGE = "57280"
NEW_HAVEN_VILLAGE = "57380"
NEW_LOTHROP_VILLAGE = "57520"
NEW_TROY_CDP = "57660"
NEWAYGO_CITY = "57080"
NEWBERRY_VILLAGE = "57140"
NILES_CITY = "57760"
NORTH_ADAMS_VILLAGE = "57920"
NORTH_BRANCH_VILLAGE = "58080"
NORTH_MUSKEGON_CITY = "58640"
NORTHPORT_VILLAGE = "58740"
NORTHVIEW_CDP = "58945"
NORTHVILLE_CITY = "58980"
NORTON_SHORES_CITY = "59140"
NORWAY_CITY = "59220"
NORWOOD_CDP = "59320"
NOVI_CITY = "59440"
NUNICA_CDP = "59520"
OAK_HILL_CDP = "59740"
OAK_PARK_CITY = "59920"
OAKLEY_VILLAGE = "59860"
ODEN_CDP = "60180"
OKEMOS_CDP = "60340"
OLIVET_CITY = "60580"
OMENA_CDP = "60640"
OMER_CITY = "60660"
ONAWAY_CITY = "60680"
ONEKAMA_VILLAGE = "60740"
ONSTED_VILLAGE = "60840"
ONTONAGON_VILLAGE = "60860"
ORCHARD_LAKE_VILLAGE_CITY = "61020"
ORTONVILLE_VILLAGE = "61220"
OSCODA_CDP = "61320"
OSSINEKE_CDP = "61500"
OTISVILLE_VILLAGE = "61600"
OTSEGO_CITY = "61620"
OTTER_LAKE_VILLAGE = "61760"
OVID_CITY = "61860"
OWENDALE_VILLAGE = "61920"
OWOSSO_CITY = "61940"
OXFORD_VILLAGE = "62020"
PAINESDALE_CDP = "62120"
PALMER_CDP = "62180"
PALO_CDP = "62260"
PARCHMENT_CITY = "62340"
PARIS_CDP = "62400"
PARKDALE_CDP = "62500"
PARMA_VILLAGE = "62740"
PAW_PAW_LAKE_CDP = "63020"
PAW_PAW_VILLAGE = "62980"
PEARL_BEACH_CDP = "63200"
PECK_VILLAGE = "63260"
PELKIE_CDP = "63280"
PELLSTON_VILLAGE = "63300"
PENTWATER_VILLAGE = "63540"
PERRINTON_VILLAGE = "63660"
PERRY_CITY = "63700"
PETERSBURG_CITY = "63800"
PETOSKEY_CITY = "63820"
PEWAMO_VILLAGE = "63900"
PIERSON_VILLAGE = "64020"
PIGEON_VILLAGE = "64060"
PILGRIM_CDP = "64100"
PINCKNEY_VILLAGE = "64140"
PINCONNING_CITY = "64160"
PITTSFORD_CDP = "64600"
PLAINWELL_CITY = "64740"
PLEASANT_RIDGE_CITY = "64900"
PLYMOUTH_CITY = "65060"
PONSHEWAING_CDP = "65420"
PONTIAC_CITY = "65440"
PORT_AUSTIN_VILLAGE = "65680"
PORT_HOPE_VILLAGE = "65800"
PORT_HURON_CITY = "65820"
PORT_SANILAC_VILLAGE = "65900"
PORTAGE_CITY = "65560"
PORTLAND_CITY = "65860"
POSEN_VILLAGE = "66000"
POTTERVILLE_CITY = "66100"
POWERS_VILLAGE = "66140"
PRESCOTT_VILLAGE = "66300"
PRESQUE_ISLE_HARBOR_CDP = "66343"
PRUDENVILLE_CDP = "66400"
QUINCY_VILLAGE = "66640"
QUINNESEC_CDP = "66720"
RAMSAY_CDP = "66980"
RAPID_CITY_CDP = "67140"
RAPID_RIVER_CDP = "67160"
RAVENNA_VILLAGE = "67280"
READING_CITY = "67500"
REED_CITY_CITY = "67820"
REESE_VILLAGE = "67900"
REPUBLIC_CDP = "67980"
RICHLAND_VILLAGE = "68240"
RICHMOND_CITY = "68380"
RIVER_ROUGE_CITY = "68760"
RIVERDALE_CDP = "68720"
RIVERVIEW_CITY = "68880"
ROBIN_GLEN_INDIANTOWN_CDP = "68990"
ROCHESTER_HILLS_CITY = "69035"
ROCHESTER_CITY = "69020"
ROCK_CDP = "69060"
ROCKFORD_CITY = "69080"
ROCKLAND_CDP = "69120"
ROCKWOOD_CITY = "69180"
ROGERS_CITY_CITY = "69260"
ROMEO_VILLAGE = "69400"
ROMULUS_CITY = "69420"
ROOSEVELT_PARK_CITY = "69520"
ROSCOMMON_VILLAGE = "69540"
ROSE_CITY_CITY = "69680"
ROSEBUSH_VILLAGE = "69640"
ROSEVILLE_CITY = "69800"
ROTHBURY_VILLAGE = "69880"
ROYAL_OAK_CITY = "70040"
RUBY_CDP = "70160"
SAGINAW_CITY = "70520"
SALINE_CITY = "71140"
SAND_LAKE_CDP = "71340"
SAND_LAKE_VILLAGE = "71360"
SANDUSKY_CITY = "71540"
SANFORD_VILLAGE = "71560"
SARANAC_VILLAGE = "71660"
SAUGATUCK_CITY = "71700"
SAULT_STE_MARIE_CITY = "71740"
SCHOOLCRAFT_VILLAGE = "71860"
SCOTTS_CDP = "72060"
SCOTTVILLE_CITY = "72080"
SEBEWAING_VILLAGE = "72180"
SHAFTSBURG_CDP = "72700"
SHELBY_VILLAGE = "72840"
SHEPHERD_VILLAGE = "72960"
SHERIDAN_VILLAGE = "73100"
SHERWOOD_VILLAGE = "73420"
SHIELDS_CDP = "73560"
SHOREHAM_VILLAGE = "73660"
SHOREWOOD_TOWER_HILLS_HARBERT_CDP = "73730"
SKANEE_CDP = "74120"
SKIDWAY_LAKE_CDP = "74200"
SNOVER_CDP = "74380"
SOUTH_BOARDMAN_CDP = "74740"
SOUTH_GULL_LAKE_CDP = "74975"
SOUTH_HAVEN_CITY = "74980"
SOUTH_LYON_CITY = "75100"
SOUTH_MONROE_CDP = "75140"
SOUTH_RANGE_VILLAGE = "75220"
SOUTH_ROCKWOOD_VILLAGE = "75280"
SOUTHFIELD_CITY = "74900"
SOUTHGATE_CITY = "74960"
SPARTA_VILLAGE = "75420"
SPRING_ARBOR_CDP = "75620"
SPRING_LAKE_VILLAGE = "75820"
SPRINGFIELD_CITY = "75700"
SPRINGPORT_VILLAGE = "75860"
ST_CHARLES_VILLAGE = "70640"
ST_CLAIR_SHORES_CITY = "70760"
ST_CLAIR_CITY = "70680"
ST_HELEN_CDP = "70800"
ST_IGNACE_CITY = "70840"
ST_JAMES_CDP = "70900"
ST_JOHNS_CITY = "70940"
ST_JOSEPH_CITY = "70960"
ST_LOUIS_CITY = "71000"
STANDISH_CITY = "76120"
STANTON_CITY = "76220"
STANWOOD_VILLAGE = "76240"
STEPHENSON_CITY = "76380"
STERLING_HEIGHTS_CITY = "76460"
STERLING_VILLAGE = "76420"
STEVENSVILLE_VILLAGE = "76500"
STOCKBRIDGE_VILLAGE = "76560"
STONY_POINT_CDP = "76720"
STRONACH_CDP = "76820"
STURGIS_CITY = "76960"
SUNFIELD_VILLAGE = "77420"
SUTTONS_BAY_VILLAGE = "77600"
SWARTZ_CREEK_CITY = "77700"
SYLVAN_LAKE_CITY = "77860"
TAWAS_CITY_CITY = "78140"
TAYLOR_CITY = "79000"
TECUMSEH_CITY = "79120"
TEKONSHA_VILLAGE = "79160"
TEMPERANCE_CDP = "79240"
THOMPSONVILLE_VILLAGE = "79600"
THREE_LAKES_CDP = "79680"
THREE_OAKS_VILLAGE = "79720"
THREE_RIVERS_CITY = "79760"
TOWER_CDP = "80200"
TRAVERSE_CITY_CITY = "80340"
TRENTON_CITY = "80420"
TRIMOUNTAIN_CDP = "80480"
TROWBRIDGE_PARK_CDP = "80660"
TROY_CITY = "80700"
TRUFANT_CDP = "80720"
TURNER_VILLAGE = "80820"
TUSTIN_VILLAGE = "80960"
TWIN_LAKE_CDP = "81040"
TWINING_VILLAGE = "81020"
UBLY_VILLAGE = "81200"
UNION_CITY_VILLAGE = "81360"
UNIONVILLE_VILLAGE = "81420"
UTICA_CITY = "81540"
VANDALIA_VILLAGE = "81680"
VANDERBILT_VILLAGE = "81700"
VANDERCOOK_LAKE_CDP = "81740"
VASSAR_CITY = "81840"
VERMONTVILLE_VILLAGE = "81960"
VERNON_VILLAGE = "82020"
VICKSBURG_VILLAGE = "82300"
VILLAGE_OF_CLARKSTON_CITY = "82450"
VILLAGE_OF_GROSSE_POINTE_SHORES_CITY = "82453"
VINEYARD_LAKE_CDP = "82490"
WACOUSTA_CDP = "82680"
WAKEFIELD_CITY = "82780"
WALDRON_VILLAGE = "82880"
WALKER_CITY = "82960"
WALKERVILLE_VILLAGE = "83020"
WALLED_LAKE_CITY = "83060"
WALLOON_LAKE_CDP = "83140"
WARREN_CITY = "84000"
WATERSMEET_CDP = "84360"
WATERVLIET_CITY = "84500"
WAVERLY_CDP = "84800"
WAYLAND_CITY = "84880"
WAYNE_CITY = "84940"
WEBBERVILLE_VILLAGE = "85080"
WEDGEWOOD_CDP = "85110"
WEIDMAN_CDP = "85140"
WELLSTON_CDP = "85300"
WEST_BRANCH_CITY = "85580"
WEST_ISHPEMING_CDP = "85700"
WEST_MONROE_CDP = "86050"
WESTLAND_CITY = "86000"
WESTPHALIA_VILLAGE = "86120"
WESTWOOD_CDP = "86380"
WHITE_CLOUD_CITY = "86680"
WHITE_PIGEON_VILLAGE = "86920"
WHITE_PINE_CDP = "86960"
WHITEHALL_CITY = "86780"
WHITMORE_LAKE_CDP = "87060"
WHITTEMORE_CITY = "87140"
WILLIAMSTON_CITY = "87420"
WINN_CDP = "87920"
WIXOM_CITY = "88140"
WOLF_LAKE_CDP = "88220"
WOLVERINE_LAKE_VILLAGE = "88260"
WOLVERINE_VILLAGE = "88240"
WOODHAVEN_CITY = "88380"
WOODLAND_BEACH_CDP = "88480"
WOODLAND_VILLAGE = "88420"
WYANDOTTE_CITY = "88900"
WYOMING_CITY = "88940"
YALE_CITY = "89000"
YPSILANTI_CITY = "89140"
ZEBA_CDP = "89240"
ZEELAND_CITY = "89260"
ZILWAUKEE_CITY = "89320"
