# Copyright (c) 2023 Darren Erik Vengroff
"""Places in New York."""


ACCORD_CDP = "00155"
ADAMS_CENTER_CDP = "00232"
ADAMS_VILLAGE = "00199"
ADDISON_VILLAGE = "00276"
AFTON_VILLAGE = "00342"
AIRMONT_VILLAGE = "00408"
AKRON_VILLAGE = "00441"
AKWESASNE_CDP = "00457"
ALBANY_CITY = "01000"
ALBERTSON_CDP = "01011"
ALBION_VILLAGE = "01033"
ALDEN_VILLAGE = "01088"
ALEXANDER_VILLAGE = "01154"
ALEXANDRIA_BAY_VILLAGE = "01187"
ALFRED_VILLAGE = "01198"
ALLEGANY_VILLAGE = "01286"
ALMOND_VILLAGE = "01440"
ALTAMONT_VILLAGE = "01517"
ALTMAR_CDP = "01550"
ALTONA_CDP = "01572"
AMAGANSETT_CDP = "01594"
AMENIA_CDP = "01682"
AMES_VILLAGE = "01737"
AMITYVILLE_VILLAGE = "02044"
AMSTERDAM_CITY = "02066"
ANDES_CDP = "02121"
ANDOVER_VILLAGE = "02143"
ANGELICA_VILLAGE = "02176"
ANGOLA_ON_THE_LAKE_CDP = "02220"
ANGOLA_VILLAGE = "02198"
ANTWERP_VILLAGE = "02286"
APALACHIN_CDP = "02308"
AQUEBOGUE_CDP = "02374"
ARCADE_VILLAGE = "02407"
ARDSLEY_VILLAGE = "02506"
ARGYLE_VILLAGE = "02550"
ARKPORT_VILLAGE = "02583"
ARLINGTON_CDP = "02616"
ARMONK_CDP = "02649"
ASHAROKEN_VILLAGE = "02737"
ATHENS_VILLAGE = "02902"
ATLANTIC_BEACH_VILLAGE = "02968"
ATTICA_VILLAGE = "03001"
AU_SABLE_FORKS_CDP = "03254"
AUBURN_CITY = "03078"
AURORA_VILLAGE = "03188"
AVERILL_PARK_CDP = "03320"
AVOCA_VILLAGE = "03331"
AVON_VILLAGE = "03353"
BABYLON_VILLAGE = "03408"
BAINBRIDGE_VILLAGE = "04033"
BAITING_HOLLOW_CDP = "04055"
BALDWIN_CDP = "04143"
BALDWINSVILLE_VILLAGE = "04198"
BALLSTON_SPA_VILLAGE = "04253"
BALMVILLE_CDP = "04286"
BARD_COLLEGE_CDP = "04388"
BARDONIA_CDP = "04396"
BARKER_VILLAGE = "04440"
BARNEVELD_CDP = "04528"
BARNUM_ISLAND_CDP = "04550"
BARRYTOWN_CDP = "04605"
BARRYVILLE_CDP = "04616"
BATAVIA_CITY = "04715"
BATH_VILLAGE = "04759"
BAXTER_ESTATES_VILLAGE = "04803"
BAY_PARK_CDP = "04891"
BAY_SHORE_CDP = "04935"
BAYPORT_CDP = "04913"
BAYVILLE_VILLAGE = "05034"
BAYWOOD_CDP = "05039"
BEACON_CITY = "05100"
BEAVER_DAM_LAKE_CDP = "05188"
BEDFORD_CDP = "05309"
BEDFORD_HILLS_CDP = "05342"
BELFAST_CDP = "05562"
BELLE_TERRE_VILLAGE = "05672"
BELLEROSE_TERRACE_CDP = "05661"
BELLEROSE_VILLAGE = "05639"
BELLEVILLE_CDP = "05683"
BELLMORE_CDP = "05738"
BELLPORT_VILLAGE = "05771"
BELMONT_VILLAGE = "05815"
BEMUS_POINT_VILLAGE = "05848"
BERGEN_VILLAGE = "06046"
BETHPAGE_CDP = "06387"
BIG_FLATS_CDP = "06464"
BILLINGTON_HEIGHTS_CDP = "06574"
BINGHAMTON_UNIVERSITY_CDP = "06644"
BINGHAMTON_CITY = "06607"
BLACK_RIVER_VILLAGE = "06794"
BLASDELL_VILLAGE = "06849"
BLAUVELT_CDP = "06860"
BLISS_CDP = "06904"
BLODGETT_MILLS_CDP = "06937"
BLOOMFIELD_VILLAGE = "06945"
BLOOMINGBURG_VILLAGE = "06959"
BLOOMVILLE_CDP = "07025"
BLUE_POINT_CDP = "07069"
BOHEMIA_CDP = "07157"
BOLIVAR_VILLAGE = "07190"
BOLTON_LANDING_CDP = "07245"
BOONVILLE_VILLAGE = "07355"
BRASHER_FALLS_CDP = "07960"
BREESPORT_CDP = "08004"
BRENTWOOD_CDP = "08026"
BREWERTON_CDP = "08059"
BREWSTER_HEIGHTS_CDP = "08081"
BREWSTER_HILL_CDP = "08092"
BREWSTER_VILLAGE = "08070"
BRIARCLIFF_MANOR_VILLAGE = "08103"
BRIDGEHAMPTON_CDP = "08136"
BRIDGEPORT_CDP = "08147"
BRIDGEVILLE_CDP = "08158"
BRIDGEWATER_CDP = "08169"
BRIGHTON_CDP = "08257"
BRIGHTWATERS_VILLAGE = "08323"
BRINCKERHOFF_CDP = "08334"
BROADALBIN_VILLAGE = "08422"
BROCKPORT_VILLAGE = "08466"
BROCTON_VILLAGE = "08488"
BRONXVILLE_VILLAGE = "08532"
BROOKHAVEN_CDP = "09000"
BROOKTONDALE_CDP = "10077"
BROOKVILLE_VILLAGE = "10132"
BROWNVILLE_VILLAGE = "10231"
BRUSHTON_VILLAGE = "10286"
BUCHANAN_VILLAGE = "10341"
BUFFALO_CITY = "11000"
BURDETT_VILLAGE = "11132"
BURKE_VILLAGE = "11154"
BURLINGTON_FLATS_CDP = "11220"
BUSTI_CDP = "11440"
BYERSVILLE_CDP = "11550"
CADYVILLE_CDP = "11616"
CAIRO_CDP = "11638"
CALCIUM_CDP = "11671"
CALEDONIA_VILLAGE = "11704"
CALLICOON_CDP = "11748"
CALVERTON_CDP = "11781"
CAMBRIDGE_VILLAGE = "11825"
CAMDEN_VILLAGE = "11847"
CAMILLUS_VILLAGE = "11902"
CAMPBELL_CDP = "11935"
CANAJOHARIE_VILLAGE = "12111"
CANANDAIGUA_CITY = "12144"
CANASERAGA_VILLAGE = "12177"
CANASTOTA_VILLAGE = "12188"
CANDOR_VILLAGE = "12210"
CANISTEO_VILLAGE = "12254"
CANTON_VILLAGE = "12331"
CAPE_VINCENT_VILLAGE = "12353"
CAPTREE_CDP = "12402"
CARLE_PLACE_CDP = "12419"
CARMEL_CDP = "12518"
CAROGA_LAKE_CDP = "12584"
CARTHAGE_VILLAGE = "12683"
CASSADAGA_VILLAGE = "12749"
CASTILE_VILLAGE = "12771"
CASTLETON_ON_HUDSON_VILLAGE = "12870"
CASTORLAND_VILLAGE = "12881"
CATO_VILLAGE = "12958"
CATSKILL_VILLAGE = "13002"
CATTARAUGUS_VILLAGE = "13024"
CAYUGA_HEIGHTS_VILLAGE = "13079"
CAYUGA_VILLAGE = "13068"
CAZENOVIA_VILLAGE = "13145"
CEDARHURST_VILLAGE = "13233"
CELORON_VILLAGE = "13288"
CEMENTON_CDP = "13299"
CENTER_MORICHES_CDP = "13420"
CENTEREACH_CDP = "13376"
CENTERPORT_CDP = "13442"
CENTRAL_BRIDGE_CDP = "13530"
CENTRAL_ISLIP_CDP = "13552"
CENTRAL_SQUARE_VILLAGE = "13585"
CENTRE_ISLAND_VILLAGE = "13618"
CHADWICKS_CDP = "13662"
CHAMPLAIN_VILLAGE = "13739"
CHAPPAQUA_CDP = "13805"
CHATEAUGAY_VILLAGE = "13981"
CHATHAM_VILLAGE = "14003"
CHAUMONT_VILLAGE = "14036"
CHAUTAUQUA_CDP = "14058"
CHAZY_CDP = "14102"
CHEEKTOWAGA_CDP = "15000"
CHELSEA_COVE_CDP = "15060"
CHENANGO_BRIDGE_CDP = "15121"
CHERRY_CREEK_CDP = "15187"
CHERRY_VALLEY_VILLAGE = "15242"
CHESTER_VILLAGE = "15297"
CHESTERTOWN_CDP = "15363"
CHESTNUT_RIDGE_VILLAGE = "15400"
CHITTENANGO_VILLAGE = "15561"
CHURCHVILLE_VILLAGE = "15638"
CLARENCE_CDP = "15814"
CLARENCE_CENTER_CDP = "15836"
CLARK_MILLS_CDP = "15902"
CLARKSON_CDP = "15946"
CLAVERACK_RED_MILLS_CDP = "16050"
CLAYTON_VILLAGE = "16089"
CLAYVILLE_VILLAGE = "16111"
CLEVELAND_VILLAGE = "16188"
CLIFTON_GARDENS_CDP = "16298"
CLIFTON_KNOLLS_MILL_CREEK_CDP = "16322"
CLIFTON_SPRINGS_VILLAGE = "16375"
CLINTON_VILLAGE = "16419"
CLINTONDALE_CDP = "16452"
CLYDE_VILLAGE = "16573"
COBLESKILL_VILLAGE = "16628"
COHOCTON_VILLAGE = "16727"
COHOES_CITY = "16749"
COLD_BROOK_VILLAGE = "16815"
COLD_SPRING_HARBOR_CDP = "16958"
COLD_SPRING_VILLAGE = "16936"
COLONIE_VILLAGE = "17332"
COLTON_CDP = "17398"
COMMACK_CDP = "17530"
CONESUS_CDP = "17607"
CONESUS_LAKE_CDP = "17622"
CONGERS_CDP = "17739"
CONSTABLEVILLE_VILLAGE = "17882"
CONSTANTIA_CDP = "17893"
COOPERS_PLAINS_CDP = "18036"
COOPERSTOWN_VILLAGE = "18047"
COPAKE_CDP = "18091"
COPAKE_FALLS_CDP = "18113"
COPAKE_LAKE_CDP = "18124"
COPENHAGEN_VILLAGE = "18135"
COPIAGUE_CDP = "18146"
CORAM_CDP = "18157"
CORFU_VILLAGE = "18201"
CORINTH_VILLAGE = "18212"
CORNING_CITY = "18256"
CORNWALL_ON_HUDSON_VILLAGE = "18333"
CORTLAND_WEST_CDP = "18443"
CORTLAND_CITY = "18388"
COUNTRY_KNOLLS_CDP = "18542"
COVE_NECK_VILLAGE = "18597"
COXSACKIE_VILLAGE = "18718"
CRAGSMOOR_CDP = "18762"
CRANBERRY_LAKE_CDP = "18817"
CREST_VIEW_HEIGHTS_CDP = "18993"
CROGHAN_VILLAGE = "19070"
CROMPOND_CDP = "19092"
CROTON_ON_HUDSON_VILLAGE = "19213"
CROWN_HEIGHTS_CDP = "19229"
CRUGERS_CDP = "19290"
CRYSTAL_BEACH_CDP = "19308"
CUBA_VILLAGE = "19356"
CUMBERLAND_HEAD_CDP = "19408"
CUMMINSVILLE_CDP = "19411"
CUTCHOGUE_CDP = "19466"
CUYLERVILLE_CDP = "19510"
DALTON_CDP = "19587"
DANBY_CDP = "19609"
DANNEMORA_VILLAGE = "19642"
DANSVILLE_VILLAGE = "19664"
DAVENPORT_CENTER_CDP = "19774"
DE_WITT_CDP = "20467"
DEKALB_JUNCTION_CDP = "20049"
DERUYTER_VILLAGE = "20390"
DEER_PARK_CDP = "19972"
DEFERIET_VILLAGE = "19994"
DELANSON_VILLAGE = "20082"
DELEVAN_VILLAGE = "20115"
DELHI_VILLAGE = "20126"
DEPAUVILLE_CDP = "20302"
DEPEW_VILLAGE = "20313"
DEPOSIT_VILLAGE = "20346"
DERING_HARBOR_VILLAGE = "20379"
DEXTER_VILLAGE = "20500"
DIX_HILLS_CDP = "20687"
DOBBS_FERRY_VILLAGE = "20698"
DOLGEVILLE_VILLAGE = "20731"
DOVER_PLAINS_CDP = "20841"
DOWNSVILLE_CDP = "20852"
DRESDEN_VILLAGE = "20896"
DRYDEN_VILLAGE = "20951"
DUANE_LAKE_CDP = "20989"
DUANESBURG_CDP = "20995"
DUNDEE_VILLAGE = "21050"
DUNKIRK_CITY = "21105"
DURHAMVILLE_CDP = "21226"
EAGLE_BAY_CDP = "21380"
EARLVILLE_VILLAGE = "21523"
EAST_ATLANTIC_BEACH_CDP = "21578"
EAST_AURORA_VILLAGE = "21589"
EAST_AVON_CDP = "21600"
EAST_DURHAM_CDP = "21919"
EAST_FARMINGDALE_CDP = "21985"
EAST_FRANKFORT_CDP = "22029"
EAST_GLENVILLE_CDP = "22084"
EAST_GREENBUSH_CDP = "22106"
EAST_HAMPTON_NORTH_CDP = "22200"
EAST_HAMPTON_VILLAGE = "22183"
EAST_HERKIMER_CDP = "22238"
EAST_HILLS_VILLAGE = "22260"
EAST_ISLIP_CDP = "22315"
EAST_ITHACA_CDP = "22326"
EAST_KINGSTON_CDP = "22370"
EAST_MARION_CDP = "22447"
EAST_MASSAPEQUA_CDP = "22480"
EAST_MEADOW_CDP = "22502"
EAST_MORICHES_CDP = "22546"
EAST_NASSAU_VILLAGE = "22557"
EAST_NORTHPORT_CDP = "22612"
EAST_NORWICH_CDP = "22623"
EAST_PATCHOGUE_CDP = "22733"
EAST_QUOGUE_CDP = "22832"
EAST_RANDOLPH_CDP = "22843"
EAST_ROCHESTER_VILLAGE = "22865"
EAST_ROCKAWAY_VILLAGE = "22876"
EAST_SETAUKET_CDP = "22964"
EAST_SHOREHAM_CDP = "22980"
EAST_SYRACUSE_VILLAGE = "23052"
EAST_WILLISTON_VILLAGE = "23217"
EAST_WORCESTER_CDP = "23283"
EASTCHESTER_CDP = "21809"
EASTPORT_CDP = "22810"
EATONS_NECK_CDP = "23316"
EDEN_CDP = "23404"
EDMESTON_CDP = "23602"
EDWARDS_CDP = "23635"
EGGERTSVILLE_CDP = "23701"
ELBA_VILLAGE = "23745"
ELBRIDGE_VILLAGE = "23789"
ELDRED_CDP = "23811"
ELIZABETHTOWN_CDP = "23822"
ELLENVILLE_VILLAGE = "23965"
ELLICOTTVILLE_VILLAGE = "24020"
ELLISBURG_VILLAGE = "24075"
ELMA_CENTER_CDP = "24141"
ELMIRA_HEIGHTS_VILLAGE = "24251"
ELMIRA_CITY = "24229"
ELMONT_CDP = "24273"
ELMSFORD_VILLAGE = "24295"
ELWOOD_CDP = "24405"
ENDICOTT_VILLAGE = "24515"
ENDWELL_CDP = "24526"
ERIN_CDP = "24625"
ESPERANCE_VILLAGE = "24713"
EVANS_MILLS_VILLAGE = "24823"
FABIUS_VILLAGE = "24867"
FAIR_HAVEN_VILLAGE = "24988"
FAIRMOUNT_CDP = "25043"
FAIRPORT_VILLAGE = "25076"
FAIRVIEW_CDP_DUTCHESS_COUNTY = "25109"
FAIRVIEW_CDP_WESTCHESTER_COUNTY = "25120"
FALCONER_VILLAGE = "25164"
FALLSBURG_CDP = "25230"
FARMINGDALE_VILLAGE = "25384"
FARMINGVILLE_CDP = "25417"
FARNHAM_VILLAGE = "25428"
FAYETTEVILLE_VILLAGE = "25527"
FELTS_MILLS_CDP = "25571"
FILLMORE_CDP = "25747"
FIRE_ISLAND_CDP = "25839"
FIRTHCLIFFE_CDP = "25857"
FISHERS_ISLAND_CDP = "25923"
FISHERS_LANDING_CDP = "25934"
FISHKILL_VILLAGE = "25967"
FLANDERS_CDP = "26121"
FLEISCHMANNS_VILLAGE = "26209"
FLORAL_PARK_VILLAGE = "26264"
FLORIDA_VILLAGE = "26319"
FLOWER_HILL_VILLAGE = "26352"
FLY_CREEK_CDP = "26418"
FONDA_VILLAGE = "26462"
FOREST_HOME_CDP = "26561"
FORESTVILLE_CDP = "26649"
FORT_ANN_VILLAGE = "26704"
FORT_COVINGTON_CDP = "26726"
FORT_DRUM_CDP = "26759"
FORT_EDWARD_VILLAGE = "26770"
FORT_JOHNSON_VILLAGE = "26880"
FORT_MONTGOMERY_CDP = "26902"
FORT_PLAIN_VILLAGE = "26924"
FORT_SALONGA_CDP = "26946"
FOWLERVILLE_CDP = "27133"
FRANKFORT_VILLAGE = "27188"
FRANKLIN_SQUARE_CDP = "27309"
FRANKLIN_VILLAGE = "27221"
FRANKLINVILLE_VILLAGE = "27331"
FREDONIA_VILLAGE = "27419"
FREEDOM_PLAINS_CDP = "27452"
FREEPORT_VILLAGE = "27485"
FREEVILLE_VILLAGE = "27529"
FREWSBURG_CDP = "27672"
FRIENDSHIP_CDP = "27694"
FULTON_CITY = "27815"
FULTONVILLE_VILLAGE = "27859"
GAINESVILLE_VILLAGE = "27969"
GALEVILLE_CDP = "28035"
GALWAY_VILLAGE = "28101"
GANANDA_CDP = "28138"
GANG_MILLS_CDP = "28145"
GARDEN_CITY_PARK_CDP = "28189"
GARDEN_CITY_SOUTH_CDP = "28200"
GARDEN_CITY_VILLAGE = "28178"
GARDINER_CDP = "28244"
GARDNERTOWN_CDP = "28310"
GARRATTSVILLE_CDP = "28376"
GASPORT_CDP = "28431"
GATES_CDP = "28453"
GENESEO_VILLAGE = "28618"
GENEVA_CITY = "28640"
GERMANTOWN_CDP = "28761"
GHENT_CDP = "28860"
GILBERTSVILLE_VILLAGE = "28959"
GILGO_CDP = "28990"
GLASCO_CDP = "29014"
GLEN_AUBREY_CDP = "29058"
GLEN_COVE_CITY = "29113"
GLEN_HEAD_CDP = "29245"
GLEN_PARK_VILLAGE = "29322"
GLENS_FALLS_NORTH_CDP = "29338"
GLENS_FALLS_CITY = "29333"
GLENWOOD_LANDING_CDP = "29421"
GLOVERSVILLE_CITY = "29443"
GOLDENS_BRIDGE_CDP = "29476"
GORDON_HEIGHTS_CDP = "29509"
GORHAM_CDP = "29520"
GOSHEN_VILLAGE = "29542"
GOUVERNEUR_VILLAGE = "29597"
GOWANDA_VILLAGE = "29630"
GRAHAMSVILLE_CDP = "29707"
GRAND_VIEW_ON_HUDSON_VILLAGE = "29872"
GRANDYLE_VILLAGE_CDP = "29894"
GRANVILLE_VILLAGE = "30026"
GREAT_BEND_CDP = "30136"
GREAT_NECK_ESTATES_VILLAGE = "30191"
GREAT_NECK_GARDENS_CDP = "30202"
GREAT_NECK_PLAZA_VILLAGE = "30213"
GREAT_NECK_VILLAGE = "30169"
GREAT_RIVER_CDP = "30235"
GREECE_CDP = "30279"
GREEN_ISLAND_VILLAGE = "30521"
GREENE_VILLAGE = "30411"
GREENLAWN_CDP = "30543"
GREENPORT_WEST_CDP = "30581"
GREENPORT_VILLAGE = "30576"
GREENVALE_CDP = "30598"
GREENVILLE_CDP_GREENE_COUNTY = "30609"
GREENVILLE_CDP_WESTCHESTER_COUNTY = "30642"
GREENWICH_VILLAGE = "30675"
GREENWOOD_LAKE_VILLAGE = "30752"
GREIGSVILLE_CDP = "30807"
GROTON_VILLAGE = "30961"
GROVELAND_STATION_CDP = "31022"
GUILFORD_CDP = "31137"
HADLEY_CDP = "31258"
HAGAMAN_VILLAGE = "31291"
HAILESBORO_CDP = "31346"
HAINES_FALLS_CDP = "31357"
HALESITE_CDP = "31445"
HALL_CDP = "31533"
HAMBURG_VILLAGE = "31643"
HAMILTON_COLLEGE_CDP = "31746"
HAMILTON_VILLAGE = "31709"
HAMLIN_CDP = "31786"
HAMMOND_VILLAGE = "31830"
HAMMONDSPORT_VILLAGE = "31852"
HAMPTON_BAYS_CDP = "31896"
HAMPTON_MANOR_CDP = "31918"
HANCOCK_VILLAGE = "31940"
HANKINS_CDP = "31973"
HANNAWA_FALLS_CDP = "32006"
HANNIBAL_VILLAGE = "32017"
HARBOR_HILLS_CDP = "32094"
HARBOR_ISLE_CDP = "32105"
HARRIMAN_VILLAGE = "32325"
HARRIS_HILL_CDP = "32391"
HARRISON_VILLAGE = "32402"
HARTSDALE_CDP = "32523"
HARTWICK_CDP = "32578"
HARTWICK_SEMINARY_CDP = "32597"
HASTINGS_ON_HUDSON_VILLAGE = "32710"
HAUPPAUGE_CDP = "32732"
HAVERSTRAW_VILLAGE = "32754"
HAVILAND_CDP = "32776"
HAWTHORNE_CDP = "32842"
HEAD_OF_THE_HARBOR_VILLAGE = "32963"
HEMLOCK_CDP = "33128"
HEMPSTEAD_VILLAGE = "33139"
HENDERSON_CDP = "34044"
HERITAGE_HILLS_CDP = "34118"
HERKIMER_VILLAGE = "34121"
HERMON_CDP = "34165"
HERRICKS_CDP = "34198"
HERRINGS_CDP = "34220"
HEUVELTON_VILLAGE = "34264"
HEWLETT_BAY_PARK_VILLAGE = "34297"
HEWLETT_CDP = "34286"
HEWLETT_HARBOR_VILLAGE = "34308"
HEWLETT_NECK_VILLAGE = "34319"
HICKSVILLE_CDP = "34374"
HIGH_FALLS_CDP = "34451"
HIGHLAND_CDP = "34484"
HIGHLAND_FALLS_VILLAGE = "34495"
HIGHLAND_ON_THE_LAKE_CDP = "34528"
HILLBURN_VILLAGE = "34660"
HILLCREST_CDP = "34693"
HILLSIDE_CDP = "34786"
HILLSIDE_LAKE_CDP = "34803"
HILTON_VILLAGE = "34847"
HOBART_VILLAGE = "34979"
HOLBROOK_CDP = "35056"
HOLLAND_CDP = "35111"
HOLLAND_PATENT_VILLAGE = "35144"
HOLLEY_VILLAGE = "35155"
HOLTSVILLE_CDP = "35254"
HOMER_VILLAGE = "35276"
HONEOYE_CDP = "35353"
HONEOYE_FALLS_VILLAGE = "35364"
HOOSICK_FALLS_VILLAGE = "35474"
HOPEWELL_JUNCTION_CDP = "35573"
HORNELL_CITY = "35672"
HORSEHEADS_NORTH_CDP = "35710"
HORSEHEADS_VILLAGE = "35694"
HORTONVILLE_CDP = "35738"
HOUGHTON_CDP = "35771"
HUDSON_FALLS_VILLAGE = "35980"
HUDSON_CITY = "35969"
HUNT_CDP = "36156"
HUNTER_VILLAGE = "36167"
HUNTINGTON_BAY_VILLAGE = "37022"
HUNTINGTON_CDP = "36233"
HUNTINGTON_STATION_CDP = "37044"
HURLEY_CDP = "37132"
HURLEYVILLE_CDP = "37154"
HYDE_PARK_CDP = "37198"
ILION_VILLAGE = "37275"
INTERLAKEN_VILLAGE = "37528"
INWOOD_CDP = "37583"
IRONDEQUOIT_CDP = "37737"
IRVINGTON_VILLAGE = "37803"
ISLAND_PARK_VILLAGE = "37847"
ISLANDIA_VILLAGE = "37840"
ISLIP_CDP = "37869"
ISLIP_TERRACE_CDP = "38022"
ITHACA_CITY = "38077"
JACKSONVILLE_CDP = "38209"
JAMESPORT_CDP = "38253"
JAMESTOWN_WEST_CDP = "38275"
JAMESTOWN_CITY = "38264"
JEFFERSON_CDP = "38429"
JEFFERSON_HEIGHTS_CDP = "38451"
JEFFERSON_VALLEY_YORKTOWN_CDP = "38500"
JEFFERSONVILLE_VILLAGE = "38506"
JERICHO_CDP = "38539"
JOHNSON_CITY_VILLAGE = "38748"
JOHNSTOWN_CITY = "38781"
JORDAN_VILLAGE = "38825"
KASER_VILLAGE = "38934"
KATONAH_CDP = "38946"
KAUNEONGA_LAKE_CDP = "38985"
KEESEVILLE_CDP = "39089"
KENMORE_VILLAGE = "39232"
KENNEDY_CDP = "39243"
KENSINGTON_VILLAGE = "39309"
KERHONKSON_CDP = "39397"
KEUKA_PARK_CDP = "39463"
KIAMESHA_LAKE_CDP = "39485"
KINDERHOOK_VILLAGE = "39562"
KINGS_PARK_CDP = "39672"
KINGS_POINT_VILLAGE = "39694"
KINGSTON_CITY = "39727"
KIRYAS_JOEL_VILLAGE = "39853"
KYSORVILLE_CDP = "40175"
LA_FARGEVILLE_CDP = "40233"
LACKAWANNA_CITY = "40189"
LACONA_VILLAGE = "40200"
LAKE_CARMEL_CDP = "40398"
LAKE_DELTA_CDP = "40475"
LAKE_ERIE_BEACH_CDP = "40486"
LAKE_GEORGE_VILLAGE = "40508"
LAKE_GROVE_VILLAGE = "40530"
LAKE_HUNTINGTON_CDP = "40552"
LAKE_KATRINE_CDP = "40585"
LAKE_LUZERNE_CDP = "40651"
LAKE_MOHEGAN_CDP = "40689"
LAKE_PLACID_VILLAGE = "40761"
LAKE_RONKONKOMA_CDP = "40838"
LAKE_SUCCESS_VILLAGE = "40937"
LAKELAND_CDP = "40607"
LAKEVIEW_CDP = "41003"
LAKEVILLE_CDP = "41036"
LAKEWOOD_VILLAGE = "41069"
LANCASTER_VILLAGE = "41135"
LANSING_VILLAGE = "41223"
LARCHMONT_VILLAGE = "41333"
LATHAM_CDP = "41399"
LATTINGTOWN_VILLAGE = "41432"
LAUREL_CDP = "41465"
LAUREL_HOLLOW_VILLAGE = "41487"
LAURENS_VILLAGE = "41520"
LAWRENCE_VILLAGE = "41553"
LE_ROY_VILLAGE = "42026"
LEEDS_CDP = "41784"
LEICESTER_VILLAGE = "41872"
LEVITTOWN_CDP = "42081"
LEWISTON_VILLAGE = "42147"
LIBERTY_VILLAGE = "42224"
LIDO_BEACH_CDP = "42279"
LIMA_VILLAGE = "42323"
LIME_LAKE_CDP = "42345"
LIMESTONE_CDP = "42378"
LINCOLN_PARK_CDP = "42488"
LINCOLNDALE_CDP = "42455"
LINDENHURST_VILLAGE = "42554"
LINWOOD_CDP = "42609"
LISLE_VILLAGE = "42642"
LITTLE_FALLS_CITY = "42741"
LITTLE_VALLEY_VILLAGE = "42829"
LIVERPOOL_VILLAGE = "42884"
LIVINGSTON_MANOR_CDP = "42928"
LIVONIA_CENTER_CDP = "42972"
LIVONIA_VILLAGE = "42950"
LLOYD_HARBOR_VILLAGE = "43005"
LOCH_SHELDRAKE_CDP = "43038"
LOCKPORT_CITY = "43082"
LOCUST_VALLEY_CDP = "43192"
LODI_VILLAGE = "43214"
LONG_BEACH_CITY = "43335"
LONG_LAKE_CDP = "43401"
LORENZ_PARK_CDP = "43511"
LORRAINE_CDP = "43533"
LOUDONVILLE_CDP = "43566"
LOWVILLE_VILLAGE = "43720"
LYNBROOK_VILLAGE = "43874"
LYNCOURT_CDP = "43885"
LYNDONVILLE_VILLAGE = "43918"
LYON_MOUNTAIN_CDP = "43951"
LYONS_CDP = "43962"
LYONS_FALLS_VILLAGE = "44006"
MACDONNELL_HEIGHTS_CDP = "44105"
MACEDON_CDP = "44149"
MACHIAS_CDP = "44226"
MADISON_VILLAGE = "44424"
MADRID_CDP = "44479"
MAHOPAC_CDP = "44534"
MALDEN_ON_HUDSON_CDP = "44677"
MALONE_VILLAGE = "44710"
MALVERNE_PARK_OAKS_CDP = "44792"
MALVERNE_VILLAGE = "44787"
MAMARONECK_VILLAGE = "44831"
MANCHESTER_VILLAGE = "44853"
MANHASSET_CDP = "44897"
MANHASSET_HILLS_CDP = "44908"
MANLIUS_VILLAGE = "45018"
MANNSVILLE_VILLAGE = "45073"
MANORHAVEN_VILLAGE = "45106"
MANORVILLE_CDP = "45139"
MARATHON_VILLAGE = "45392"
MARCELLUS_VILLAGE = "45480"
MARCY_CDP = "45524"
MARGARETVILLE_VILLAGE = "45557"
MARIAVILLE_LAKE_CDP = "45573"
MARION_CDP = "45634"
MARIST_COLLEGE_CDP = "45659"
MARLBORO_CDP = "45700"
MASSAPEQUA_CDP = "45986"
MASSAPEQUA_PARK_VILLAGE = "45997"
MASSENA_VILLAGE = "46019"
MASTIC_BEACH_CDP = "46085"
MASTIC_CDP = "46074"
MATINECOCK_VILLAGE = "46107"
MATTITUCK_CDP = "46140"
MATTYDALE_CDP = "46151"
MAYBROOK_VILLAGE = "46162"
MAYFIELD_VILLAGE = "46206"
MAYVILLE_VILLAGE = "46239"
MCGRAW_VILLAGE = "44193"
MCLEAN_CDP = "44358"
MECHANICSTOWN_CDP = "46349"
MECHANICVILLE_CITY = "46360"
MEDFORD_CDP = "46404"
MEDINA_VILLAGE = "46415"
MELROSE_PARK_CDP = "46503"
MELVILLE_CDP = "46514"
MENANDS_VILLAGE = "46536"
MERIDIAN_VILLAGE = "46646"
MERRICK_CDP = "46668"
MERRITT_PARK_CDP = "46750"
MEXICO_VILLAGE = "46811"
MIDDLE_ISLAND_CDP = "46976"
MIDDLEBURGH_VILLAGE = "46866"
MIDDLEPORT_VILLAGE = "46998"
MIDDLETOWN_CITY = "47042"
MIDDLEVILLE_VILLAGE = "47108"
MILFORD_VILLAGE = "47229"
MILL_NECK_VILLAGE = "47405"
MILLBROOK_VILLAGE = "47273"
MILLER_PLACE_CDP = "47306"
MILLERTON_VILLAGE = "47361"
MILLPORT_VILLAGE = "47427"
MILLWOOD_CDP = "47482"
MILTON_CDP_SARATOGA_COUNTY = "47548"
MILTON_CDP_ULSTER_COUNTY = "47554"
MINEOLA_VILLAGE = "47636"
MINETTO_CDP = "47680"
MINEVILLE_CDP = "47702"
MINOA_VILLAGE = "47757"
MOHAWK_VILLAGE = "47823"
MONGAUP_VALLEY_CDP = "47977"
MONROE_VILLAGE = "47988"
MONSEY_CDP = "48010"
MONTAUK_CDP = "48054"
MONTEBELLO_VILLAGE = "48090"
MONTGOMERY_VILLAGE = "48142"
MONTICELLO_VILLAGE = "48175"
MONTOUR_FALLS_VILLAGE = "48197"
MONTROSE_CDP = "48208"
MOOERS_CDP = "48241"
MORAVIA_VILLAGE = "48296"
MORICHES_CDP = "48450"
MORRIS_VILLAGE = "48483"
MORRISONVILLE_CDP = "48538"
MORRISVILLE_VILLAGE = "48593"
MOUNT_IVY_CDP = "48879"
MOUNT_KISCO_VILLAGE = "48890"
MOUNT_MORRIS_VILLAGE = "48945"
MOUNT_SINAI_CDP = "49066"
MOUNT_VERNON_CITY = "49121"
MOUNT_VISION_CDP = "49143"
MOUNTAIN_DALE_CDP = "48736"
MOUNTAIN_LODGE_PARK_CDP = "48750"
MUNNSVILLE_VILLAGE = "49220"
MUNSEY_PARK_VILLAGE = "49231"
MUNSONS_CORNERS_CDP = "49242"
MUTTONTOWN_VILLAGE = "49330"
MYERS_CORNER_CDP = "49363"
NANUET_CDP = "49407"
NAPANOCH_CDP = "49418"
NAPEAGUE_CDP = "49424"
NAPLES_VILLAGE = "49429"
NARROWSBURG_CDP = "49473"
NASSAU_LAKE_CDP = "49555"
NASSAU_VILLAGE = "49506"
NATURAL_BRIDGE_CDP = "49605"
NAZARETH_COLLEGE_CDP = "49715"
NEDROW_CDP = "49726"
NELLISTON_VILLAGE = "49748"
NELSONVILLE_VILLAGE = "49781"
NESCONSET_CDP = "49825"
NEW_BALTIMORE_CDP = "49924"
NEW_BERLIN_VILLAGE = "49946"
NEW_CASSEL_CDP = "50067"
NEW_CITY_CDP = "50100"
NEW_HACKENSACK_CDP = "50265"
NEW_HAMBURG_CDP = "50276"
NEW_HARTFORD_VILLAGE = "50298"
NEW_HEMPSTEAD_VILLAGE = "50353"
NEW_HYDE_PARK_VILLAGE = "50397"
NEW_PALTZ_VILLAGE = "50551"
NEW_ROCHELLE_CITY = "50617"
NEW_SQUARE_VILLAGE = "50705"
NEW_SUFFOLK_CDP = "50727"
NEW_WINDSOR_CDP = "50837"
NEW_YORK_MILLS_VILLAGE = "51011"
NEW_YORK_CITY = "51000"
NEWARK_VALLEY_VILLAGE = "49902"
NEWARK_VILLAGE = "49891"
NEWBURGH_CITY = "50034"
NEWFANE_CDP = "50221"
NEWFIELD_CDP = "50243"
NEWPORT_VILLAGE = "50573"
NIAGARA_FALLS_CITY = "51055"
NIAGARA_UNIVERSITY_CDP = "51088"
NICHOLS_VILLAGE = "51110"
NISKAYUNA_CDP = "51262"
NISSEQUOGUE_VILLAGE = "51286"
NIVERVILLE_CDP = "51297"
NORFOLK_CDP = "51319"
NORTH_AMITYVILLE_CDP = "51396"
NORTH_BABYLON_CDP = "51440"
NORTH_BALLSTON_SPA_CDP = "51467"
NORTH_BAY_CDP = "51484"
NORTH_BAY_SHORE_CDP = "51495"
NORTH_BELLMORE_CDP = "51517"
NORTH_BELLPORT_CDP = "51528"
NORTH_BLENHEIM_CDP = "51561"
NORTH_BOSTON_CDP = "51583"
NORTH_COLLINS_VILLAGE = "51792"
NORTH_CREEK_CDP = "51847"
NORTH_GATES_CDP = "52040"
NORTH_GRANVILLE_CDP = "52067"
NORTH_GREAT_RIVER_CDP = "52078"
NORTH_HAVEN_VILLAGE = "52188"
NORTH_HILLS_VILLAGE = "53022"
NORTH_HORNELL_VILLAGE = "53055"
NORTH_LINDENHURST_CDP = "53198"
NORTH_LYNBROOK_CDP = "53231"
NORTH_MASSAPEQUA_CDP = "53253"
NORTH_MERRICK_CDP = "53264"
NORTH_NEW_HYDE_PARK_CDP = "53275"
NORTH_PATCHOGUE_CDP = "53319"
NORTH_ROSE_CDP = "53462"
NORTH_SEA_CDP = "53561"
NORTH_SYRACUSE_VILLAGE = "53660"
NORTH_TONAWANDA_CITY = "53682"
NORTH_VALLEY_STREAM_CDP = "53748"
NORTH_WANTAGH_CDP = "53792"
NORTHAMPTON_CDP = "51418"
NORTHEAST_ITHACA_CDP = "51915"
NORTHPORT_VILLAGE = "53396"
NORTHVILLE_CDP = "53775"
NORTHVILLE_VILLAGE = "53770"
NORTHWEST_HARBOR_CDP = "53852"
NORTHWEST_ITHACA_CDP = "53853"
NORWICH_CITY = "53979"
NORWOOD_VILLAGE = "54012"
NOYACK_CDP = "54056"
NUNDA_VILLAGE = "54078"
NYACK_VILLAGE = "54100"
OAK_BEACH_CDP = "54111"
OAKDALE_CDP = "54144"
OAKFIELD_VILLAGE = "54155"
OCEAN_BEACH_VILLAGE = "54430"
OCEANSIDE_CDP = "54441"
ODESSA_VILLAGE = "54452"
OGDENSBURG_CITY = "54485"
OLCOTT_CDP = "54540"
OLD_BETHPAGE_CDP = "54551"
OLD_BROOKVILLE_VILLAGE = "54562"
OLD_FIELD_VILLAGE = "54617"
OLD_FORGE_CDP = "54639"
OLD_WESTBURY_VILLAGE = "54705"
OLEAN_CITY = "54716"
ONEIDA_CASTLE_VILLAGE = "54848"
ONEIDA_CITY = "54837"
ONEONTA_CITY = "54881"
ONTARIO_CDP = "55002"
ORANGE_LAKE_CDP = "55189"
ORANGEBURG_CDP = "55167"
ORCHARD_PARK_VILLAGE = "55266"
ORIENT_CDP = "55321"
ORISKANY_FALLS_VILLAGE = "55376"
ORISKANY_VILLAGE = "55365"
OSSINING_VILLAGE = "55530"
OSWEGO_CITY = "55574"
OTEGO_VILLAGE = "55618"
OTISVILLE_VILLAGE = "55673"
OTTER_LAKE_CDP = "55750"
OVID_VILLAGE = "55816"
OWEGO_VILLAGE = "55882"
OXBOW_CDP = "55937"
OXFORD_VILLAGE = "55948"
OYSTER_BAY_CDP = "55992"
OYSTER_BAY_COVE_VILLAGE = "56011"
PAINTED_POST_VILLAGE = "56088"
PALATINE_BRIDGE_VILLAGE = "56110"
PALENVILLE_CDP = "56132"
PALMYRA_VILLAGE = "56187"
PAMELIA_CENTER_CDP = "56212"
PANAMA_VILLAGE = "56231"
PARC_CDP = "56291"
PARISH_VILLAGE = "56341"
PARISHVILLE_CDP = "56363"
PATCHOGUE_VILLAGE = "56660"
PAUL_SMITHS_CDP = "56770"
PAVILION_CDP = "56781"
PAWLING_VILLAGE = "56814"
PEACH_LAKE_CDP = "56869"
PEARL_RIVER_CDP = "56902"
PECONIC_CDP = "56968"
PEEKSKILL_CITY = "56979"
PELHAM_MANOR_VILLAGE = "57023"
PELHAM_VILLAGE = "57001"
PENN_YAN_VILLAGE = "57177"
PERRY_VILLAGE = "57243"
PERRYSBURG_CDP = "57287"
PERU_CDP = "57364"
PHELPS_VILLAGE = "57518"
PHILADELPHIA_VILLAGE = "57551"
PHILMONT_VILLAGE = "57639"
PHOENICIA_CDP = "57650"
PHOENIX_VILLAGE = "57661"
PIERMONT_VILLAGE = "57749"
PIERREPONT_MANOR_CDP = "57782"
PIFFARD_CDP = "57804"
PIKE_CDP = "57815"
PINE_BUSH_CDP = "57980"
PINE_HILL_CDP = "58057"
PINE_PLAINS_CDP = "58145"
PINE_VALLEY_CDP = "58189"
PITTSFORD_VILLAGE = "58354"
PLAINEDGE_CDP = "58409"
PLAINVIEW_CDP = "58442"
PLANDOME_HEIGHTS_VILLAGE = "58486"
PLANDOME_MANOR_VILLAGE = "58497"
PLANDOME_VILLAGE = "58475"
PLATTEKILL_CDP = "58541"
PLATTSBURGH_WEST_CDP = "58601"
PLATTSBURGH_CITY = "58574"
PLEASANT_VALLEY_CDP = "58684"
PLEASANTVILLE_VILLAGE = "58728"
PLESSIS_CDP = "58739"
POESTENKILL_CDP = "58794"
POINT_LOOKOUT_CDP = "58849"
POLAND_VILLAGE = "58937"
POMONA_VILLAGE = "58992"
POQUOTT_VILLAGE = "59157"
PORT_BYRON_VILLAGE = "59212"
PORT_CHESTER_VILLAGE = "59223"
PORT_DICKINSON_VILLAGE = "59245"
PORT_EWEN_CDP = "59311"
PORT_GIBSON_CDP = "59322"
PORT_HENRY_CDP = "59333"
PORT_JEFFERSON_STATION_CDP = "59377"
PORT_JEFFERSON_VILLAGE = "59355"
PORT_JERVIS_CITY = "59388"
PORT_LEYDEN_VILLAGE = "59454"
PORT_WASHINGTON_CDP = "59520"
PORT_WASHINGTON_NORTH_VILLAGE = "59531"
PORTLANDVILLE_CDP = "59443"
PORTVILLE_VILLAGE = "59498"
POTSDAM_VILLAGE = "59564"
POTTERSVILLE_CDP = "59619"
POUGHKEEPSIE_CITY = "59641"
PRATTSBURGH_CDP = "59708"
PRATTSVILLE_CDP = "59740"
PRESTON_POTTER_HOLLOW_CDP = "59831"
PROSPECT_CDP = "59883"
PULASKI_VILLAGE = "59960"
PULTNEYVILLE_CDP = "59993"
PUTNAM_LAKE_CDP = "60103"
QUIOGUE_CDP = "60408"
QUOGUE_VILLAGE = "60422"
RADISSON_CDP = "60455"
RANDOLPH_CDP = "60576"
RANSOMVILLE_CDP = "60598"
RAPIDS_CDP = "60609"
RAVENA_VILLAGE = "60675"
RED_CREEK_VILLAGE = "60829"
RED_HOOK_VILLAGE = "60895"
RED_OAKS_MILL_CDP = "60983"
REDFORD_CDP = "60884"
REDWOOD_CDP = "61016"
REMSEN_VILLAGE = "61115"
REMSENBURG_SPEONK_CDP = "61142"
RENSSELAER_FALLS_VILLAGE = "61159"
RENSSELAER_CITY = "61148"
RETSOF_CDP = "61236"
RHINEBECK_VILLAGE = "61346"
RHINECLIFF_CDP = "61368"
RICHBURG_VILLAGE = "61434"
RICHFIELD_SPRINGS_VILLAGE = "61489"
RICHMONDVILLE_VILLAGE = "61588"
RICHVILLE_VILLAGE = "61621"
RIDGE_CDP = "61665"
RIFTON_CDP = "61797"
RIPLEY_CDP = "61874"
RIVERHEAD_CDP = "61973"
RIVERSIDE_CDP = "62066"
RIVERSIDE_VILLAGE = "62061"
ROCHESTER_INSTITUTE_OF_TECHNOLOGY_CDP = "63014"
ROCHESTER_CITY = "63000"
ROCK_HILL_CDP = "63132"
ROCKVILLE_CENTRE_VILLAGE = "63264"
ROCKY_POINT_CDP = "63319"
RODMAN_CDP = "63330"
ROESSLEVILLE_CDP = "63363"
ROME_CITY = "63418"
ROMULUS_CDP = "63429"
RONKONKOMA_CDP = "63473"
ROOSEVELT_CDP = "63506"
ROSCOE_CDP = "63583"
ROSENDALE_CDP = "63725"
ROSLYN_ESTATES_VILLAGE = "63792"
ROSLYN_HARBOR_VILLAGE = "63803"
ROSLYN_HEIGHTS_CDP = "63814"
ROSLYN_VILLAGE = "63770"
ROTTERDAM_CDP = "63924"
ROUND_LAKE_VILLAGE = "63957"
ROUND_TOP_CDP = "63968"
ROUSES_POINT_VILLAGE = "63979"
RUBY_CDP = "64056"
RUSHFORD_CDP = "64155"
RUSHVILLE_VILLAGE = "64199"
RUSSELL_GARDENS_VILLAGE = "64232"
RYE_BROOK_VILLAGE = "64325"
RYE_CITY = "64309"
SUNY_OSWEGO_CDP = "72327"
SACKETS_HARBOR_VILLAGE = "64408"
SADDLE_ROCK_ESTATES_CDP = "64441"
SADDLE_ROCK_VILLAGE = "64430"
SAG_HARBOR_VILLAGE = "64485"
SAGAPONACK_VILLAGE = "64452"
SALAMANCA_CITY = "64749"
SALEM_CDP = "64771"
SALISBURY_CDP = "64842"
SALISBURY_CENTER_CDP = "64848"
SALISBURY_MILLS_CDP = "64859"
SALT_POINT_CDP = "64892"
SALTAIRE_VILLAGE = "64881"
SANBORN_CDP = "64958"
SAND_RIDGE_CDP = "65024"
SANDS_POINT_VILLAGE = "65035"
SANDY_CREEK_VILLAGE = "65068"
SARANAC_LAKE_VILLAGE = "65233"
SARATOGA_SPRINGS_CITY = "65255"
SAUGERTIES_SOUTH_CDP = "65310"
SAUGERTIES_VILLAGE = "65288"
SAVANNAH_CDP = "65332"
SAVONA_VILLAGE = "65354"
SAYVILLE_CDP = "65409"
SCARSDALE_VILLAGE = "65431"
SCHAGHTICOKE_VILLAGE = "65475"
SCHENECTADY_CITY = "65508"
SCHENEVUS_CDP = "65519"
SCHOHARIE_VILLAGE = "65585"
SCHROON_LAKE_CDP = "65640"
SCHUYLER_LAKE_CDP = "65739"
SCHUYLERVILLE_VILLAGE = "65750"
SCIO_CDP = "65761"
SCOTCHTOWN_CDP = "65882"
SCOTIA_VILLAGE = "65893"
SCOTTS_CORNERS_CDP = "65948"
SCOTTSBURG_CDP = "65926"
SCOTTSVILLE_VILLAGE = "65959"
SEA_CLIFF_VILLAGE = "66047"
SEAFORD_CDP = "66058"
SEARINGTOWN_CDP = "66102"
SELDEN_CDP = "66212"
SENECA_FALLS_CDP = "66322"
SENECA_KNOLLS_CDP = "66366"
SETAUKET_CDP = "66465"
SHARON_SPRINGS_VILLAGE = "66663"
SHELTER_ISLAND_CDP = "66828"
SHELTER_ISLAND_HEIGHTS_CDP = "66850"
SHENOROCK_CDP = "66872"
SHERBURNE_VILLAGE = "66883"
SHERMAN_VILLAGE = "66949"
SHERRILL_CITY = "66993"
SHINNECOCK_HILLS_CDP = "67048"
SHIRLEY_CDP = "67070"
SHOKAN_CDP = "67081"
SHOREHAM_VILLAGE = "67191"
SHOREHAVEN_CDP = "67207"
SHORTSVILLE_VILLAGE = "67257"
SHRUB_OAK_CDP = "67279"
SIDNEY_VILLAGE = "67334"
SIENA_COLLEGE_CDP = "67367"
SILVER_CREEK_VILLAGE = "67411"
SILVER_SPRINGS_VILLAGE = "67466"
SINCLAIRVILLE_VILLAGE = "67488"
SKANEATELES_VILLAGE = "67510"
SLATERVILLE_SPRINGS_CDP = "67631"
SLEEPY_HOLLOW_LAKE_CDP = "67640"
SLEEPY_HOLLOW_VILLAGE = "67638"
SLOAN_VILLAGE = "67686"
SLOATSBURG_VILLAGE = "67708"
SMALLWOOD_CDP = "67730"
SMITHTOWN_CDP = "67851"
SMITHVILLE_FLATS_CDP = "68088"
SMYRNA_VILLAGE = "68099"
SODUS_POINT_VILLAGE = "68242"
SODUS_VILLAGE = "68209"
SOLVAY_VILLAGE = "68286"
SOUND_BEACH_CDP = "68374"
SOUTH_BLOOMING_GROVE_VILLAGE = "68610"
SOUTH_CAIRO_CDP = "68737"
SOUTH_CORNING_VILLAGE = "68847"
SOUTH_DAYTON_VILLAGE = "68891"
SOUTH_EDMESTON_CDP = "68946"
SOUTH_FALLSBURG_CDP = "68968"
SOUTH_FARMINGDALE_CDP = "69001"
SOUTH_FLORAL_PARK_VILLAGE = "69023"
SOUTH_GLENS_FALLS_VILLAGE = "69078"
SOUTH_HEMPSTEAD_CDP = "69188"
SOUTH_HILL_CDP = "69199"
SOUTH_HUNTINGTON_CDP = "69254"
SOUTH_ILION_CDP = "69265"
SOUTH_LANSING_CDP = "69342"
SOUTH_LIMA_CDP = "69364"
SOUTH_LOCKPORT_CDP = "69386"
SOUTH_NYACK_VILLAGE = "69441"
SOUTH_VALLEY_STREAM_CDP = "69892"
SOUTHAMPTON_VILLAGE = "68462"
SOUTHOLD_CDP = "69452"
SOUTHPORT_CDP = "69606"
SPACKENKILL_CDP = "70035"
SPARKILL_CDP = "70068"
SPARROW_BUSH_CDP = "70090"
SPECULATOR_VILLAGE = "70123"
SPENCER_VILLAGE = "70167"
SPENCERPORT_VILLAGE = "70189"
SPRING_VALLEY_VILLAGE = "70420"
SPRINGFIELD_CENTER_CDP = "70321"
SPRINGS_CDP = "70387"
SPRINGVILLE_VILLAGE = "70442"
SPRINGWATER_CDP = "70464"
ST_BONAVENTURE_CDP = "64551"
ST_JAMES_CDP = "64584"
ST_JOHN_FISHER_COLLEGE_CDP = "64606"
ST_JOHNSVILLE_VILLAGE = "64639"
ST_REGIS_FALLS_CDP = "64716"
STAATSBURG_CDP = "70552"
STAMFORD_VILLAGE = "70618"
STANNARDS_CDP = "70717"
STAR_LAKE_CDP = "70849"
STEWART_MANOR_VILLAGE = "71267"
STILLWATER_VILLAGE = "71322"
STITTVILLE_CDP = "71377"
STONE_RIDGE_CDP = "71597"
STONY_BROOK_CDP = "71608"
STONY_BROOK_UNIVERSITY_CDP = "71620"
STONY_POINT_CDP = "71663"
STOTTVILLE_CDP = "71718"
STRYKERSVILLE_CDP = "71817"
SUFFERN_VILLAGE = "71894"
SUNSET_BAY_CDP = "72246"
SWAN_LAKE_CDP = "72400"
SYLVAN_BEACH_VILLAGE = "72521"
SYOSSET_CDP = "72554"
SYRACUSE_CITY = "73000"
TACONIC_SHORES_CDP = "73057"
TANNERSVILLE_VILLAGE = "73143"
TAPPAN_CDP = "73154"
TARRYTOWN_VILLAGE = "73176"
TERRYVILLE_CDP = "73352"
THENDARA_CDP = "73495"
THERESA_VILLAGE = "73517"
THIELLS_CDP = "73583"
THOMASTON_VILLAGE = "73605"
THORNWOOD_CDP = "73715"
THOUSAND_ISLAND_PARK_CDP = "73726"
THREE_MILE_BAY_CDP = "73737"
TICONDEROGA_CDP = "73880"
TILLSON_CDP = "73902"
TIOGA_TERRACE_CDP = "73990"
TITUSVILLE_CDP = "74017"
TIVOLI_VILLAGE = "74023"
TONAWANDA_TOWN_CDP = "75021"
TONAWANDA_CITY = "74166"
TOWN_LINE_CDP = "75121"
TRIBES_HILL_CDP = "75341"
TROY_CITY = "75484"
TRUMANSBURG_VILLAGE = "75506"
TUCKAHOE_CDP = "75572"
TUCKAHOE_VILLAGE = "75583"
TULLY_VILLAGE = "75627"
TUPPER_LAKE_VILLAGE = "75671"
TURIN_VILLAGE = "75682"
TUSCARORA_CDP = "75726"
TUXEDO_PARK_VILLAGE = "75803"
TUXEDO_VILLAGE = "75779"
UNADILLA_FORKS_CDP = "76023"
UNADILLA_VILLAGE = "76001"
UNION_SPRINGS_VILLAGE = "76155"
UNIONDALE_CDP = "76089"
UNIONVILLE_VILLAGE = "76210"
UNIVERSITY_GARDENS_CDP = "76287"
UNIVERSITY_AT_BUFFALO_CDP = "76280"
UPPER_BROOKVILLE_VILLAGE = "76331"
UPPER_NYACK_VILLAGE = "76386"
UPPER_RED_HOOK_CDP = "76397"
UTICA_CITY = "76540"
VAILS_GATE_CDP = "76584"
VALATIE_VILLAGE = "76617"
VALHALLA_CDP = "76639"
VALLEY_COTTAGE_CDP = "76661"
VALLEY_FALLS_VILLAGE = "76672"
VALLEY_STREAM_VILLAGE = "76705"
VAN_ETTEN_CDP = "76881"
VARNA_CDP = "76969"
VASSAR_COLLEGE_CDP = "76985"
VERNON_VILLAGE = "77112"
VERONA_CDP = "77167"
VERPLANCK_CDP = "77211"
VICTOR_VILLAGE = "77376"
VICTORY_VILLAGE = "77431"
VILLAGE_GREEN_CDP = "77513"
VILLAGE_OF_THE_BRANCH_VILLAGE = "77519"
VIOLA_CDP = "77574"
VIRGIL_CDP = "77585"
VOORHEESVILLE_VILLAGE = "77684"
WADDINGTON_VILLAGE = "77728"
WADING_RIVER_CDP = "77772"
WADSWORTH_CDP = "77783"
WAINSCOTT_CDP = "77805"
WALDEN_VILLAGE = "77849"
WALKER_VALLEY_CDP = "77948"
WALLKILL_CDP = "78003"
WALTON_PARK_CDP = "78063"
WALTON_VILLAGE = "78036"
WALWORTH_CDP = "78091"
WAMPSVILLE_VILLAGE = "78113"
WANAKAH_CDP = "78124"
WANTAGH_CDP = "78146"
WAPPINGERS_FALLS_VILLAGE = "78168"
WARRENSBURG_CDP = "78289"
WARSAW_VILLAGE = "78333"
WARWICK_VILLAGE = "78355"
WASHINGTON_HEIGHTS_CDP = "78421"
WASHINGTON_MILLS_CDP = "78454"
WASHINGTONVILLE_VILLAGE = "78465"
WASSAIC_CDP = "78476"
WATCHTOWER_CDP = "78487"
WATER_MILL_CDP = "78575"
WATERFORD_VILLAGE = "78520"
WATERLOO_VILLAGE = "78553"
WATERTOWN_CITY = "78608"
WATERVILLE_VILLAGE = "78663"
WATERVLIET_CITY = "78674"
WATKINS_GLEN_VILLAGE = "78696"
WAVERLY_VILLAGE = "78806"
WAYLAND_VILLAGE = "78850"
WEBSTER_VILLAGE = "78960"
WEBSTERS_CROSSING_CDP = "78982"
WEEDSPORT_VILLAGE = "79015"
WELLS_BRIDGE_CDP = "79070"
WELLS_CDP = "79048"
WELLSBURG_VILLAGE = "79081"
WELLSVILLE_VILLAGE = "79092"
WESLEY_HILLS_VILLAGE = "79174"
WEST_BABYLON_CDP = "79246"
WEST_BAY_SHORE_CDP = "79301"
WEST_CARTHAGE_VILLAGE = "79499"
WEST_CHAZY_CDP = "79543"
WEST_DANBY_CDP = "79697"
WEST_ELMIRA_CDP = "79785"
WEST_END_CDP = "79796"
WEST_GLENS_FALLS_CDP = "80082"
WEST_HAMPTON_DUNES_VILLAGE = "80186"
WEST_HAVERSTRAW_VILLAGE = "80203"
WEST_HEMPSTEAD_CDP = "80225"
WEST_HILLS_CDP = "80258"
WEST_HURLEY_CDP = "80291"
WEST_ISLIP_CDP = "80302"
WEST_KILL_CDP = "80324"
WEST_NYACK_CDP = "80599"
WEST_POINT_CDP = "80747"
WEST_SAND_LAKE_CDP = "80863"
WEST_SAYVILLE_CDP = "80885"
WEST_SENECA_CDP = "80907"
WEST_VALLEY_CDP = "81138"
WEST_WINFIELD_VILLAGE = "81292"
WESTBURY_VILLAGE = "79444"
WESTERNVILLE_CDP = "79895"
WESTFIELD_VILLAGE = "79939"
WESTFORD_CDP = "79961"
WESTHAMPTON_BEACH_VILLAGE = "80181"
WESTHAMPTON_CDP = "80170"
WESTMERE_CDP = "80423"
WESTMORELAND_CDP = "80522"
WESTON_MILLS_CDP = "80632"
WESTPORT_CDP = "80764"
WESTVALE_CDP = "81127"
WHEATLEY_HEIGHTS_CDP = "81419"
WHITE_LAKE_CDP_ONEIDA_COUNTY = "81644"
WHITE_LAKE_CDP_SULLIVAN_COUNTY = "81655"
WHITE_PLAINS_CITY = "81677"
WHITEHALL_VILLAGE = "81622"
WHITESBORO_VILLAGE = "81710"
WHITNEY_POINT_VILLAGE = "81831"
WILLIAMSON_CDP = "82029"
WILLIAMSVILLE_VILLAGE = "82084"
WILLISTON_PARK_VILLAGE = "82117"
WILLSBORO_CDP = "82260"
WILLSBORO_POINT_CDP = "82282"
WILMINGTON_CDP = "82304"
WILSON_VILLAGE = "82359"
WINDHAM_CDP = "82469"
WINDSOR_VILLAGE = "82524"
WINGDALE_CDP = "82579"
WINTHROP_CDP = "82612"
WITHERBEE_CDP = "82656"
WOLCOTT_VILLAGE = "82678"
WOODBOURNE_CDP = "82733"
WOODBURY_CDP = "82744"
WOODBURY_VILLAGE = "82750"
WOODMERE_CDP = "82942"
WOODRIDGE_VILLAGE = "82953"
WOODSBURGH_VILLAGE = "82986"
WOODSTOCK_CDP = "83041"
WOODSVILLE_CDP = "83063"
WORCESTER_CDP = "83118"
WURTSBORO_HILLS_CDP = "83283"
WURTSBORO_VILLAGE = "83272"
WYANDANCH_CDP = "83294"
WYNANTSKILL_CDP = "83349"
WYOMING_VILLAGE = "83371"
YAPHANK_CDP = "83426"
YONKERS_CITY = "84000"
YORK_CDP = "84011"
YORKSHIRE_CDP = "84044"
YORKTOWN_HEIGHTS_CDP = "84088"
YORKVILLE_VILLAGE = "84099"
YOUNGSTOWN_VILLAGE = "84143"
ZENA_CDP = "84187"
