# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Georgia."""


APPLING = "001"
ATKINSON = "003"
BACON = "005"
BAKER = "007"
BALDWIN = "009"
BANKS = "011"
BARROW = "013"
BARTOW = "015"
BEN_HILL = "017"
BERRIEN = "019"
BIBB = "021"
BLECKLEY = "023"
BRANTLEY = "025"
BROOKS = "027"
BRYAN = "029"
BULLOCH = "031"
BURKE = "033"
BUTTS = "035"
CALHOUN = "037"
CAMDEN = "039"
CANDLER = "043"
CARROLL = "045"
CATOOSA = "047"
CHARLTON = "049"
CHATHAM = "051"
CHATTAHOOCHEE = "053"
CHATTOOGA = "055"
CHEROKEE = "057"
CLARKE = "059"
CLAY = "061"
CLAYTON = "063"
CLINCH = "065"
COBB = "067"
COFFEE = "069"
COLQUITT = "071"
COLUMBIA = "073"
COOK = "075"
COWETA = "077"
CRAWFORD = "079"
CRISP = "081"
DADE = "083"
DAWSON = "085"
DEKALB = "089"
DECATUR = "087"
DODGE = "091"
DOOLY = "093"
DOUGHERTY = "095"
DOUGLAS = "097"
EARLY = "099"
ECHOLS = "101"
EFFINGHAM = "103"
ELBERT = "105"
EMANUEL = "107"
EVANS = "109"
FANNIN = "111"
FAYETTE = "113"
FLOYD = "115"
FORSYTH = "117"
FRANKLIN = "119"
FULTON = "121"
GILMER = "123"
GLASCOCK = "125"
GLYNN = "127"
GORDON = "129"
GRADY = "131"
GREENE = "133"
GWINNETT = "135"
HABERSHAM = "137"
HALL = "139"
HANCOCK = "141"
HARALSON = "143"
HARRIS = "145"
HART = "147"
HEARD = "149"
HENRY = "151"
HOUSTON = "153"
IRWIN = "155"
JACKSON = "157"
JASPER = "159"
JEFF_DAVIS = "161"
JEFFERSON = "163"
JENKINS = "165"
JOHNSON = "167"
JONES = "169"
LAMAR = "171"
LANIER = "173"
LAURENS = "175"
LEE = "177"
LIBERTY = "179"
LINCOLN = "181"
LONG = "183"
LOWNDES = "185"
LUMPKIN = "187"
MACON = "193"
MADISON = "195"
MARION = "197"
MCDUFFIE = "189"
MCINTOSH = "191"
MERIWETHER = "199"
MILLER = "201"
MITCHELL = "205"
MONROE = "207"
MONTGOMERY = "209"
MORGAN = "211"
MURRAY = "213"
MUSCOGEE = "215"
NEWTON = "217"
OCONEE = "219"
OGLETHORPE = "221"
PAULDING = "223"
PEACH = "225"
PICKENS = "227"
PIERCE = "229"
PIKE = "231"
POLK = "233"
PULASKI = "235"
PUTNAM = "237"
QUITMAN = "239"
RABUN = "241"
RANDOLPH = "243"
RICHMOND = "245"
ROCKDALE = "247"
SCHLEY = "249"
SCREVEN = "251"
SEMINOLE = "253"
SPALDING = "255"
STEPHENS = "257"
STEWART = "259"
SUMTER = "261"
TALBOT = "263"
TALIAFERRO = "265"
TATTNALL = "267"
TAYLOR = "269"
TELFAIR = "271"
TERRELL = "273"
THOMAS = "275"
TIFT = "277"
TOOMBS = "279"
TOWNS = "281"
TREUTLEN = "283"
TROUP = "285"
TURNER = "287"
TWIGGS = "289"
UNION = "291"
UPSON = "293"
WALKER = "295"
WALTON = "297"
WARE = "299"
WARREN = "301"
WASHINGTON = "303"
WAYNE = "305"
WEBSTER = "307"
WHEELER = "309"
WHITE = "311"
WHITFIELD = "313"
WILCOX = "315"
WILKES = "317"
WILKINSON = "319"
WORTH = "321"
