# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Iowa."""


ACKLEY_CITY = "00190"
ACKWORTH_CITY = "00235"
ADAIR_CITY = "00370"
ADEL_CITY = "00505"
AFTON_CITY = "00595"
AGENCY_CITY = "00640"
AINSWORTH_CITY = "00730"
AKRON_CITY = "00775"
ALBERT_CITY_CITY = "00865"
ALBIA_CITY = "00910"
ALBION_CITY = "00955"
ALBURNETT_CITY = "01000"
ALDEN_CITY = "01045"
ALEXANDER_CITY = "01090"
ALGONA_CITY = "01135"
ALLEMAN_CITY = "01180"
ALLERTON_CITY = "01270"
ALLISON_CITY = "01315"
ALTA_VISTA_CITY = "01540"
ALTA_CITY = "01495"
ALTON_CITY = "01585"
ALTOONA_CITY = "01630"
ALVORD_CITY = "01675"
AMANA_CDP = "01720"
AMES_CITY = "01855"
ANAMOSA_CITY = "01990"
ANDERSON_CDP = "02035"
ANDOVER_CITY = "02080"
ANDREW_CITY = "02125"
ANITA_CITY = "02260"
ANKENY_CITY = "02305"
ANTHON_CITY = "02350"
APLINGTON_CITY = "02395"
ARCADIA_CITY = "02485"
ARCHER_CITY = "02530"
AREDALE_CITY = "02620"
ARGO_CDP = "02665"
ARGYLE_CDP = "02710"
ARION_CITY = "02755"
ARISPE_CITY = "02800"
ARLINGTON_CITY = "02845"
ARMSTRONG_CITY = "02935"
ARNOLDS_PARK_CITY = "03025"
ARTHUR_CITY = "03115"
ASBURY_CITY = "03160"
ASHTON_CITY = "03295"
ASPINWALL_CITY = "03340"
ATALISSA_CITY = "03385"
ATHELSTAN_CDP = "03430"
ATKINS_CITY = "03475"
ATLANTIC_CITY = "03520"
AUBURN_CITY = "03610"
AUDUBON_CITY = "03655"
AUGUSTA_CDP = "03700"
AURELIA_CITY = "03745"
AURORA_CITY = "03835"
AVOCA_CITY = "03970"
AYRSHIRE_CITY = "04105"
BADGER_CITY = "04195"
BAGLEY_CITY = "04240"
BALDWIN_CITY = "04330"
BALLTOWN_CITY = "04375"
BANCROFT_CITY = "04420"
BANKSTON_CITY = "04510"
BARNES_CITY_CITY = "04555"
BARNUM_CITY = "04645"
BARTLETT_CDP = "04735"
BASSETT_CITY = "04780"
BATAVIA_CITY = "04825"
BATTLE_CREEK_CITY = "04870"
BAXTER_CITY = "04915"
BAYARD_CITY = "04960"
BEACON_CITY = "05050"
BEACONSFIELD_CITY = "05095"
BEAMAN_CITY = "05140"
BEAVER_CITY = "05185"
BEAVERDALE_CDP = "05200"
BEDFORD_CITY = "05365"
BELLE_PLAINE_CITY = "05590"
BELLEVUE_CITY = "05635"
BELMOND_CITY = "05680"
BENNETT_CITY = "05770"
BENTLEY_CDP = "05870"
BENTON_CITY = "05905"
BERKLEY_CITY = "06040"
BERNARD_CITY = "06085"
BERTRAM_CITY = "06175"
BETTENDORF_CITY = "06355"
BEVINGTON_CITY = "06490"
BIG_ROCK_CDP = "06535"
BIRMINGHAM_CITY = "06625"
BLAIRSBURG_CITY = "06760"
BLAIRSTOWN_CITY = "06805"
BLAKESBURG_CITY = "06850"
BLANCHARD_CITY = "06895"
BLENCOE_CITY = "06940"
BLOCKTON_CITY = "06985"
BLOOMFIELD_CITY = "07030"
BLUE_GRASS_CITY = "07075"
BODE_CITY = "07210"
BOLAN_CDP = "07255"
BONAPARTE_CITY = "07345"
BONDURANT_CITY = "07390"
BOONE_CITY = "07480"
BOUTON_CITY = "07660"
BOXHOLM_CITY = "07750"
BOYDEN_CITY = "07840"
BRADDYVILLE_CITY = "07930"
BRADFORD_CDP = "08020"
BRADGATE_CITY = "08065"
BRANDON_CITY = "08155"
BRAYTON_CITY = "08200"
BREDA_CITY = "08290"
BRIDGEWATER_CITY = "08425"
BRIGHTON_CITY = "08470"
BRISTOW_CITY = "08560"
BRITT_CITY = "08605"
BRONSON_CITY = "08650"
BROOKLYN_CITY = "08695"
BRUNSVILLE_CITY = "08875"
BUCK_GROVE_CITY = "09145"
BUCKEYE_CITY = "09100"
BUFFALO_CENTER_CITY = "09280"
BUFFALO_CITY = "09235"
BURCHINAL_CDP = "09415"
BURLINGTON_CITY = "09550"
BURR_OAK_CDP = "09640"
BURT_CITY = "09685"
BUSSEY_CITY = "09730"
CALAMUS_CITY = "09820"
CALIFORNIA_JUNCTION_CDP = "09910"
CALLENDER_CITY = "09955"
CALMAR_CITY = "10045"
CALUMET_CITY = "10090"
CAMANCHE_CITY = "10135"
CAMBRIDGE_CITY = "10225"
CANTRIL_CITY = "10450"
CARBON_CITY = "10585"
CARLISLE_CITY = "10765"
CARPENTER_CITY = "11035"
CARROLL_CITY = "11080"
CARSON_CITY = "11170"
CARTER_LAKE_CITY = "11215"
CASCADE_CITY = "11305"
CASEY_CITY = "11395"
CASTALIA_CITY = "11485"
CASTANA_CITY = "11530"
CEDAR_FALLS_CITY = "11755"
CEDAR_RAPIDS_CITY = "12000"
CENTER_JUNCTION_CDP = "12225"
CENTER_POINT_CITY = "12270"
CENTERVILLE_CITY = "12315"
CENTRAL_CITY_CITY = "12495"
CENTRALIA_CITY = "12630"
CHAPIN_CDP = "12675"
CHARITON_CITY = "12720"
CHARLES_CITY_CITY = "12765"
CHARLOTTE_CITY = "12855"
CHARTER_OAK_CITY = "12900"
CHATSWORTH_CITY = "12945"
CHELSEA_CITY = "12990"
CHEROKEE_CITY = "13080"
CHESTER_CITY = "13125"
CHILLICOTHE_CITY = "13215"
CHURDAN_CITY = "13350"
CINCINNATI_CITY = "13395"
CLARE_CITY = "13485"
CLARENCE_CITY = "13530"
CLARINDA_CITY = "13575"
CLARION_CITY = "13620"
CLARKSVILLE_CITY = "13755"
CLAYTON_CITY = "13845"
CLEAR_LAKE_CITY = "14025"
CLEARFIELD_CITY = "13980"
CLEGHORN_CITY = "14115"
CLEMONS_CITY = "14160"
CLERMONT_CITY = "14250"
CLIMBING_HILL_CDP = "14385"
CLINTON_CITY = "14430"
CLIO_CITY = "14475"
CLIVE_CITY = "14520"
CLUTIER_CITY = "14655"
COALVILLE_CDP = "14835"
COBURG_CITY = "14880"
COGGON_CITY = "14925"
COIN_CITY = "14970"
COLESBURG_CITY = "15015"
COLFAX_CITY = "15060"
COLLEGE_SPRINGS_CITY = "15105"
COLLINS_CITY = "15195"
COLO_CITY = "15240"
COLUMBUS_CITY_CITY = "15375"
COLUMBUS_JUNCTION_CITY = "15420"
COLWELL_CITY = "15465"
CONESVILLE_CITY = "15645"
CONRAD_CITY = "15825"
CONROY_CDP = "15870"
CONWAY_CITY = "15960"
COON_RAPIDS_CITY = "16050"
COPPOCK_CITY = "16140"
CORALVILLE_CITY = "16230"
CORLEY_CDP = "16320"
CORNING_CITY = "16500"
CORRECTIONVILLE_CITY = "16545"
CORWITH_CITY = "16590"
CORYDON_CITY = "16635"
COTTER_CITY = "16725"
COULTER_CITY = "16815"
COUNCIL_BLUFFS_CITY = "16860"
CRAIG_CITY = "16950"
CRAWFORDSVILLE_CITY = "17130"
CRESCENT_CITY = "17175"
CRESCO_CITY = "17220"
CRESTON_CITY = "17265"
CROMWELL_CITY = "17490"
CRYSTAL_LAKE_CITY = "17670"
CUMBERLAND_CITY = "17760"
CUMMING_CITY = "17850"
CURLEW_CITY = "17895"
CUSHING_CITY = "17940"
CYLINDER_CITY = "17985"
DAKOTA_CITY_CITY = "18075"
DALLAS_CENTER_CITY = "18255"
DANA_CITY = "18345"
DANBURY_CITY = "18390"
DANVILLE_CITY = "18435"
DAVENPORT_CITY = "19000"
DAVIS_CITY_CITY = "19090"
DAWSON_CITY = "19135"
DAYTON_CITY = "19180"
DE_SOTO_CITY = "21045"
DEWITT_CITY = "21180"
DECATUR_CITY_CITY = "19360"
DECORAH_CITY = "19405"
DEDHAM_CITY = "19450"
DEEP_RIVER_CITY = "19495"
DEFIANCE_CITY = "19585"
DELAWARE_CITY = "19630"
DELHI_CITY = "19675"
DELMAR_CITY = "19720"
DELOIT_CITY = "19765"
DELPHOS_CDP = "19810"
DELTA_CITY = "19855"
DENISON_CITY = "19945"
DENMARK_CDP = "19990"
DENVER_CITY = "20035"
DERBY_CITY = "20125"
DES_MOINES_CITY = "21000"
DEXTER_CITY = "21225"
DIAGONAL_CITY = "21270"
DIAMONDHEAD_LAKE_CDP = "21320"
DICKENS_CITY = "21360"
DIKE_CITY = "21405"
DIXON_CITY = "21540"
DOLLIVER_CITY = "21675"
DONAHUE_CITY = "21720"
DONNELLSON_CITY = "21810"
DOON_CITY = "21900"
DOUDS_CDP = "22035"
DOUGHERTY_CITY = "22080"
DOW_CITY_CITY = "22215"
DOWNEY_CDP = "22260"
DOWS_CITY = "22305"
DRAKESVILLE_CITY = "22350"
DUBUQUE_CITY = "22395"
DUMONT_CITY = "22620"
DUNCAN_CDP = "22710"
DUNCOMBE_CITY = "22755"
DUNDEE_CITY = "22800"
DUNKERTON_CITY = "22845"
DUNLAP_CITY = "22890"
DURANGO_CITY = "22935"
DURANT_CITY = "22980"
DYERSVILLE_CITY = "23115"
DYSART_CITY = "23160"
EAGLE_GROVE_CITY = "23250"
EARLHAM_CITY = "23340"
EARLING_CITY = "23385"
EARLVILLE_CITY = "23430"
EARLY_CITY = "23475"
EAST_AMANA_CDP = "23520"
EAST_PERU_CITY = "23790"
EDDYVILLE_CITY = "23970"
EDGEWOOD_CITY = "24060"
ELBERON_CITY = "24375"
ELDON_CITY = "24420"
ELDORA_CITY = "24465"
ELDRIDGE_CITY = "24600"
ELGIN_CITY = "24645"
ELK_HORN_CITY = "24780"
ELK_RUN_HEIGHTS_CITY = "24870"
ELKADER_CITY = "24690"
ELKHART_CITY = "24735"
ELKPORT_CITY = "24825"
ELLIOTT_CITY = "24915"
ELLSTON_CITY = "25005"
ELLSWORTH_CITY = "25050"
ELMA_CITY = "25095"
ELY_CITY = "25365"
EMERSON_CITY = "25500"
EMMETSBURG_CITY = "25590"
EPWORTH_CITY = "25725"
ESSEX_CITY = "25815"
ESTHERVILLE_CITY = "25860"
EVANSDALE_CITY = "25995"
EVERLY_CITY = "26175"
EXIRA_CITY = "26265"
EXLINE_CITY = "26310"
FAIRBANK_CITY = "26355"
FAIRFAX_CITY = "26400"
FAIRFIELD_CITY = "26445"
FAIRPORT_CDP = "26580"
FARLEY_CITY = "26760"
FARMERSBURG_CITY = "26850"
FARMINGTON_CITY = "26895"
FARNHAMVILLE_CITY = "26940"
FARRAGUT_CITY = "26985"
FAYETTE_CITY = "27165"
FENTON_CITY = "27210"
FERGUSON_CITY = "27255"
FERTILE_CITY = "27390"
FLORIS_CITY = "27975"
FLOYD_CITY = "28020"
FONDA_CITY = "28245"
FONTANELLE_CITY = "28290"
FOREST_CITY_CITY = "28380"
FORT_ATKINSON_CITY = "28425"
FORT_DODGE_CITY = "28515"
FORT_MADISON_CITY = "28605"
FOSTORIA_CITY = "28650"
FRANKLIN_CITY = "28740"
FRASER_CITY = "28920"
FREDERICKSBURG_CITY = "28965"
FREDERIKA_CITY = "29010"
FREDONIA_CITY = "29055"
FREMONT_CITY = "29190"
FRUITLAND_CITY = "29280"
FRYTOWN_CDP = "29325"
GALT_CITY = "29550"
GALVA_CITY = "29595"
GARBER_CITY = "29685"
GARDEN_CITY_CDP = "29730"
GARDEN_GROVE_CITY = "29775"
GARNAVILLO_CITY = "29910"
GARNER_CITY = "29955"
GARRISON_CITY = "30000"
GARWIN_CITY = "30045"
GENEVA_CITY = "30135"
GEORGE_CITY = "30225"
GIBSON_CITY = "30540"
GILBERT_CITY = "30630"
GILBERTVILLE_CITY = "30675"
GILLETT_GROVE_CITY = "30810"
GILMAN_CITY = "30900"
GILMORE_CITY_CITY = "30945"
GLADBROOK_CITY = "31035"
GLENWOOD_CITY = "31350"
GLIDDEN_CITY = "31395"
GOLDFIELD_CITY = "31530"
GOODELL_CITY = "31575"
GOOSE_LAKE_CITY = "31665"
GOWRIE_CITY = "31710"
GRAETTINGER_CITY = "31800"
GRAF_CITY = "31845"
GRAFTON_CITY = "31890"
GRAND_JUNCTION_CITY = "31980"
GRAND_MOUND_CITY = "32025"
GRAND_RIVER_CITY = "32070"
GRANDVIEW_CITY = "32115"
GRANGER_CITY = "32160"
GRANT_CITY = "32295"
GRANVILLE_CITY = "32475"
GRAVITY_CITY = "32520"
GRAY_CITY = "32565"
GREELEY_CITY = "32610"
GREEN_MOUNTAIN_CDP = "32925"
GREENE_CITY = "32745"
GREENFIELD_CITY = "32790"
GREENVILLE_CITY = "32970"
GRIMES_CITY = "33060"
GRINNELL_CITY = "33105"
GRISWOLD_CITY = "33150"
GRUNDY_CENTER_CITY = "33195"
GRUVER_CITY = "33240"
GUERNSEY_CITY = "33285"
GUTHRIE_CENTER_CITY = "33420"
GUTTENBERG_CITY = "33465"
HALBUR_CITY = "33645"
HAMBURG_CITY = "33780"
HAMILTON_CITY = "33870"
HAMPTON_CITY = "33960"
HANCOCK_CITY = "34005"
HANLONTOWN_CITY = "34185"
HANSELL_CITY = "34365"
HARCOURT_CITY = "34410"
HARDY_CITY = "34455"
HARLAN_CITY = "34500"
HARPER_CITY = "34545"
HARPERS_FERRY_CITY = "34590"
HARRIS_CITY = "34635"
HARTFORD_CITY = "34680"
HARTLEY_CITY = "34725"
HARTWICK_CITY = "34770"
HARVEY_CITY = "34860"
HASTINGS_CITY = "34995"
HAVELOCK_CITY = "35130"
HAVERHILL_CITY = "35220"
HAWARDEN_CITY = "35265"
HAWKEYE_CITY = "35310"
HAYESVILLE_CITY = "35445"
HAYFIELD_CDP = "35490"
HAZLETON_CITY = "35580"
HEDRICK_CITY = "35670"
HENDERSON_CITY = "35715"
HEPBURN_CITY = "35760"
HIAWATHA_CITY = "35940"
HIGH_AMANA_CDP = "36030"
HILLS_CITY = "36345"
HILLSBORO_CITY = "36390"
HINTON_CITY = "36480"
HOLIDAY_LAKE_CDP = "36660"
HOLLAND_CITY = "36705"
HOLSTEIN_CITY = "36840"
HOLY_CROSS_CITY = "36885"
HOMESTEAD_CDP = "36975"
HOPKINTON_CITY = "37155"
HORNICK_CITY = "37200"
HOSPERS_CITY = "37290"
HOUGHTON_CITY = "37335"
HUBBARD_CITY = "37425"
HUDSON_CITY = "37470"
HULL_CITY = "37515"
HUMBOLDT_CITY = "37560"
HUMESTON_CITY = "37605"
HUTCHINS_CDP = "37875"
HUXLEY_CITY = "37920"
IDA_GROVE_CITY = "38010"
IMOGENE_CITY = "38055"
INDEPENDENCE_CITY = "38100"
INDIANOLA_CITY = "38280"
INWOOD_CITY = "38415"
IONIA_CITY = "38460"
IOWA_CITY_CITY = "38595"
IOWA_FALLS_CITY = "38640"
IRETON_CITY = "38820"
IRVINGTON_CDP = "38955"
IRWIN_CITY = "39000"
JACKSON_JUNCTION_CITY = "39135"
JACKSONVILLE_CDP = "39180"
JAMAICA_CITY = "39225"
JANESVILLE_CITY = "39405"
JEFFERSON_CITY = "39450"
JESUP_CITY = "39585"
JEWELL_JUNCTION_CITY = "39675"
JOHNSTON_CITY = "39765"
JOICE_CITY = "39855"
JOLLEY_CITY = "39900"
KALONA_CITY = "40170"
KAMRAR_CITY = "40215"
KANAWHA_CITY = "40260"
KELLERTON_CITY = "40350"
KELLEY_CITY = "40395"
KELLOGG_CITY = "40440"
KENSETT_CITY = "40665"
KENT_CDP = "40710"
KENT_ESTATES_CDP = "40733"
KEOKUK_CITY = "40845"
KEOMAH_VILLAGE_CITY = "40890"
KEOSAUQUA_CITY = "40935"
KEOTA_CITY = "40980"
KESWICK_CITY = "41070"
KEYSTONE_CITY = "41115"
KIMBALLTON_CITY = "41295"
KINGSLEY_CITY = "41385"
KINGSTON_CDP = "41430"
KINROSS_CITY = "41475"
KIRKMAN_CITY = "41520"
KIRKVILLE_CITY = "41565"
KIRON_CITY = "41610"
KLEMME_CITY = "41655"
KNIERIM_CITY = "41790"
KNOXVILLE_CITY = "42015"
LA_MOTTE_CITY = "43050"
LA_PORTE_CITY_CITY = "43365"
LACONA_CITY = "42285"
LADORA_CITY = "42330"
LAKE_CITY_CITY = "42465"
LAKE_MILLS_CITY = "42555"
LAKE_PANORAMA_CDP = "42575"
LAKE_PARK_CITY = "42600"
LAKE_VIEW_CITY = "42690"
LAKESIDE_CITY = "42645"
LAKOTA_CITY = "42825"
LAMBS_GROVE_CITY = "42870"
LAMONI_CITY = "42960"
LAMONT_CITY = "43005"
LANESBORO_CITY = "43140"
LANSING_CITY = "43275"
LARCHWOOD_CITY = "43410"
LARRABEE_CITY = "43500"
LATIMER_CITY = "43590"
LAUREL_CITY = "43680"
LAURENS_CITY = "43725"
LAWLER_CITY = "43815"
LAWTON_CITY = "43905"
LE_CLAIRE_CITY = "44085"
LE_GRAND_CITY = "44220"
LE_MARS_CITY = "44400"
LE_ROY_CITY = "44580"
LEANDO_CDP = "43950"
LEDYARD_CITY = "44130"
LEHIGH_CITY = "44265"
LEIGHTON_CITY = "44310"
LELAND_CITY = "44355"
LENOX_CITY = "44490"
LEON_CITY = "44535"
LESTER_CITY = "44670"
LETTS_CITY = "44715"
LEWIS_CITY = "44805"
LIBERTYVILLE_CITY = "44985"
LIDDERDALE_CITY = "45030"
LIME_SPRINGS_CITY = "45165"
LINCOLN_CITY = "45255"
LINDEN_CITY = "45390"
LINEVILLE_CITY = "45435"
LINN_GROVE_CITY = "45480"
LISBON_CITY = "45615"
LISCOMB_CITY = "45660"
LITTLE_CEDAR_CDP = "45705"
LITTLE_ROCK_CITY = "45795"
LITTLE_SIOUX_CITY = "45840"
LIVERMORE_CITY = "45975"
LOCKRIDGE_CITY = "46065"
LOGAN_CITY = "46155"
LOHRVILLE_CITY = "46245"
LONE_ROCK_CITY = "46290"
LONE_TREE_CITY = "46335"
LONG_GROVE_CITY = "46425"
LORIMOR_CITY = "46515"
LOST_NATION_CITY = "46605"
LOVELAND_CDP = "46785"
LOVILIA_CITY = "46830"
LOW_MOOR_CITY = "47010"
LOWDEN_CITY = "46920"
LOWELL_CDP = "46965"
LU_VERNE_CITY = "47370"
LUANA_CITY = "47055"
LUCAS_CITY = "47100"
LUTHER_CITY = "47280"
LUXEMBURG_CITY = "47460"
LUZERNE_CITY = "47505"
LYNNVILLE_CITY = "47595"
LYTTON_CITY = "47730"
MACEDONIA_CITY = "47955"
MACKSBURG_CITY = "48180"
MADRID_CITY = "48450"
MAGNOLIA_CITY = "48495"
MAHARISHI_VEDIC_CITY_CITY = "48500"
MALCOM_CITY = "48540"
MALLARD_CITY = "48585"
MALOY_CITY = "48675"
MALVERN_CITY = "48720"
MANCHESTER_CITY = "48810"
MANILLA_CITY = "48855"
MANLY_CITY = "48900"
MANNING_CITY = "48945"
MANSON_CITY = "48990"
MAPLETON_CITY = "49170"
MAQUOKETA_CITY = "49215"
MARATHON_CITY = "49260"
MARBLE_ROCK_CITY = "49305"
MARCUS_CITY = "49350"
MARENGO_CITY = "49395"
MARION_CITY = "49485"
MARNE_CITY = "49575"
MARQUETTE_CITY = "49620"
MARSHALLTOWN_CITY = "49755"
MARTELLE_CITY = "49845"
MARTENSDALE_CITY = "49890"
MARTINSBURG_CITY = "49935"
MARYSVILLE_CITY = "50070"
MASON_CITY_CITY = "50160"
MASONVILLE_CITY = "50205"
MASSENA_CITY = "50250"
MATLOCK_CITY = "50385"
MAURICE_CITY = "50430"
MAXWELL_CITY = "50520"
MAYNARD_CITY = "50610"
MAYSVILLE_CITY = "50655"
MCCALLSBURG_CITY = "47775"
MCCAUSLAND_CITY = "47820"
MCCLELLAND_CITY = "47865"
MCGREGOR_CITY = "48000"
MCINTIRE_CITY = "48045"
MECHANICSVILLE_CITY = "50700"
MEDIAPOLIS_CITY = "50790"
MELBOURNE_CITY = "50880"
MELCHER_DALLAS_CITY = "50935"
MELROSE_CITY = "50970"
MELVIN_CITY = "51060"
MENLO_CITY = "51105"
MERIDEN_CITY = "51150"
MERRILL_CITY = "51375"
MESERVEY_CITY = "51420"
MEYER_CDP = "51510"
MIDDLE_AMANA_CDP = "51600"
MIDDLETOWN_CITY = "51735"
MILES_CITY = "52050"
MILFORD_CITY = "52095"
MILLER_CDP = "52140"
MILLERSBURG_CITY = "52230"
MILLERTON_CITY = "52275"
MILO_CITY = "52455"
MILTON_CITY = "52500"
MINBURN_CITY = "52545"
MINDEN_CITY = "52590"
MINEOLA_CDP = "52635"
MINGO_CITY = "52815"
MISSOURI_VALLEY_CITY = "52860"
MITCHELL_CITY = "52905"
MITCHELLVILLE_CITY = "52950"
MODALE_CITY = "52995"
MONA_CDP = "53085"
MONDAMIN_CITY = "53175"
MONMOUTH_CITY = "53265"
MONONA_CITY = "53310"
MONROE_CITY = "53355"
MONTEZUMA_CITY = "53490"
MONTICELLO_CITY = "53625"
MONTOUR_CITY = "53670"
MONTPELIER_CDP = "53715"
MONTROSE_CITY = "53760"
MOOAR_CDP = "53805"
MOORHEAD_CITY = "53850"
MOORLAND_CITY = "53895"
MORAVIA_CITY = "53985"
MORLEY_CITY = "54030"
MORNING_SUN_CITY = "54120"
MORRISON_CITY = "54165"
MOSCOW_CDP = "54345"
MOULTON_CITY = "54390"
MOUNT_AUBURN_CITY = "54435"
MOUNT_AYR_CITY = "54480"
MOUNT_PLEASANT_CITY = "54705"
MOUNT_STERLING_CDP = "54750"
MOUNT_UNION_CDP = "54795"
MOUNT_VERNON_CITY = "54840"
MOVILLE_CITY = "54930"
MURRAY_CITY = "55065"
MUSCATINE_CITY = "55110"
MYSTIC_CITY = "55200"
NASHUA_CITY = "55335"
NEMAHA_CITY = "55515"
NEOLA_CITY = "55560"
NEVADA_CITY = "55695"
NEW_ALBIN_CITY = "55785"
NEW_HAMPTON_CITY = "56100"
NEW_HARTFORD_CITY = "56145"
NEW_HAVEN_CDP = "56190"
NEW_LIBERTY_CITY = "56280"
NEW_LONDON_CITY = "56325"
NEW_MARKET_CITY = "56370"
NEW_PROVIDENCE_CITY = "56415"
NEW_SHARON_CITY = "56460"
NEW_VIENNA_CITY = "56550"
NEW_VIRGINIA_CITY = "56595"
NEWELL_CITY = "55965"
NEWHALL_CITY = "56055"
NEWTON_CITY = "56505"
NICHOLS_CITY = "56685"
NODAWAY_CITY = "56865"
NORA_SPRINGS_CITY = "56910"
NORTH_BUENA_VISTA_CITY = "57135"
NORTH_ENGLISH_CITY = "57225"
NORTH_LIBERTY_CITY = "57360"
NORTH_WASHINGTON_CITY = "57495"
NORTHBORO_CITY = "57045"
NORTHWOOD_CITY = "57630"
NORWALK_CITY = "57675"
NORWAY_CITY = "57720"
NUMA_CITY = "57945"
OAK_HILLS_CDP = "58048"
OAKLAND_ACRES_CITY = "58170"
OAKLAND_CITY = "58080"
OAKVILLE_CITY = "58395"
OCHEYEDAN_CITY = "58530"
ODEBOLT_CITY = "58575"
OELWEIN_CITY = "58620"
OGDEN_CITY = "58665"
OKOBOJI_CITY = "58710"
OLDS_CITY = "58890"
OLIN_CITY = "58980"
OLLIE_CITY = "59070"
ONAWA_CITY = "59115"
ONSLOW_CITY = "59250"
ORANGE_CITY_CITY = "59475"
ORCHARD_CITY = "59520"
ORIENT_CITY = "59565"
ORLEANS_CITY = "59655"
OSAGE_CITY = "59745"
OSCEOLA_CITY = "59835"
OSKALOOSA_CITY = "59925"
OSSIAN_CITY = "59970"
OSTERDOCK_CITY = "60015"
OTHO_CITY = "60105"
OTO_CITY = "60240"
OTRANTO_CDP = "60285"
OTTOSEN_CITY = "60420"
OTTUMWA_CITY = "60465"
OWASA_CITY = "60555"
OXFORD_JUNCTION_CITY = "60690"
OXFORD_CITY = "60645"
OYENS_CITY = "60780"
PACIFIC_JUNCTION_CITY = "60825"
PACKWOOD_CITY = "60915"
PALMER_CITY = "61050"
PALO_CITY = "61230"
PANAMA_CITY = "61275"
PANORA_CITY = "61320"
PANORAMA_PARK_CITY = "61365"
PARK_VIEW_CDP = "61725"
PARKERSBURG_CITY = "61590"
PARNELL_CITY = "61770"
PATON_CITY = "61815"
PATTERSON_CITY = "61860"
PAULLINA_CITY = "61905"
PELLA_CITY = "62040"
PEOSTA_CITY = "62130"
PERCIVAL_CDP = "62175"
PERRY_CITY = "62355"
PERSIA_CITY = "62445"
PETERSON_CITY = "62625"
PIERSON_CITY = "62760"
PILOT_MOUND_CITY = "62850"
PISGAH_CITY = "63075"
PLAINFIELD_CITY = "63210"
PLAINVIEW_CDP = "63300"
PLANO_CITY = "63345"
PLEASANT_HILL_CITY = "63525"
PLEASANT_PLAIN_CITY = "63615"
PLEASANTON_CITY = "63570"
PLEASANTVILLE_CITY = "63750"
PLOVER_CITY = "63840"
PLYMOUTH_CITY = "63885"
POCAHONTAS_CITY = "63975"
POLK_CITY_CITY = "64020"
POMEROY_CITY = "64065"
POPEJOY_CITY = "64110"
PORTLAND_CDP = "64155"
PORTSMOUTH_CITY = "64200"
POSTVILLE_CITY = "64290"
PRAIRIE_CITY_CITY = "64470"
PRAIRIEBURG_CITY = "64425"
PRESCOTT_CITY = "64560"
PRESTON_CITY = "64605"
PRIMGHAR_CITY = "64650"
PRINCETON_CITY = "64740"
PROMISE_CITY_CITY = "64875"
PROTIVIN_CITY = "65010"
PULASKI_CITY = "65055"
QUASQUETON_CITY = "65235"
QUIMBY_CITY = "65280"
RADCLIFFE_CITY = "65370"
RAKE_CITY = "65415"
RALSTON_CITY = "65505"
RANDALIA_CITY = "65550"
RANDALL_CITY = "65595"
RANDOLPH_CITY = "65640"
RATHBUN_CITY = "65730"
RAYMOND_CITY = "65820"
READLYN_CITY = "65910"
REASNOR_CITY = "65955"
RED_OAK_CITY = "66135"
REDDING_CITY = "66000"
REDFIELD_CITY = "66045"
REINBECK_CITY = "66315"
REMBRANDT_CITY = "66360"
REMSEN_CITY = "66405"
RENWICK_CITY = "66450"
RHODES_CITY = "66540"
RICEVILLE_CITY = "66585"
RICHLAND_CITY = "66720"
RICKARDSVILLE_CITY = "66810"
RICKETTS_CITY = "66855"
RIDGEWAY_CITY = "67035"
RINARD_CITY = "67125"
RINGSTED_CITY = "67170"
RIPPEY_CITY = "67215"
RIVER_SIOUX_CDP = "67530"
RIVERDALE_CITY = "67350"
RIVERSIDE_CITY = "67440"
RIVERTON_CITY = "67575"
ROBINS_CITY = "67800"
ROCHESTER_CDP = "67890"
ROCK_FALLS_CITY = "68025"
ROCK_RAPIDS_CITY = "68160"
ROCK_VALLEY_CITY = "68205"
ROCKFORD_CITY = "68070"
ROCKWELL_CITY_CITY = "68295"
ROCKWELL_CITY = "68250"
RODMAN_CITY = "68340"
RODNEY_CITY = "68385"
ROLAND_CITY = "68475"
ROLFE_CITY = "68520"
ROME_CITY = "68565"
ROSE_HILL_CITY = "68700"
ROSEVILLE_CDP = "68800"
ROSSIE_CITY = "68925"
ROWAN_CITY = "69015"
ROWLEY_CITY = "69060"
ROYAL_CITY = "69105"
RUDD_CITY = "69195"
RUNNELLS_CITY = "69240"
RUSSELL_CITY = "69285"
RUTHVEN_CITY = "69330"
RUTLAND_CITY = "69375"
RYAN_CITY = "69465"
SABULA_CITY = "69510"
SAC_CITY_CITY = "69645"
SAGEVILLE_CITY = "69690"
SALEM_CITY = "70230"
SALIX_CITY = "70320"
SANBORN_CITY = "70410"
SANDUSKY_CDP = "70545"
SANDYVILLE_CITY = "70590"
SAYLORVILLE_CDP = "70995"
SCARVILLE_CITY = "71040"
SCHALLER_CITY = "71085"
SCHLESWIG_CITY = "71130"
SCRANTON_CITY = "71310"
SEARSBORO_CITY = "71355"
SERGEANT_BLUFF_CITY = "71625"
SEXTON_CDP = "71715"
SEYMOUR_CITY = "71760"
SHAMBAUGH_CITY = "71895"
SHANNON_CITY_CITY = "71940"
SHARPSBURG_CITY = "72075"
SHEFFIELD_CITY = "72210"
SHELBY_CITY = "72300"
SHELDAHL_CITY = "72345"
SHELDON_CITY = "72390"
SHELL_ROCK_CITY = "72435"
SHELLSBURG_CITY = "72480"
SHENANDOAH_CITY = "72525"
SHERRILL_CITY = "72660"
SHUEYVILLE_CITY = "72840"
SIBLEY_CITY = "72975"
SIDNEY_CITY = "73065"
SIGOURNEY_CITY = "73110"
SILVER_CITY_CITY = "73155"
SIOUX_CENTER_CITY = "73290"
SIOUX_CITY_CITY = "73335"
SIOUX_RAPIDS_CITY = "73425"
SLATER_CITY = "73515"
SLOAN_CITY = "73605"
SMITHLAND_CITY = "73650"
SOLDIER_CITY = "73785"
SOLON_CITY = "73875"
SOMERS_CITY = "73920"
SOUTH_AMANA_CDP = "73965"
SOUTH_ENGLISH_CITY = "74055"
SPENCER_CITY = "74280"
SPERRY_CDP = "74325"
SPILLVILLE_CITY = "74370"
SPIRIT_LAKE_CITY = "74415"
SPRAGUEVILLE_CITY = "74460"
SPRING_HILL_CITY = "74685"
SPRINGBROOK_CITY = "74505"
SPRINGVILLE_CITY = "74775"
ST_ANSGAR_CITY = "69735"
ST_ANTHONY_CITY = "69780"
ST_BENEDICT_CDP = "69825"
ST_CHARLES_CITY = "69915"
ST_DONATUS_CITY = "69960"
ST_JOSEPH_CDP = "70005"
ST_LUCAS_CITY = "70050"
ST_MARYS_CITY = "70095"
ST_OLAF_CITY = "70140"
ST_PAUL_CITY = "70185"
STACYVILLE_CITY = "74820"
STANHOPE_CITY = "74910"
STANLEY_CITY = "74955"
STANTON_CITY = "75000"
STANWOOD_CITY = "75045"
STATE_CENTER_CITY = "75135"
STEAMBOAT_ROCK_CITY = "75180"
STOCKPORT_CITY = "75405"
STOCKTON_CITY = "75450"
STONE_CITY_CDP = "75540"
STORM_LAKE_CITY = "75630"
STORY_CITY_CITY = "75675"
STOUT_CITY = "75720"
STRATFORD_CITY = "75810"
STRAWBERRY_POINT_CITY = "75855"
STRUBLE_CITY = "75945"
STUART_CITY = "75990"
SULLY_CITY = "76035"
SUMNER_CITY = "76260"
SUN_VALLEY_LAKE_CDP = "76415"
SUPERIOR_CITY = "76440"
SUTHERLAND_CITY = "76485"
SWALEDALE_CITY = "76620"
SWAN_CITY = "76665"
SWEA_CITY_CITY = "76755"
SWEDESBURG_CDP = "76800"
SWISHER_CITY = "76890"
TABOR_CITY = "76935"
TAMA_CITY = "77115"
TEMPLETON_CITY = "77340"
TENNANT_CITY = "77430"
TERRIL_CITY = "77520"
THAYER_CITY = "77565"
THOMPSON_CITY = "77745"
THOR_CITY = "77790"
THORNBURG_CITY = "77835"
THORNTON_CITY = "77880"
THURMAN_CITY = "77970"
TIFFIN_CITY = "78060"
TINGLEY_CITY = "78195"
TIPTON_CITY = "78285"
TITONKA_CITY = "78330"
TOETERVILLE_CDP = "78465"
TOLEDO_CITY = "78510"
TORONTO_CITY = "78600"
TRAER_CITY = "78735"
TRENTON_CDP = "78780"
TREYNOR_CITY = "78825"
TRIPOLI_CITY = "78915"
TRUESDALE_CITY = "79095"
TRURO_CITY = "79140"
TURIN_CITY = "79185"
TWIN_LAKES_CDP = "79335"
UDELL_CITY = "79410"
UNDERWOOD_CITY = "79500"
UNION_CITY = "79545"
UNIONVILLE_CITY = "79680"
UNIVERSITY_HEIGHTS_CITY = "79770"
UNIVERSITY_PARK_CITY = "79815"
URBANA_CITY = "79905"
URBANDALE_CITY = "79950"
UTE_CITY = "79995"
VAIL_CITY = "80130"
VALERIA_CITY = "80175"
VAN_HORNE_CITY = "80400"
VAN_METER_CITY = "80445"
VAN_WERT_CITY = "80490"
VARINA_CITY = "80535"
VENTURA_CITY = "80580"
VICTOR_CITY = "80805"
VILLISCA_CITY = "80985"
VINCENT_CITY = "81075"
VINING_CITY = "81120"
VINTON_CITY = "81210"
VOLGA_CITY = "81345"
WADENA_CITY = "81570"
WAHPETON_CITY = "81615"
WALCOTT_CITY = "81705"
WALFORD_CITY = "81840"
WALKER_CITY = "81885"
WALL_LAKE_CITY = "82020"
WALLINGFORD_CITY = "81975"
WALNUT_CITY = "82065"
WAPELLO_CITY = "82200"
WASHBURN_CDP = "82290"
WASHINGTON_CITY = "82335"
WASHTA_CITY = "82380"
WATERLOO_CITY = "82425"
WATERVILLE_CITY = "82470"
WATKINS_CDP = "82515"
WAUCOMA_CITY = "82650"
WAUKEE_CITY = "82695"
WAUKON_CITY = "82740"
WAVERLY_CITY = "82875"
WAYLAND_CITY = "82965"
WEBB_CITY = "83010"
WEBSTER_CITY_CITY = "83145"
WEBSTER_CITY = "83055"
WELDON_CITY = "83190"
WELLMAN_CITY = "83280"
WELLSBURG_CITY = "83325"
WELTON_CITY = "83370"
WESLEY_CITY = "83415"
WEST_AMANA_CDP = "83505"
WEST_BEND_CITY = "83550"
WEST_BRANCH_CITY = "83595"
WEST_BURLINGTON_CITY = "83685"
WEST_CHESTER_CITY = "83775"
WEST_DES_MOINES_CITY = "83910"
WEST_LIBERTY_CITY = "84315"
WEST_OKOBOJI_CITY = "84450"
WEST_POINT_CITY = "84585"
WEST_UNION_CITY = "84765"
WESTFIELD_CITY = "84090"
WESTGATE_CITY = "84180"
WESTON_CDP = "84495"
WESTPHALIA_CITY = "84540"
WESTSIDE_CITY = "84630"
WESTWOOD_CITY = "84835"
WEVER_CDP = "84855"
WHAT_CHEER_CITY = "84900"
WHEATLAND_CITY = "84945"
WHITING_CITY = "85215"
WHITTEMORE_CITY = "85260"
WHITTEN_CITY = "85305"
WILLEY_CITY = "85710"
WILLIAMS_CITY = "85800"
WILLIAMSBURG_CITY = "85845"
WILLIAMSON_CITY = "85935"
WILTON_CITY = "86070"
WINDSOR_HEIGHTS_CITY = "86250"
WINFIELD_CITY = "86385"
WINTERSET_CITY = "86520"
WINTHROP_CITY = "86565"
WIOTA_CITY = "86610"
WODEN_CITY = "86700"
WOODBINE_CITY = "86835"
WOODBURN_CITY = "86880"
WOODWARD_CITY = "86970"
WOOLSTOCK_CITY = "87015"
WORTHINGTON_CITY = "87060"
WYOMING_CITY = "87240"
YALE_CITY = "87285"
YARMOUTH_CDP = "87330"
YETTER_CITY = "87375"
YORKTOWN_CITY = "87420"
ZEARING_CITY = "87555"
ZWINGLE_CITY = "87690"
