# Copyright (c) 2023 Darren Erik Vengroff
"""Metropolitan Statistical Area Micropolitan Statistical Areas."""


ABERDEEN_SD_MICRO_AREA = "10100"
ABERDEEN_WA_MICRO_AREA = "10140"
ABILENE_TX_METRO_AREA = "10180"
ADA_OK_MICRO_AREA = "10220"
ADRIAN_MI_MICRO_AREA = "10300"
AGUADILLA_ISABELA_PR_METRO_AREA = "10380"
AKRON_OH_METRO_AREA = "10420"
ALAMOGORDO_NM_MICRO_AREA = "10460"
ALBANY_GA_METRO_AREA = "10500"
ALBANY_LEBANON_OR_METRO_AREA = "10540"
ALBANY_SCHENECTADY_TROY_NY_METRO_AREA = "10580"
ALBEMARLE_NC_MICRO_AREA = "10620"
ALBERT_LEA_MN_MICRO_AREA = "10660"
ALBERTVILLE_AL_MICRO_AREA = "10700"
ALBUQUERQUE_NM_METRO_AREA = "10740"
ALEXANDER_CITY_AL_MICRO_AREA = "10760"
ALEXANDRIA_LA_METRO_AREA = "10780"
ALEXANDRIA_MN_MICRO_AREA = "10820"
ALICE_TX_MICRO_AREA = "10860"
ALLENTOWN_BETHLEHEM_EASTON_PA_NJ_METRO_AREA = "10900"
ALMA_MI_MICRO_AREA = "10940"
ALPENA_MI_MICRO_AREA = "10980"
ALTOONA_PA_METRO_AREA = "11020"
ALTUS_OK_MICRO_AREA = "11060"
AMARILLO_TX_METRO_AREA = "11100"
AMERICUS_GA_MICRO_AREA = "11140"
AMES_IA_METRO_AREA = "11180"
AMSTERDAM_NY_MICRO_AREA = "11220"
ANCHORAGE_AK_METRO_AREA = "11260"
ANDREWS_TX_MICRO_AREA = "11380"
ANGOLA_IN_MICRO_AREA = "11420"
ANN_ARBOR_MI_METRO_AREA = "11460"
ANNISTON_OXFORD_AL_METRO_AREA = "11500"
APPLETON_WI_METRO_AREA = "11540"
ARCADIA_FL_MICRO_AREA = "11580"
ARDMORE_OK_MICRO_AREA = "11620"
ARECIBO_PR_METRO_AREA = "11640"
ARKADELPHIA_AR_MICRO_AREA = "11660"
ASHEVILLE_NC_METRO_AREA = "11700"
ASHLAND_OH_MICRO_AREA = "11740"
ASHTABULA_OH_MICRO_AREA = "11780"
ASTORIA_OR_MICRO_AREA = "11820"
ATCHISON_KS_MICRO_AREA = "11860"
ATHENS_OH_MICRO_AREA = "11900"
ATHENS_TN_MICRO_AREA = "11940"
ATHENS_TX_MICRO_AREA = "11980"
ATHENS_CLARKE_COUNTY_GA_METRO_AREA = "12020"
ATLANTA_SANDY_SPRINGS_ALPHARETTA_GA_METRO_AREA = "12060"
ATLANTIC_CITY_HAMMONTON_NJ_METRO_AREA = "12100"
ATMORE_AL_MICRO_AREA = "12120"
AUBURN_IN_MICRO_AREA = "12140"
AUBURN_NY_MICRO_AREA = "12180"
AUBURN_OPELIKA_AL_METRO_AREA = "12220"
AUGUSTA_RICHMOND_COUNTY_GA_SC_METRO_AREA = "12260"
AUGUSTA_WATERVILLE_ME_MICRO_AREA = "12300"
AUSTIN_MN_MICRO_AREA = "12380"
AUSTIN_ROUND_ROCK_GEORGETOWN_TX_METRO_AREA = "12420"
BAINBRIDGE_GA_MICRO_AREA = "12460"
BAKERSFIELD_CA_METRO_AREA = "12540"
BALTIMORE_COLUMBIA_TOWSON_MD_METRO_AREA = "12580"
BANGOR_ME_METRO_AREA = "12620"
BARABOO_WI_MICRO_AREA = "12660"
BARDSTOWN_KY_MICRO_AREA = "12680"
BARNSTABLE_TOWN_MA_METRO_AREA = "12700"
BARRE_VT_MICRO_AREA = "12740"
BARTLESVILLE_OK_MICRO_AREA = "12780"
BATAVIA_NY_MICRO_AREA = "12860"
BATESVILLE_AR_MICRO_AREA = "12900"
BATON_ROUGE_LA_METRO_AREA = "12940"
BATTLE_CREEK_MI_METRO_AREA = "12980"
BAY_CITY_MI_METRO_AREA = "13020"
BAY_CITY_TX_MICRO_AREA = "13060"
BEATRICE_NE_MICRO_AREA = "13100"
BEAUMONT_PORT_ARTHUR_TX_METRO_AREA = "13140"
BEAVER_DAM_WI_MICRO_AREA = "13180"
BECKLEY_WV_METRO_AREA = "13220"
BEDFORD_IN_MICRO_AREA = "13260"
BEEVILLE_TX_MICRO_AREA = "13300"
BELLEFONTAINE_OH_MICRO_AREA = "13340"
BELLINGHAM_WA_METRO_AREA = "13380"
BEMIDJI_MN_MICRO_AREA = "13420"
BEND_OR_METRO_AREA = "13460"
BENNETTSVILLE_SC_MICRO_AREA = "13500"
BENNINGTON_VT_MICRO_AREA = "13540"
BERLIN_NH_MICRO_AREA = "13620"
BIG_RAPIDS_MI_MICRO_AREA = "13660"
BIG_SPRING_TX_MICRO_AREA = "13700"
BIG_STONE_GAP_VA_MICRO_AREA = "13720"
BILLINGS_MT_METRO_AREA = "13740"
BINGHAMTON_NY_METRO_AREA = "13780"
BIRMINGHAM_HOOVER_AL_METRO_AREA = "13820"
BISMARCK_ND_METRO_AREA = "13900"
BLACKFOOT_ID_MICRO_AREA = "13940"
BLACKSBURG_CHRISTIANSBURG_VA_METRO_AREA = "13980"
BLOOMINGTON_IL_METRO_AREA = "14010"
BLOOMINGTON_IN_METRO_AREA = "14020"
BLOOMSBURG_BERWICK_PA_METRO_AREA = "14100"
BLUEFIELD_WV_VA_MICRO_AREA = "14140"
BLUFFTON_IN_MICRO_AREA = "14160"
BLYTHEVILLE_AR_MICRO_AREA = "14180"
BOGALUSA_LA_MICRO_AREA = "14220"
BOISE_CITY_ID_METRO_AREA = "14260"
BONHAM_TX_MICRO_AREA = "14300"
BOONE_NC_MICRO_AREA = "14380"
BORGER_TX_MICRO_AREA = "14420"
BOSTON_CAMBRIDGE_NEWTON_MA_NH_METRO_AREA = "14460"
BOULDER_CO_METRO_AREA = "14500"
BOWLING_GREEN_KY_METRO_AREA = "14540"
BOZEMAN_MT_MICRO_AREA = "14580"
BRADFORD_PA_MICRO_AREA = "14620"
BRAINERD_MN_MICRO_AREA = "14660"
BRANSON_MO_MICRO_AREA = "14700"
BRECKENRIDGE_CO_MICRO_AREA = "14720"
BREMERTON_SILVERDALE_PORT_ORCHARD_WA_METRO_AREA = "14740"
BRENHAM_TX_MICRO_AREA = "14780"
BREVARD_NC_MICRO_AREA = "14820"
BRIDGEPORT_STAMFORD_NORWALK_CT_METRO_AREA = "14860"
BROOKHAVEN_MS_MICRO_AREA = "15020"
BROOKINGS_OR_MICRO_AREA = "15060"
BROOKINGS_SD_MICRO_AREA = "15100"
BROWNSVILLE_TN_MICRO_AREA = "15140"
BROWNSVILLE_HARLINGEN_TX_METRO_AREA = "15180"
BROWNWOOD_TX_MICRO_AREA = "15220"
BRUNSWICK_GA_METRO_AREA = "15260"
BUCYRUS_GALION_OH_MICRO_AREA = "15340"
BUFFALO_CHEEKTOWAGA_NY_METRO_AREA = "15380"
BURLEY_ID_MICRO_AREA = "15420"
BURLINGTON_IA_IL_MICRO_AREA = "15460"
BURLINGTON_NC_METRO_AREA = "15500"
BURLINGTON_SOUTH_BURLINGTON_VT_METRO_AREA = "15540"
BUTTE_SILVER_BOW_MT_MICRO_AREA = "15580"
CADILLAC_MI_MICRO_AREA = "15620"
CALHOUN_GA_MICRO_AREA = "15660"
CALIFORNIA_LEXINGTON_PARK_MD_METRO_AREA = "15680"
CAMBRIDGE_MD_MICRO_AREA = "15700"
CAMBRIDGE_OH_MICRO_AREA = "15740"
CAMDEN_AR_MICRO_AREA = "15780"
CAMPBELLSVILLE_KY_MICRO_AREA = "15820"
CANTON_MASSILLON_OH_METRO_AREA = "15940"
CAPE_CORAL_FORT_MYERS_FL_METRO_AREA = "15980"
CAPE_GIRARDEAU_MO_IL_METRO_AREA = "16020"
CARBONDALE_MARION_IL_METRO_AREA = "16060"
CARLSBAD_ARTESIA_NM_MICRO_AREA = "16100"
CARROLL_IA_MICRO_AREA = "16140"
CARSON_CITY_NV_METRO_AREA = "16180"
CASPER_WY_METRO_AREA = "16220"
CANON_CITY_CO_MICRO_AREA = "15860"
CEDAR_CITY_UT_MICRO_AREA = "16260"
CEDAR_RAPIDS_IA_METRO_AREA = "16300"
CEDARTOWN_GA_MICRO_AREA = "16340"
CELINA_OH_MICRO_AREA = "16380"
CENTRAL_CITY_KY_MICRO_AREA = "16420"
CENTRALIA_IL_MICRO_AREA = "16460"
CENTRALIA_WA_MICRO_AREA = "16500"
CHAMBERSBURG_WAYNESBORO_PA_METRO_AREA = "16540"
CHAMPAIGN_URBANA_IL_METRO_AREA = "16580"
CHARLESTON_WV_METRO_AREA = "16620"
CHARLESTON_MATTOON_IL_MICRO_AREA = "16660"
CHARLESTON_NORTH_CHARLESTON_SC_METRO_AREA = "16700"
CHARLOTTE_CONCORD_GASTONIA_NC_SC_METRO_AREA = "16740"
CHARLOTTESVILLE_VA_METRO_AREA = "16820"
CHATTANOOGA_TN_GA_METRO_AREA = "16860"
CHEYENNE_WY_METRO_AREA = "16940"
CHICAGO_NAPERVILLE_ELGIN_IL_IN_WI_METRO_AREA = "16980"
CHICO_CA_METRO_AREA = "17020"
CHILLICOTHE_OH_MICRO_AREA = "17060"
CINCINNATI_OH_KY_IN_METRO_AREA = "17140"
CLARKSBURG_WV_MICRO_AREA = "17220"
CLARKSDALE_MS_MICRO_AREA = "17260"
CLARKSVILLE_TN_KY_METRO_AREA = "17300"
CLEARLAKE_CA_MICRO_AREA = "17340"
CLEVELAND_MS_MICRO_AREA = "17380"
CLEVELAND_TN_METRO_AREA = "17420"
CLEVELAND_ELYRIA_OH_METRO_AREA = "17460"
CLEWISTON_FL_MICRO_AREA = "17500"
CLINTON_IA_MICRO_AREA = "17540"
CLOVIS_NM_MICRO_AREA = "17580"
COAMO_PR_MICRO_AREA = "17620"
COCO_PR_MICRO_AREA = "17640"
COEUR_DALENE_ID_METRO_AREA = "17660"
COFFEYVILLE_KS_MICRO_AREA = "17700"
COLDWATER_MI_MICRO_AREA = "17740"
COLLEGE_STATION_BRYAN_TX_METRO_AREA = "17780"
COLORADO_SPRINGS_CO_METRO_AREA = "17820"
COLUMBIA_MO_METRO_AREA = "17860"
COLUMBIA_SC_METRO_AREA = "17900"
COLUMBUS_GA_AL_METRO_AREA = "17980"
COLUMBUS_IN_METRO_AREA = "18020"
COLUMBUS_MS_MICRO_AREA = "18060"
COLUMBUS_NE_MICRO_AREA = "18100"
COLUMBUS_OH_METRO_AREA = "18140"
CONCORD_NH_MICRO_AREA = "18180"
CONNERSVILLE_IN_MICRO_AREA = "18220"
COOKEVILLE_TN_MICRO_AREA = "18260"
COOS_BAY_OR_MICRO_AREA = "18300"
CORDELE_GA_MICRO_AREA = "18380"
CORINTH_MS_MICRO_AREA = "18420"
CORNELIA_GA_MICRO_AREA = "18460"
CORNING_NY_MICRO_AREA = "18500"
CORPUS_CHRISTI_TX_METRO_AREA = "18580"
CORSICANA_TX_MICRO_AREA = "18620"
CORTLAND_NY_MICRO_AREA = "18660"
CORVALLIS_OR_METRO_AREA = "18700"
COSHOCTON_OH_MICRO_AREA = "18740"
CRAIG_CO_MICRO_AREA = "18780"
CRAWFORDSVILLE_IN_MICRO_AREA = "18820"
CRESCENT_CITY_CA_MICRO_AREA = "18860"
CRESTVIEW_FORT_WALTON_BEACH_DESTIN_FL_METRO_AREA = "18880"
CROSSVILLE_TN_MICRO_AREA = "18900"
CULLMAN_AL_MICRO_AREA = "18980"
CULLOWHEE_NC_MICRO_AREA = "19000"
CUMBERLAND_MD_WV_METRO_AREA = "19060"
DALLAS_FORT_WORTH_ARLINGTON_TX_METRO_AREA = "19100"
DALTON_GA_METRO_AREA = "19140"
DANVILLE_IL_METRO_AREA = "19180"
DANVILLE_KY_MICRO_AREA = "19220"
DANVILLE_VA_MICRO_AREA = "19260"
DAPHNE_FAIRHOPE_FOLEY_AL_METRO_AREA = "19300"
DAVENPORT_MOLINE_ROCK_ISLAND_IA_IL_METRO_AREA = "19340"
DAYTON_TN_MICRO_AREA = "19420"
DAYTON_KETTERING_OH_METRO_AREA = "19430"
DERIDDER_LA_MICRO_AREA = "19760"
DECATUR_AL_METRO_AREA = "19460"
DECATUR_IL_METRO_AREA = "19500"
DECATUR_IN_MICRO_AREA = "19540"
DEFIANCE_OH_MICRO_AREA = "19580"
DEL_RIO_TX_MICRO_AREA = "19620"
DELTONA_DAYTONA_BEACH_ORMOND_BEACH_FL_METRO_AREA = "19660"
DEMING_NM_MICRO_AREA = "19700"
DENVER_AURORA_LAKEWOOD_CO_METRO_AREA = "19740"
DES_MOINES_WEST_DES_MOINES_IA_METRO_AREA = "19780"
DETROIT_WARREN_DEARBORN_MI_METRO_AREA = "19820"
DICKINSON_ND_MICRO_AREA = "19860"
DIXON_IL_MICRO_AREA = "19940"
DODGE_CITY_KS_MICRO_AREA = "19980"
DOTHAN_AL_METRO_AREA = "20020"
DOUGLAS_GA_MICRO_AREA = "20060"
DOVER_DE_METRO_AREA = "20100"
DUBOIS_PA_MICRO_AREA = "20180"
DUBLIN_GA_MICRO_AREA = "20140"
DUBUQUE_IA_METRO_AREA = "20220"
DULUTH_MN_WI_METRO_AREA = "20260"
DUMAS_TX_MICRO_AREA = "20300"
DUNCAN_OK_MICRO_AREA = "20340"
DURANGO_CO_MICRO_AREA = "20420"
DURANT_OK_MICRO_AREA = "20460"
DURHAM_CHAPEL_HILL_NC_METRO_AREA = "20500"
DYERSBURG_TN_MICRO_AREA = "20540"
EAGLE_PASS_TX_MICRO_AREA = "20580"
EAST_STROUDSBURG_PA_METRO_AREA = "20700"
EASTON_MD_MICRO_AREA = "20660"
EAU_CLAIRE_WI_METRO_AREA = "20740"
EDWARDS_CO_MICRO_AREA = "20780"
EFFINGHAM_IL_MICRO_AREA = "20820"
EL_CAMPO_TX_MICRO_AREA = "20900"
EL_CENTRO_CA_METRO_AREA = "20940"
EL_DORADO_AR_MICRO_AREA = "20980"
EL_PASO_TX_METRO_AREA = "21340"
ELIZABETH_CITY_NC_MICRO_AREA = "21020"
ELIZABETHTOWN_FORT_KNOX_KY_METRO_AREA = "21060"
ELK_CITY_OK_MICRO_AREA = "21120"
ELKHART_GOSHEN_IN_METRO_AREA = "21140"
ELKINS_WV_MICRO_AREA = "21180"
ELKO_NV_MICRO_AREA = "21220"
ELLENSBURG_WA_MICRO_AREA = "21260"
ELMIRA_NY_METRO_AREA = "21300"
EMPORIA_KS_MICRO_AREA = "21380"
ENID_OK_METRO_AREA = "21420"
ENTERPRISE_AL_MICRO_AREA = "21460"
ERIE_PA_METRO_AREA = "21500"
ESCANABA_MI_MICRO_AREA = "21540"
ESPANOLA_NM_MICRO_AREA = "21580"
EUFAULA_AL_GA_MICRO_AREA = "21640"
EUGENE_SPRINGFIELD_OR_METRO_AREA = "21660"
EUREKA_ARCATA_CA_MICRO_AREA = "21700"
EVANSTON_WY_MICRO_AREA = "21740"
EVANSVILLE_IN_KY_METRO_AREA = "21780"
FAIRBANKS_AK_METRO_AREA = "21820"
FAIRFIELD_IA_MICRO_AREA = "21840"
FAIRMONT_MN_MICRO_AREA = "21860"
FAIRMONT_WV_MICRO_AREA = "21900"
FALLON_NV_MICRO_AREA = "21980"
FARGO_ND_MN_METRO_AREA = "22020"
FARIBAULT_NORTHFIELD_MN_MICRO_AREA = "22060"
FARMINGTON_MO_MICRO_AREA = "22100"
FARMINGTON_NM_METRO_AREA = "22140"
FAYETTEVILLE_NC_METRO_AREA = "22180"
FAYETTEVILLE_SPRINGDALE_ROGERS_AR_METRO_AREA = "22220"
FERGUS_FALLS_MN_MICRO_AREA = "22260"
FERNLEY_NV_MICRO_AREA = "22280"
FINDLAY_OH_MICRO_AREA = "22300"
FITZGERALD_GA_MICRO_AREA = "22340"
FLAGSTAFF_AZ_METRO_AREA = "22380"
FLINT_MI_METRO_AREA = "22420"
FLORENCE_SC_METRO_AREA = "22500"
FLORENCE_MUSCLE_SHOALS_AL_METRO_AREA = "22520"
FOND_DU_LAC_WI_METRO_AREA = "22540"
FOREST_CITY_NC_MICRO_AREA = "22580"
FORREST_CITY_AR_MICRO_AREA = "22620"
FORT_COLLINS_CO_METRO_AREA = "22660"
FORT_DODGE_IA_MICRO_AREA = "22700"
FORT_LEONARD_WOOD_MO_MICRO_AREA = "22780"
FORT_MADISON_KEOKUK_IA_IL_MO_MICRO_AREA = "22800"
FORT_MORGAN_CO_MICRO_AREA = "22820"
FORT_PAYNE_AL_MICRO_AREA = "22840"
FORT_POLK_SOUTH_LA_MICRO_AREA = "22860"
FORT_SMITH_AR_OK_METRO_AREA = "22900"
FORT_WAYNE_IN_METRO_AREA = "23060"
FRANKFORT_IN_MICRO_AREA = "23140"
FRANKFORT_KY_MICRO_AREA = "23180"
FREDERICKSBURG_TX_MICRO_AREA = "23240"
FREEPORT_IL_MICRO_AREA = "23300"
FREMONT_NE_MICRO_AREA = "23340"
FREMONT_OH_MICRO_AREA = "23380"
FRESNO_CA_METRO_AREA = "23420"
GADSDEN_AL_METRO_AREA = "23460"
GAFFNEY_SC_MICRO_AREA = "23500"
GAINESVILLE_FL_METRO_AREA = "23540"
GAINESVILLE_GA_METRO_AREA = "23580"
GAINESVILLE_TX_MICRO_AREA = "23620"
GALESBURG_IL_MICRO_AREA = "23660"
GALLUP_NM_MICRO_AREA = "23700"
GARDEN_CITY_KS_MICRO_AREA = "23780"
GARDNERVILLE_RANCHOS_NV_MICRO_AREA = "23820"
GEORGETOWN_SC_MICRO_AREA = "23860"
GETTYSBURG_PA_METRO_AREA = "23900"
GILLETTE_WY_MICRO_AREA = "23940"
GLASGOW_KY_MICRO_AREA = "23980"
GLENS_FALLS_NY_METRO_AREA = "24020"
GLENWOOD_SPRINGS_CO_MICRO_AREA = "24060"
GLOVERSVILLE_NY_MICRO_AREA = "24100"
GOLDSBORO_NC_METRO_AREA = "24140"
GRANBURY_TX_MICRO_AREA = "24180"
GRAND_FORKS_ND_MN_METRO_AREA = "24220"
GRAND_ISLAND_NE_METRO_AREA = "24260"
GRAND_JUNCTION_CO_METRO_AREA = "24300"
GRAND_RAPIDS_MN_MICRO_AREA = "24330"
GRAND_RAPIDS_KENTWOOD_MI_METRO_AREA = "24340"
GRANTS_PASS_OR_METRO_AREA = "24420"
GRANTS_NM_MICRO_AREA = "24380"
GREAT_BEND_KS_MICRO_AREA = "24460"
GREAT_FALLS_MT_METRO_AREA = "24500"
GREELEY_CO_METRO_AREA = "24540"
GREEN_BAY_WI_METRO_AREA = "24580"
GREENEVILLE_TN_MICRO_AREA = "24620"
GREENSBORO_HIGH_POINT_NC_METRO_AREA = "24660"
GREENSBURG_IN_MICRO_AREA = "24700"
GREENVILLE_MS_MICRO_AREA = "24740"
GREENVILLE_NC_METRO_AREA = "24780"
GREENVILLE_OH_MICRO_AREA = "24820"
GREENVILLE_ANDERSON_SC_METRO_AREA = "24860"
GREENWOOD_MS_MICRO_AREA = "24900"
GREENWOOD_SC_MICRO_AREA = "24940"
GRENADA_MS_MICRO_AREA = "24980"
GUAYAMA_PR_METRO_AREA = "25020"
GULFPORT_BILOXI_MS_METRO_AREA = "25060"
GUYMON_OK_MICRO_AREA = "25100"
HAGERSTOWN_MARTINSBURG_MD_WV_METRO_AREA = "25180"
HAILEY_ID_MICRO_AREA = "25200"
HAMMOND_LA_METRO_AREA = "25220"
HANFORD_CORCORAN_CA_METRO_AREA = "25260"
HANNIBAL_MO_MICRO_AREA = "25300"
HARRISBURG_CARLISLE_PA_METRO_AREA = "25420"
HARRISON_AR_MICRO_AREA = "25460"
HARRISONBURG_VA_METRO_AREA = "25500"
HARTFORD_EAST_HARTFORD_MIDDLETOWN_CT_METRO_AREA = "25540"
HASTINGS_NE_MICRO_AREA = "25580"
HATTIESBURG_MS_METRO_AREA = "25620"
HAYS_KS_MICRO_AREA = "25700"
HEBER_UT_MICRO_AREA = "25720"
HELENA_MT_MICRO_AREA = "25740"
HELENA_WEST_HELENA_AR_MICRO_AREA = "25760"
HENDERSON_NC_MICRO_AREA = "25780"
HEREFORD_TX_MICRO_AREA = "25820"
HERMISTON_PENDLETON_OR_MICRO_AREA = "25840"
HICKORY_LENOIR_MORGANTON_NC_METRO_AREA = "25860"
HILLSDALE_MI_MICRO_AREA = "25880"
HILO_HI_MICRO_AREA = "25900"
HILTON_HEAD_ISLAND_BLUFFTON_SC_METRO_AREA = "25940"
HINESVILLE_GA_METRO_AREA = "25980"
HOBBS_NM_MICRO_AREA = "26020"
HOLLAND_MI_MICRO_AREA = "26090"
HOMOSASSA_SPRINGS_FL_METRO_AREA = "26140"
HOOD_RIVER_OR_MICRO_AREA = "26220"
HOPE_AR_MICRO_AREA = "26260"
HOT_SPRINGS_AR_METRO_AREA = "26300"
HOUGHTON_MI_MICRO_AREA = "26340"
HOUMA_THIBODAUX_LA_METRO_AREA = "26380"
HOUSTON_THE_WOODLANDS_SUGAR_LAND_TX_METRO_AREA = "26420"
HUDSON_NY_MICRO_AREA = "26460"
HUNTINGDON_PA_MICRO_AREA = "26500"
HUNTINGTON_IN_MICRO_AREA = "26540"
HUNTINGTON_ASHLAND_WV_KY_OH_METRO_AREA = "26580"
HUNTSVILLE_AL_METRO_AREA = "26620"
HUNTSVILLE_TX_MICRO_AREA = "26660"
HURON_SD_MICRO_AREA = "26700"
HUTCHINSON_KS_MICRO_AREA = "26740"
HUTCHINSON_MN_MICRO_AREA = "26780"
IDAHO_FALLS_ID_METRO_AREA = "26820"
INDIANA_PA_MICRO_AREA = "26860"
INDIANAPOLIS_CARMEL_ANDERSON_IN_METRO_AREA = "26900"
INDIANOLA_MS_MICRO_AREA = "26940"
IOWA_CITY_IA_METRO_AREA = "26980"
IRON_MOUNTAIN_MI_WI_MICRO_AREA = "27020"
ITHACA_NY_METRO_AREA = "27060"
JACKSON_MI_METRO_AREA = "27100"
JACKSON_MS_METRO_AREA = "27140"
JACKSON_OH_MICRO_AREA = "27160"
JACKSON_TN_METRO_AREA = "27180"
JACKSON_WY_ID_MICRO_AREA = "27220"
JACKSONVILLE_FL_METRO_AREA = "27260"
JACKSONVILLE_IL_MICRO_AREA = "27300"
JACKSONVILLE_NC_METRO_AREA = "27340"
JACKSONVILLE_TX_MICRO_AREA = "27380"
JAMESTOWN_ND_MICRO_AREA = "27420"
JAMESTOWN_DUNKIRK_FREDONIA_NY_MICRO_AREA = "27460"
JANESVILLE_BELOIT_WI_METRO_AREA = "27500"
JASPER_AL_MICRO_AREA = "27530"
JASPER_IN_MICRO_AREA = "27540"
JAYUYA_PR_MICRO_AREA = "27580"
JEFFERSON_CITY_MO_METRO_AREA = "27620"
JEFFERSON_GA_MICRO_AREA = "27600"
JENNINGS_LA_MICRO_AREA = "27660"
JESUP_GA_MICRO_AREA = "27700"
JOHNSON_CITY_TN_METRO_AREA = "27740"
JOHNSTOWN_PA_METRO_AREA = "27780"
JONESBORO_AR_METRO_AREA = "27860"
JOPLIN_MO_METRO_AREA = "27900"
JUNEAU_AK_MICRO_AREA = "27940"
KAHULUI_WAILUKU_LAHAINA_HI_METRO_AREA = "27980"
KALAMAZOO_PORTAGE_MI_METRO_AREA = "28020"
KALISPELL_MT_MICRO_AREA = "28060"
KANKAKEE_IL_METRO_AREA = "28100"
KANSAS_CITY_MO_KS_METRO_AREA = "28140"
KAPAA_HI_MICRO_AREA = "28180"
KEARNEY_NE_MICRO_AREA = "28260"
KEENE_NH_MICRO_AREA = "28300"
KENDALLVILLE_IN_MICRO_AREA = "28340"
KENNETT_MO_MICRO_AREA = "28380"
KENNEWICK_RICHLAND_WA_METRO_AREA = "28420"
KERRVILLE_TX_MICRO_AREA = "28500"
KETCHIKAN_AK_MICRO_AREA = "28540"
KEY_WEST_FL_MICRO_AREA = "28580"
KILL_DEVIL_HILLS_NC_MICRO_AREA = "28620"
KILLEEN_TEMPLE_TX_METRO_AREA = "28660"
KINGSPORT_BRISTOL_TN_VA_METRO_AREA = "28700"
KINGSTON_NY_METRO_AREA = "28740"
KINGSVILLE_TX_MICRO_AREA = "28780"
KINSTON_NC_MICRO_AREA = "28820"
KIRKSVILLE_MO_MICRO_AREA = "28860"
KLAMATH_FALLS_OR_MICRO_AREA = "28900"
KNOXVILLE_TN_METRO_AREA = "28940"
KOKOMO_IN_METRO_AREA = "29020"
LA_CROSSE_ONALASKA_WI_MN_METRO_AREA = "29100"
LA_GRANDE_OR_MICRO_AREA = "29260"
LAGRANGE_GA_AL_MICRO_AREA = "29300"
LACONIA_NH_MICRO_AREA = "29060"
LAFAYETTE_LA_METRO_AREA = "29180"
LAFAYETTE_WEST_LAFAYETTE_IN_METRO_AREA = "29200"
LAKE_CHARLES_LA_METRO_AREA = "29340"
LAKE_CITY_FL_MICRO_AREA = "29380"
LAKE_HAVASU_CITY_KINGMAN_AZ_METRO_AREA = "29420"
LAKELAND_WINTER_HAVEN_FL_METRO_AREA = "29460"
LAMESA_TX_MICRO_AREA = "29500"
LANCASTER_PA_METRO_AREA = "29540"
LANSING_EAST_LANSING_MI_METRO_AREA = "29620"
LARAMIE_WY_MICRO_AREA = "29660"
LAREDO_TX_METRO_AREA = "29700"
LAS_CRUCES_NM_METRO_AREA = "29740"
LAS_VEGAS_NM_MICRO_AREA = "29780"
LAS_VEGAS_HENDERSON_PARADISE_NV_METRO_AREA = "29820"
LAUREL_MS_MICRO_AREA = "29860"
LAURINBURG_NC_MICRO_AREA = "29900"
LAWRENCE_KS_METRO_AREA = "29940"
LAWRENCEBURG_TN_MICRO_AREA = "29980"
LAWTON_OK_METRO_AREA = "30020"
LEBANON_MO_MICRO_AREA = "30060"
LEBANON_NH_VT_MICRO_AREA = "30100"
LEBANON_PA_METRO_AREA = "30140"
LEVELLAND_TX_MICRO_AREA = "30220"
LEWISBURG_PA_MICRO_AREA = "30260"
LEWISBURG_TN_MICRO_AREA = "30280"
LEWISTON_ID_WA_METRO_AREA = "30300"
LEWISTON_AUBURN_ME_METRO_AREA = "30340"
LEWISTOWN_PA_MICRO_AREA = "30380"
LEXINGTON_NE_MICRO_AREA = "30420"
LEXINGTON_FAYETTE_KY_METRO_AREA = "30460"
LIBERAL_KS_MICRO_AREA = "30580"
LIMA_OH_METRO_AREA = "30620"
LINCOLN_IL_MICRO_AREA = "30660"
LINCOLN_NE_METRO_AREA = "30700"
LITTLE_ROCK_NORTH_LITTLE_ROCK_CONWAY_AR_METRO_AREA = "30780"
LOCK_HAVEN_PA_MICRO_AREA = "30820"
LOGAN_UT_ID_METRO_AREA = "30860"
LOGANSPORT_IN_MICRO_AREA = "30900"
LONDON_KY_MICRO_AREA = "30940"
LONGVIEW_TX_METRO_AREA = "30980"
LONGVIEW_WA_METRO_AREA = "31020"
LOS_ALAMOS_NM_MICRO_AREA = "31060"
LOS_ANGELES_LONG_BEACH_ANAHEIM_CA_METRO_AREA = "31080"
LOUISVILLE_JEFFERSON_COUNTY_KY_IN_METRO_AREA = "31140"
LUBBOCK_TX_METRO_AREA = "31180"
LUDINGTON_MI_MICRO_AREA = "31220"
LUFKIN_TX_MICRO_AREA = "31260"
LUMBERTON_NC_MICRO_AREA = "31300"
LYNCHBURG_VA_METRO_AREA = "31340"
MACOMB_IL_MICRO_AREA = "31380"
MACON_BIBB_COUNTY_GA_METRO_AREA = "31420"
MADERA_CA_METRO_AREA = "31460"
MADISON_IN_MICRO_AREA = "31500"
MADISON_WI_METRO_AREA = "31540"
MADISONVILLE_KY_MICRO_AREA = "31580"
MAGNOLIA_AR_MICRO_AREA = "31620"
MALONE_NY_MICRO_AREA = "31660"
MALVERN_AR_MICRO_AREA = "31680"
MANCHESTER_NASHUA_NH_METRO_AREA = "31700"
MANHATTAN_KS_METRO_AREA = "31740"
MANITOWOC_WI_MICRO_AREA = "31820"
MANKATO_MN_METRO_AREA = "31860"
MANSFIELD_OH_METRO_AREA = "31900"
MARIETTA_OH_MICRO_AREA = "31930"
MARINETTE_WI_MI_MICRO_AREA = "31940"
MARION_IN_MICRO_AREA = "31980"
MARION_NC_MICRO_AREA = "32000"
MARION_OH_MICRO_AREA = "32020"
MARQUETTE_MI_MICRO_AREA = "32100"
MARSHALL_MN_MICRO_AREA = "32140"
MARSHALL_MO_MICRO_AREA = "32180"
MARSHALLTOWN_IA_MICRO_AREA = "32260"
MARTIN_TN_MICRO_AREA = "32280"
MARTINSVILLE_VA_MICRO_AREA = "32300"
MARYVILLE_MO_MICRO_AREA = "32340"
MASON_CITY_IA_MICRO_AREA = "32380"
MAYAGUEZ_PR_METRO_AREA = "32420"
MAYFIELD_KY_MICRO_AREA = "32460"
MAYSVILLE_KY_MICRO_AREA = "32500"
MCALESTER_OK_MICRO_AREA = "32540"
MCALLEN_EDINBURG_MISSION_TX_METRO_AREA = "32580"
MCCOMB_MS_MICRO_AREA = "32620"
MCMINNVILLE_TN_MICRO_AREA = "32660"
MCPHERSON_KS_MICRO_AREA = "32700"
MEADVILLE_PA_MICRO_AREA = "32740"
MEDFORD_OR_METRO_AREA = "32780"
MEMPHIS_TN_MS_AR_METRO_AREA = "32820"
MENOMONIE_WI_MICRO_AREA = "32860"
MERCED_CA_METRO_AREA = "32900"
MERIDIAN_MS_MICRO_AREA = "32940"
MEXICO_MO_MICRO_AREA = "33020"
MIAMI_OK_MICRO_AREA = "33060"
MIAMI_FORT_LAUDERDALE_POMPANO_BEACH_FL_METRO_AREA = "33100"
MICHIGAN_CITY_LA_PORTE_IN_METRO_AREA = "33140"
MIDDLESBOROUGH_KY_MICRO_AREA = "33180"
MIDLAND_MI_METRO_AREA = "33220"
MIDLAND_TX_METRO_AREA = "33260"
MILLEDGEVILLE_GA_MICRO_AREA = "33300"
MILWAUKEE_WAUKESHA_WI_METRO_AREA = "33340"
MINDEN_LA_MICRO_AREA = "33380"
MINERAL_WELLS_TX_MICRO_AREA = "33420"
MINNEAPOLIS_ST_PAUL_BLOOMINGTON_MN_WI_METRO_AREA = "33460"
MINOT_ND_MICRO_AREA = "33500"
MISSOULA_MT_METRO_AREA = "33540"
MITCHELL_SD_MICRO_AREA = "33580"
MOBERLY_MO_MICRO_AREA = "33620"
MOBILE_AL_METRO_AREA = "33660"
MODESTO_CA_METRO_AREA = "33700"
MONROE_LA_METRO_AREA = "33740"
MONROE_MI_METRO_AREA = "33780"
MONTGOMERY_AL_METRO_AREA = "33860"
MONTROSE_CO_MICRO_AREA = "33940"
MOREHEAD_CITY_NC_MICRO_AREA = "33980"
MORGAN_CITY_LA_MICRO_AREA = "34020"
MORGANTOWN_WV_METRO_AREA = "34060"
MORRISTOWN_TN_METRO_AREA = "34100"
MOSCOW_ID_MICRO_AREA = "34140"
MOSES_LAKE_WA_MICRO_AREA = "34180"
MOULTRIE_GA_MICRO_AREA = "34220"
MOUNT_AIRY_NC_MICRO_AREA = "34340"
MOUNT_GAY_SHAMROCK_WV_MICRO_AREA = "34350"
MOUNT_PLEASANT_MI_MICRO_AREA = "34380"
MOUNT_PLEASANT_TX_MICRO_AREA = "34420"
MOUNT_STERLING_KY_MICRO_AREA = "34460"
MOUNT_VERNON_IL_MICRO_AREA = "34500"
MOUNT_VERNON_OH_MICRO_AREA = "34540"
MOUNT_VERNON_ANACORTES_WA_METRO_AREA = "34580"
MOUNTAIN_HOME_AR_MICRO_AREA = "34260"
MOUNTAIN_HOME_ID_MICRO_AREA = "34300"
MUNCIE_IN_METRO_AREA = "34620"
MURRAY_KY_MICRO_AREA = "34660"
MUSCATINE_IA_MICRO_AREA = "34700"
MUSKEGON_MI_METRO_AREA = "34740"
MUSKOGEE_OK_MICRO_AREA = "34780"
MYRTLE_BEACH_CONWAY_NORTH_MYRTLE_BEACH_SC_NC_METRO_AREA = "34820"
NACOGDOCHES_TX_MICRO_AREA = "34860"
NAPA_CA_METRO_AREA = "34900"
NAPLES_MARCO_ISLAND_FL_METRO_AREA = "34940"
NASHVILLE_DAVIDSON_MURFREESBORO_FRANKLIN_TN_METRO_AREA = "34980"
NATCHEZ_MS_LA_MICRO_AREA = "35020"
NATCHITOCHES_LA_MICRO_AREA = "35060"
NEW_BERN_NC_METRO_AREA = "35100"
NEW_CASTLE_IN_MICRO_AREA = "35220"
NEW_CASTLE_PA_MICRO_AREA = "35260"
NEW_HAVEN_MILFORD_CT_METRO_AREA = "35300"
NEW_ORLEANS_METAIRIE_LA_METRO_AREA = "35380"
NEW_PHILADELPHIA_DOVER_OH_MICRO_AREA = "35420"
NEW_ULM_MN_MICRO_AREA = "35580"
NEW_YORK_NEWARK_JERSEY_CITY_NY_NJ_PA_METRO_AREA = "35620"
NEWBERRY_SC_MICRO_AREA = "35140"
NEWPORT_OR_MICRO_AREA = "35440"
NEWPORT_TN_MICRO_AREA = "35460"
NILES_MI_METRO_AREA = "35660"
NOGALES_AZ_MICRO_AREA = "35700"
NORFOLK_NE_MICRO_AREA = "35740"
NORTH_PLATTE_NE_MICRO_AREA = "35820"
NORTH_PORT_SARASOTA_BRADENTON_FL_METRO_AREA = "35840"
NORTH_VERNON_IN_MICRO_AREA = "35860"
NORTH_WILKESBORO_NC_MICRO_AREA = "35900"
NORWALK_OH_MICRO_AREA = "35940"
NORWICH_NEW_LONDON_CT_METRO_AREA = "35980"
OAK_HARBOR_WA_MICRO_AREA = "36020"
OCALA_FL_METRO_AREA = "36100"
OCEAN_CITY_NJ_METRO_AREA = "36140"
ODESSA_TX_METRO_AREA = "36220"
OGDEN_CLEARFIELD_UT_METRO_AREA = "36260"
OGDENSBURG_MASSENA_NY_MICRO_AREA = "36300"
OIL_CITY_PA_MICRO_AREA = "36340"
OKEECHOBEE_FL_MICRO_AREA = "36380"
OKLAHOMA_CITY_OK_METRO_AREA = "36420"
OLEAN_NY_MICRO_AREA = "36460"
OLYMPIA_LACEY_TUMWATER_WA_METRO_AREA = "36500"
OMAHA_COUNCIL_BLUFFS_NE_IA_METRO_AREA = "36540"
ONEONTA_NY_MICRO_AREA = "36580"
ONTARIO_OR_ID_MICRO_AREA = "36620"
OPELOUSAS_LA_MICRO_AREA = "36660"
ORANGEBURG_SC_MICRO_AREA = "36700"
ORLANDO_KISSIMMEE_SANFORD_FL_METRO_AREA = "36740"
OSHKOSH_NEENAH_WI_METRO_AREA = "36780"
OSKALOOSA_IA_MICRO_AREA = "36820"
OTHELLO_WA_MICRO_AREA = "36830"
OTTAWA_IL_MICRO_AREA = "36837"
OTTAWA_KS_MICRO_AREA = "36840"
OTTUMWA_IA_MICRO_AREA = "36900"
OWATONNA_MN_MICRO_AREA = "36940"
OWENSBORO_KY_METRO_AREA = "36980"
OXFORD_MS_MICRO_AREA = "37060"
OXNARD_THOUSAND_OAKS_VENTURA_CA_METRO_AREA = "37100"
OZARK_AL_MICRO_AREA = "37120"
PADUCAH_KY_IL_MICRO_AREA = "37140"
PAHRUMP_NV_MICRO_AREA = "37220"
PALATKA_FL_MICRO_AREA = "37260"
PALESTINE_TX_MICRO_AREA = "37300"
PALM_BAY_MELBOURNE_TITUSVILLE_FL_METRO_AREA = "37340"
PAMPA_TX_MICRO_AREA = "37420"
PANAMA_CITY_FL_METRO_AREA = "37460"
PARAGOULD_AR_MICRO_AREA = "37500"
PARIS_TN_MICRO_AREA = "37540"
PARIS_TX_MICRO_AREA = "37580"
PARKERSBURG_VIENNA_WV_METRO_AREA = "37620"
PARSONS_KS_MICRO_AREA = "37660"
PAYSON_AZ_MICRO_AREA = "37740"
PEARSALL_TX_MICRO_AREA = "37770"
PECOS_TX_MICRO_AREA = "37780"
PELLA_IA_MICRO_AREA = "37800"
PENSACOLA_FERRY_PASS_BRENT_FL_METRO_AREA = "37860"
PEORIA_IL_METRO_AREA = "37900"
PERU_IN_MICRO_AREA = "37940"
PHILADELPHIA_CAMDEN_WILMINGTON_PA_NJ_DE_MD_METRO_AREA = "37980"
PHOENIX_MESA_CHANDLER_AZ_METRO_AREA = "38060"
PICAYUNE_MS_MICRO_AREA = "38100"
PIERRE_SD_MICRO_AREA = "38180"
PINE_BLUFF_AR_METRO_AREA = "38220"
PINEHURST_SOUTHERN_PINES_NC_MICRO_AREA = "38240"
PITTSBURG_KS_MICRO_AREA = "38260"
PITTSBURGH_PA_METRO_AREA = "38300"
PITTSFIELD_MA_METRO_AREA = "38340"
PLAINVIEW_TX_MICRO_AREA = "38380"
PLATTEVILLE_WI_MICRO_AREA = "38420"
PLATTSBURGH_NY_MICRO_AREA = "38460"
PLYMOUTH_IN_MICRO_AREA = "38500"
POCATELLO_ID_METRO_AREA = "38540"
POINT_PLEASANT_WV_OH_MICRO_AREA = "38580"
PONCA_CITY_OK_MICRO_AREA = "38620"
PONCE_PR_METRO_AREA = "38660"
PONTIAC_IL_MICRO_AREA = "38700"
POPLAR_BLUFF_MO_MICRO_AREA = "38740"
PORT_ANGELES_WA_MICRO_AREA = "38820"
PORT_LAVACA_TX_MICRO_AREA = "38920"
PORT_ST_LUCIE_FL_METRO_AREA = "38940"
PORTALES_NM_MICRO_AREA = "38780"
PORTLAND_SOUTH_PORTLAND_ME_METRO_AREA = "38860"
PORTLAND_VANCOUVER_HILLSBORO_OR_WA_METRO_AREA = "38900"
PORTSMOUTH_OH_MICRO_AREA = "39020"
POTTSVILLE_PA_MICRO_AREA = "39060"
POUGHKEEPSIE_NEWBURGH_MIDDLETOWN_NY_METRO_AREA = "39100"
PRESCOTT_VALLEY_PRESCOTT_AZ_METRO_AREA = "39150"
PRICE_UT_MICRO_AREA = "39220"
PRINEVILLE_OR_MICRO_AREA = "39260"
PROVIDENCE_WARWICK_RI_MA_METRO_AREA = "39300"
PROVO_OREM_UT_METRO_AREA = "39340"
PUEBLO_CO_METRO_AREA = "39380"
PULLMAN_WA_MICRO_AREA = "39420"
PUNTA_GORDA_FL_METRO_AREA = "39460"
QUINCY_IL_MO_MICRO_AREA = "39500"
RACINE_WI_METRO_AREA = "39540"
RALEIGH_CARY_NC_METRO_AREA = "39580"
RAPID_CITY_SD_METRO_AREA = "39660"
RAYMONDVILLE_TX_MICRO_AREA = "39700"
READING_PA_METRO_AREA = "39740"
RED_BLUFF_CA_MICRO_AREA = "39780"
RED_WING_MN_MICRO_AREA = "39860"
REDDING_CA_METRO_AREA = "39820"
RENO_NV_METRO_AREA = "39900"
REXBURG_ID_MICRO_AREA = "39940"
RICHMOND_IN_MICRO_AREA = "39980"
RICHMOND_VA_METRO_AREA = "40060"
RICHMOND_BEREA_KY_MICRO_AREA = "40080"
RIO_GRANDE_CITY_ROMA_TX_MICRO_AREA = "40100"
RIVERSIDE_SAN_BERNARDINO_ONTARIO_CA_METRO_AREA = "40140"
RIVERTON_WY_MICRO_AREA = "40180"
ROANOKE_RAPIDS_NC_MICRO_AREA = "40260"
ROANOKE_VA_METRO_AREA = "40220"
ROCHELLE_IL_MICRO_AREA = "40300"
ROCHESTER_MN_METRO_AREA = "40340"
ROCHESTER_NY_METRO_AREA = "40380"
ROCK_SPRINGS_WY_MICRO_AREA = "40540"
ROCKFORD_IL_METRO_AREA = "40420"
ROCKINGHAM_NC_MICRO_AREA = "40460"
ROCKPORT_TX_MICRO_AREA = "40530"
ROCKY_MOUNT_NC_METRO_AREA = "40580"
ROLLA_MO_MICRO_AREA = "40620"
ROME_GA_METRO_AREA = "40660"
ROSEBURG_OR_MICRO_AREA = "40700"
ROSWELL_NM_MICRO_AREA = "40740"
RUIDOSO_NM_MICRO_AREA = "40760"
RUSSELLVILLE_AR_MICRO_AREA = "40780"
RUSTON_LA_MICRO_AREA = "40820"
RUTLAND_VT_MICRO_AREA = "40860"
SACRAMENTO_ROSEVILLE_FOLSOM_CA_METRO_AREA = "40900"
SAFFORD_AZ_MICRO_AREA = "40940"
SAGINAW_MI_METRO_AREA = "40980"
SALEM_OH_MICRO_AREA = "41400"
SALEM_OR_METRO_AREA = "41420"
SALINA_KS_MICRO_AREA = "41460"
SALINAS_CA_METRO_AREA = "41500"
SALISBURY_MD_DE_METRO_AREA = "41540"
SALT_LAKE_CITY_UT_METRO_AREA = "41620"
SAN_ANGELO_TX_METRO_AREA = "41660"
SAN_ANTONIO_NEW_BRAUNFELS_TX_METRO_AREA = "41700"
SAN_DIEGO_CHULA_VISTA_CARLSBAD_CA_METRO_AREA = "41740"
SAN_FRANCISCO_OAKLAND_BERKELEY_CA_METRO_AREA = "41860"
SAN_GERMAN_PR_METRO_AREA = "41900"
SAN_JOSE_SUNNYVALE_SANTA_CLARA_CA_METRO_AREA = "41940"
SAN_JUAN_BAYAMON_CAGUAS_PR_METRO_AREA = "41980"
SAN_LUIS_OBISPO_PASO_ROBLES_CA_METRO_AREA = "42020"
SANDPOINT_ID_MICRO_AREA = "41760"
SANDUSKY_OH_MICRO_AREA = "41780"
SANFORD_NC_MICRO_AREA = "41820"
SANTA_CRUZ_WATSONVILLE_CA_METRO_AREA = "42100"
SANTA_FE_NM_METRO_AREA = "42140"
SANTA_ISABEL_PR_MICRO_AREA = "42180"
SANTA_MARIA_SANTA_BARBARA_CA_METRO_AREA = "42200"
SANTA_ROSA_PETALUMA_CA_METRO_AREA = "42220"
SAULT_STE_MARIE_MI_MICRO_AREA = "42300"
SAVANNAH_GA_METRO_AREA = "42340"
SAYRE_PA_MICRO_AREA = "42380"
SCOTTSBLUFF_NE_MICRO_AREA = "42420"
SCOTTSBORO_AL_MICRO_AREA = "42460"
SCOTTSBURG_IN_MICRO_AREA = "42500"
SCRANTON_WILKES_BARRE_PA_METRO_AREA = "42540"
SEARCY_AR_MICRO_AREA = "42620"
SEATTLE_TACOMA_BELLEVUE_WA_METRO_AREA = "42660"
SEBASTIAN_VERO_BEACH_FL_METRO_AREA = "42680"
SEBRING_AVON_PARK_FL_METRO_AREA = "42700"
SEDALIA_MO_MICRO_AREA = "42740"
SELINSGROVE_PA_MICRO_AREA = "42780"
SELMA_AL_MICRO_AREA = "42820"
SENECA_FALLS_NY_MICRO_AREA = "42900"
SENECA_SC_MICRO_AREA = "42860"
SEVIERVILLE_TN_MICRO_AREA = "42940"
SEYMOUR_IN_MICRO_AREA = "42980"
SHAWANO_WI_MICRO_AREA = "43020"
SHAWNEE_OK_MICRO_AREA = "43060"
SHEBOYGAN_WI_METRO_AREA = "43100"
SHELBY_NC_MICRO_AREA = "43140"
SHELBYVILLE_TN_MICRO_AREA = "43180"
SHELTON_WA_MICRO_AREA = "43220"
SHERIDAN_WY_MICRO_AREA = "43260"
SHERMAN_DENISON_TX_METRO_AREA = "43300"
SHOW_LOW_AZ_MICRO_AREA = "43320"
SHREVEPORT_BOSSIER_CITY_LA_METRO_AREA = "43340"
SIDNEY_OH_MICRO_AREA = "43380"
SIERRA_VISTA_DOUGLAS_AZ_METRO_AREA = "43420"
SIKESTON_MO_MICRO_AREA = "43460"
SILVER_CITY_NM_MICRO_AREA = "43500"
SIOUX_CITY_IA_NE_SD_METRO_AREA = "43580"
SIOUX_FALLS_SD_METRO_AREA = "43620"
SNYDER_TX_MICRO_AREA = "43660"
SOMERSET_KY_MICRO_AREA = "43700"
SOMERSET_PA_MICRO_AREA = "43740"
SONORA_CA_MICRO_AREA = "43760"
SOUTH_BEND_MISHAWAKA_IN_MI_METRO_AREA = "43780"
SPARTANBURG_SC_METRO_AREA = "43900"
SPEARFISH_SD_MICRO_AREA = "43940"
SPENCER_IA_MICRO_AREA = "43980"
SPIRIT_LAKE_IA_MICRO_AREA = "44020"
SPOKANE_SPOKANE_VALLEY_WA_METRO_AREA = "44060"
SPRINGFIELD_IL_METRO_AREA = "44100"
SPRINGFIELD_MA_METRO_AREA = "44140"
SPRINGFIELD_MO_METRO_AREA = "44180"
SPRINGFIELD_OH_METRO_AREA = "44220"
ST_CLOUD_MN_METRO_AREA = "41060"
ST_GEORGE_UT_METRO_AREA = "41100"
ST_JOSEPH_MO_KS_METRO_AREA = "41140"
ST_LOUIS_MO_IL_METRO_AREA = "41180"
ST_MARYS_GA_MICRO_AREA = "41220"
ST_MARYS_PA_MICRO_AREA = "41260"
STARKVILLE_MS_MICRO_AREA = "44260"
STATE_COLLEGE_PA_METRO_AREA = "44300"
STATESBORO_GA_MICRO_AREA = "44340"
STAUNTON_VA_METRO_AREA = "44420"
STEAMBOAT_SPRINGS_CO_MICRO_AREA = "44460"
STEPHENVILLE_TX_MICRO_AREA = "44500"
STERLING_CO_MICRO_AREA = "44540"
STERLING_IL_MICRO_AREA = "44580"
STEVENS_POINT_WI_MICRO_AREA = "44620"
STILLWATER_OK_MICRO_AREA = "44660"
STOCKTON_CA_METRO_AREA = "44700"
STORM_LAKE_IA_MICRO_AREA = "44740"
STURGIS_MI_MICRO_AREA = "44780"
SULPHUR_SPRINGS_TX_MICRO_AREA = "44860"
SUMMERVILLE_GA_MICRO_AREA = "44900"
SUMTER_SC_METRO_AREA = "44940"
SUNBURY_PA_MICRO_AREA = "44980"
SUSANVILLE_CA_MICRO_AREA = "45000"
SWEETWATER_TX_MICRO_AREA = "45020"
SYRACUSE_NY_METRO_AREA = "45060"
TAHLEQUAH_OK_MICRO_AREA = "45140"
TALLADEGA_SYLACAUGA_AL_MICRO_AREA = "45180"
TALLAHASSEE_FL_METRO_AREA = "45220"
TAMPA_ST_PETERSBURG_CLEARWATER_FL_METRO_AREA = "45300"
TAOS_NM_MICRO_AREA = "45340"
TAYLORVILLE_IL_MICRO_AREA = "45380"
TERRE_HAUTE_IN_METRO_AREA = "45460"
TEXARKANA_TX_AR_METRO_AREA = "45500"
THE_DALLES_OR_MICRO_AREA = "45520"
THE_VILLAGES_FL_METRO_AREA = "45540"
THOMASTON_GA_MICRO_AREA = "45580"
THOMASVILLE_GA_MICRO_AREA = "45620"
TIFFIN_OH_MICRO_AREA = "45660"
TIFTON_GA_MICRO_AREA = "45700"
TOCCOA_GA_MICRO_AREA = "45740"
TOLEDO_OH_METRO_AREA = "45780"
TOPEKA_KS_METRO_AREA = "45820"
TORRINGTON_CT_MICRO_AREA = "45860"
TRAVERSE_CITY_MI_MICRO_AREA = "45900"
TRENTON_PRINCETON_NJ_METRO_AREA = "45940"
TROY_AL_MICRO_AREA = "45980"
TRUCKEE_GRASS_VALLEY_CA_MICRO_AREA = "46020"
TUCSON_AZ_METRO_AREA = "46060"
TULLAHOMA_MANCHESTER_TN_MICRO_AREA = "46100"
TULSA_OK_METRO_AREA = "46140"
TUPELO_MS_MICRO_AREA = "46180"
TUSCALOOSA_AL_METRO_AREA = "46220"
TWIN_FALLS_ID_METRO_AREA = "46300"
TYLER_TX_METRO_AREA = "46340"
UKIAH_CA_MICRO_AREA = "46380"
UNION_CITY_TN_MICRO_AREA = "46460"
UNION_SC_MICRO_AREA = "46420"
URBAN_HONOLULU_HI_METRO_AREA = "46520"
URBANA_OH_MICRO_AREA = "46500"
UTICA_ROME_NY_METRO_AREA = "46540"
UVALDE_TX_MICRO_AREA = "46620"
VALDOSTA_GA_METRO_AREA = "46660"
VALLEJO_CA_METRO_AREA = "46700"
VAN_WERT_OH_MICRO_AREA = "46780"
VERMILLION_SD_MICRO_AREA = "46820"
VERNAL_UT_MICRO_AREA = "46860"
VERNON_TX_MICRO_AREA = "46900"
VICKSBURG_MS_MICRO_AREA = "46980"
VICTORIA_TX_METRO_AREA = "47020"
VIDALIA_GA_MICRO_AREA = "47080"
VINCENNES_IN_MICRO_AREA = "47180"
VINELAND_BRIDGETON_NJ_METRO_AREA = "47220"
VINEYARD_HAVEN_MA_MICRO_AREA = "47240"
VIRGINIA_BEACH_NORFOLK_NEWPORT_NEWS_VA_NC_METRO_AREA = "47260"
VISALIA_CA_METRO_AREA = "47300"
WABASH_IN_MICRO_AREA = "47340"
WACO_TX_METRO_AREA = "47380"
WAHPETON_ND_MN_MICRO_AREA = "47420"
WALLA_WALLA_WA_METRO_AREA = "47460"
WAPAKONETA_OH_MICRO_AREA = "47540"
WARNER_ROBINS_GA_METRO_AREA = "47580"
WARREN_PA_MICRO_AREA = "47620"
WARRENSBURG_MO_MICRO_AREA = "47660"
WARSAW_IN_MICRO_AREA = "47700"
WASHINGTON_COURT_HOUSE_OH_MICRO_AREA = "47920"
WASHINGTON_IN_MICRO_AREA = "47780"
WASHINGTON_NC_MICRO_AREA = "47820"
WASHINGTON_ARLINGTON_ALEXANDRIA_DC_VA_MD_WV_METRO_AREA = "47900"
WATERLOO_CEDAR_FALLS_IA_METRO_AREA = "47940"
WATERTOWN_SD_MICRO_AREA = "47980"
WATERTOWN_FORT_ATKINSON_WI_MICRO_AREA = "48020"
WATERTOWN_FORT_DRUM_NY_METRO_AREA = "48060"
WAUCHULA_FL_MICRO_AREA = "48100"
WAUSAU_WESTON_WI_METRO_AREA = "48140"
WAYCROSS_GA_MICRO_AREA = "48180"
WEATHERFORD_OK_MICRO_AREA = "48220"
WEIRTON_STEUBENVILLE_WV_OH_METRO_AREA = "48260"
WENATCHEE_WA_METRO_AREA = "48300"
WEST_PLAINS_MO_MICRO_AREA = "48460"
WEST_POINT_MS_MICRO_AREA = "48500"
WHEELING_WV_OH_METRO_AREA = "48540"
WHITEWATER_WI_MICRO_AREA = "48580"
WICHITA_FALLS_TX_METRO_AREA = "48660"
WICHITA_KS_METRO_AREA = "48620"
WILLIAMSPORT_PA_METRO_AREA = "48700"
WILLISTON_ND_MICRO_AREA = "48780"
WILLMAR_MN_MICRO_AREA = "48820"
WILMINGTON_NC_METRO_AREA = "48900"
WILMINGTON_OH_MICRO_AREA = "48940"
WILSON_NC_MICRO_AREA = "48980"
WINCHESTER_VA_WV_METRO_AREA = "49020"
WINFIELD_KS_MICRO_AREA = "49060"
WINNEMUCCA_NV_MICRO_AREA = "49080"
WINONA_MN_MICRO_AREA = "49100"
WINSTON_SALEM_NC_METRO_AREA = "49180"
WISCONSIN_RAPIDS_MARSHFIELD_WI_MICRO_AREA = "49220"
WOODWARD_OK_MICRO_AREA = "49260"
WOOSTER_OH_MICRO_AREA = "49300"
WORCESTER_MA_CT_METRO_AREA = "49340"
WORTHINGTON_MN_MICRO_AREA = "49380"
YAKIMA_WA_METRO_AREA = "49420"
YANKTON_SD_MICRO_AREA = "49460"
YAUCO_PR_METRO_AREA = "49500"
YORK_HANOVER_PA_METRO_AREA = "49620"
YOUNGSTOWN_WARREN_BOARDMAN_OH_PA_METRO_AREA = "49660"
YUBA_CITY_CA_METRO_AREA = "49700"
YUMA_AZ_METRO_AREA = "49740"
ZANESVILLE_OH_MICRO_AREA = "49780"
ZAPATA_TX_MICRO_AREA = "49820"
