# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Montana."""


BEAVERHEAD = "001"
BIG_HORN = "003"
BLAINE = "005"
BROADWATER = "007"
CARBON = "009"
CARTER = "011"
CASCADE = "013"
CHOUTEAU = "015"
CUSTER = "017"
DANIELS = "019"
DAWSON = "021"
DEER_LODGE = "023"
FALLON = "025"
FERGUS = "027"
FLATHEAD = "029"
GALLATIN = "031"
GARFIELD = "033"
GLACIER = "035"
GOLDEN_VALLEY = "037"
GRANITE = "039"
HILL = "041"
JEFFERSON = "043"
JUDITH_BASIN = "045"
LAKE = "047"
LEWIS_AND_CLARK = "049"
LIBERTY = "051"
LINCOLN = "053"
MADISON = "057"
MCCONE = "055"
MEAGHER = "059"
MINERAL = "061"
MISSOULA = "063"
MUSSELSHELL = "065"
PARK = "067"
PETROLEUM = "069"
PHILLIPS = "071"
PONDERA = "073"
POWDER_RIVER = "075"
POWELL = "077"
PRAIRIE = "079"
RAVALLI = "081"
RICHLAND = "083"
ROOSEVELT = "085"
ROSEBUD = "087"
SANDERS = "089"
SHERIDAN = "091"
SILVER_BOW = "093"
STILLWATER = "095"
SWEET_GRASS = "097"
TETON = "099"
TOOLE = "101"
TREASURE = "103"
VALLEY = "105"
WHEATLAND = "107"
WIBAUX = "109"
YELLOWSTONE = "111"
