# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Alaska."""


ALEUTIANS_EAST_BOROUGH = "013"
ALEUTIANS_WEST_CENSUS_AREA = "016"
ANCHORAGE_MUNICIPALITY = "020"
BETHEL_CENSUS_AREA = "050"
BRISTOL_BAY_BOROUGH = "060"
CHUGACH_CENSUS_AREA = "063"
COPPER_RIVER_CENSUS_AREA = "066"
DENALI_BOROUGH = "068"
DILLINGHAM_CENSUS_AREA = "070"
FAIRBANKS_NORTH_STAR_BOROUGH = "090"
HAINES_BOROUGH = "100"
HOONAH_ANGOON_CENSUS_AREA = "105"
JUNEAU_CITY_AND_BOROUGH = "110"
KENAI_PENINSULA_BOROUGH = "122"
KETCHIKAN_GATEWAY_BOROUGH = "130"
KODIAK_ISLAND_BOROUGH = "150"
KUSILVAK_CENSUS_AREA = "158"
LAKE_AND_PENINSULA_BOROUGH = "164"
MATANUSKA_SUSITNA_BOROUGH = "170"
NOME_CENSUS_AREA = "180"
NORTH_SLOPE_BOROUGH = "185"
NORTHWEST_ARCTIC_BOROUGH = "188"
PETERSBURG_BOROUGH = "195"
PRINCE_OF_WALES_HYDER_CENSUS_AREA = "198"
SITKA_CITY_AND_BOROUGH = "220"
SKAGWAY_MUNICIPALITY = "230"
SOUTHEAST_FAIRBANKS_CENSUS_AREA = "240"
WRANGELL_CITY_AND_BOROUGH = "275"
YAKUTAT_CITY_AND_BOROUGH = "282"
YUKON_KOYUKUK_CENSUS_AREA = "290"
