# Copyright (c) 2023 Darren Erik Vengroff
"""Combined Statistical Areas."""


ALBANY_SCHENECTADY_NY_CSA = "104"
ALBUQUERQUE_SANTA_FE_LAS_VEGAS_NM_CSA = "106"
ALTOONA_HUNTINGDON_PA_CSA = "107"
AMARILLO_PAMPA_BORGER_TX_CSA = "108"
APPLETON_OSHKOSH_NEENAH_WI_CSA = "118"
ASHEVILLE_MARION_BREVARD_NC_CSA = "120"
ATLANTA_ATHENS_CLARKE_COUNTY_SANDY_SPRINGS_GA_AL_CSA = "122"
BEND_PRINEVILLE_OR_CSA = "140"
BIRMINGHAM_HOOVER_TALLADEGA_AL_CSA = "142"
BLOOMINGTON_BEDFORD_IN_CSA = "144"
BLOOMINGTON_PONTIAC_IL_CSA = "145"
BLOOMSBURG_BERWICK_SUNBURY_PA_CSA = "146"
BOISE_CITY_MOUNTAIN_HOME_ONTARIO_ID_OR_CSA = "147"
BOSTON_WORCESTER_PROVIDENCE_MA_RI_NH_CT_CSA = "148"
BOWLING_GREEN_GLASGOW_KY_CSA = "150"
BROWNSVILLE_HARLINGEN_RAYMONDVILLE_TX_CSA = "154"
BUFFALO_CHEEKTOWAGA_OLEAN_NY_CSA = "160"
BURLINGTON_FORT_MADISON_KEOKUK_IA_IL_MO_CSA = "161"
BURLINGTON_SOUTH_BURLINGTON_BARRE_VT_CSA = "162"
CAPE_CORAL_FORT_MYERS_NAPLES_FL_CSA = "163"
CAPE_GIRARDEAU_SIKESTON_MO_IL_CSA = "164"
CEDAR_RAPIDS_IOWA_CITY_IA_CSA = "168"
CHARLESTON_HUNTINGTON_ASHLAND_WV_OH_KY_CSA = "170"
CHARLOTTE_CONCORD_NC_SC_CSA = "172"
CHATTANOOGA_CLEVELAND_DALTON_TN_GA_CSA = "174"
CHICAGO_NAPERVILLE_IL_IN_WI_CSA = "176"
CINCINNATI_WILMINGTON_MAYSVILLE_OH_KY_IN_CSA = "178"
CLEVELAND_AKRON_CANTON_OH_CSA = "184"
CLEVELAND_INDIANOLA_MS_CSA = "185"
CLOVIS_PORTALES_NM_CSA = "188"
COLUMBIA_MOBERLY_MEXICO_MO_CSA = "190"
COLUMBIA_ORANGEBURG_NEWBERRY_SC_CSA = "192"
COLUMBUS_AUBURN_OPELIKA_GA_AL_CSA = "194"
COLUMBUS_MARION_ZANESVILLE_OH_CSA = "198"
COLUMBUS_WEST_POINT_MS_CSA = "200"
CORPUS_CHRISTI_KINGSVILLE_ALICE_TX_CSA = "204"
DALLAS_FORT_WORTH_TX_OK_CSA = "206"
DAVENPORT_MOLINE_IA_IL_CSA = "209"
DAYTON_SPRINGFIELD_KETTERING_OH_CSA = "212"
DERIDDER_FORT_POLK_SOUTH_LA_CSA = "217"
DENVER_AURORA_CO_CSA = "216"
DES_MOINES_AMES_WEST_DES_MOINES_IA_CSA = "218"
DETROIT_WARREN_ANN_ARBOR_MI_CSA = "220"
DIXON_STERLING_IL_CSA = "221"
DOTHAN_OZARK_AL_CSA = "222"
EAU_CLAIRE_MENOMONIE_WI_CSA = "232"
EDWARDS_GLENWOOD_SPRINGS_CO_CSA = "233"
EL_PASO_LAS_CRUCES_TX_NM_CSA = "238"
ELMIRA_CORNING_NY_CSA = "236"
ERIE_MEADVILLE_PA_CSA = "240"
FARGO_WAHPETON_ND_MN_CSA = "244"
FAYETTEVILLE_SANFORD_LUMBERTON_NC_CSA = "246"
FORT_WAYNE_HUNTINGTON_AUBURN_IN_CSA = "258"
FRESNO_MADERA_HANFORD_CA_CSA = "260"
GAINESVILLE_LAKE_CITY_FL_CSA = "264"
GRAND_RAPIDS_KENTWOOD_MUSKEGON_MI_CSA = "266"
GREEN_BAY_SHAWANO_WI_CSA = "267"
GREENSBORO_WINSTON_SALEM_HIGH_POINT_NC_CSA = "268"
GREENVILLE_KINSTON_WASHINGTON_NC_CSA = "272"
GREENVILLE_SPARTANBURG_ANDERSON_SC_CSA = "273"
HARRISBURG_YORK_LEBANON_PA_CSA = "276"
HARRISONBURG_STAUNTON_VA_CSA = "277"
HARTFORD_EAST_HARTFORD_CT_CSA = "278"
HATTIESBURG_LAUREL_MS_CSA = "279"
HOT_SPRINGS_MALVERN_AR_CSA = "284"
HOUSTON_THE_WOODLANDS_TX_CSA = "288"
HUNTSVILLE_DECATUR_AL_CSA = "290"
IDAHO_FALLS_REXBURG_BLACKFOOT_ID_CSA = "292"
INDIANAPOLIS_CARMEL_MUNCIE_IN_CSA = "294"
ITHACA_CORTLAND_NY_CSA = "296"
JACKSON_BROWNSVILLE_TN_CSA = "297"
JACKSON_VICKSBURG_BROOKHAVEN_MS_CSA = "298"
JACKSONVILLE_ST_MARYS_PALATKA_FL_GA_CSA = "300"
JOHNSON_CITY_KINGSPORT_BRISTOL_TN_VA_CSA = "304"
JOHNSTOWN_SOMERSET_PA_CSA = "306"
JONESBORO_PARAGOULD_AR_CSA = "308"
JOPLIN_MIAMI_MO_OK_CSA = "309"
KALAMAZOO_BATTLE_CREEK_PORTAGE_MI_CSA = "310"
KANSAS_CITY_OVERLAND_PARK_KANSAS_CITY_MO_KS_CSA = "312"
KENNEWICK_RICHLAND_WALLA_WALLA_WA_CSA = "313"
KERRVILLE_FREDERICKSBURG_TX_CSA = "314"
KNOXVILLE_MORRISTOWN_SEVIERVILLE_TN_CSA = "315"
KOKOMO_PERU_IN_CSA = "316"
LAFAYETTE_OPELOUSAS_MORGAN_CITY_LA_CSA = "318"
LAFAYETTE_WEST_LAFAYETTE_FRANKFORT_IN_CSA = "320"
LAKE_CHARLES_JENNINGS_LA_CSA = "324"
LAS_VEGAS_HENDERSON_NV_CSA = "332"
LEXINGTON_FAYETTE_RICHMOND_FRANKFORT_KY_CSA = "336"
LIMA_VAN_WERT_CELINA_OH_CSA = "338"
LINCOLN_BEATRICE_NE_CSA = "339"
LITTLE_ROCK_NORTH_LITTLE_ROCK_AR_CSA = "340"
LOS_ANGELES_LONG_BEACH_CA_CSA = "348"
LOUISVILLE_JEFFERSON_COUNTY_ELIZABETHTOWN_BARDSTOWN_KY_IN_CSA = "350"
LUBBOCK_PLAINVIEW_LEVELLAND_TX_CSA = "352"
MACON_BIBB_COUNTY_WARNER_ROBINS_GA_CSA = "356"
MADISON_JANESVILLE_BELOIT_WI_CSA = "357"
MANKATO_NEW_ULM_MN_CSA = "359"
MANSFIELD_ASHLAND_BUCYRUS_OH_CSA = "360"
MARINETTE_IRON_MOUNTAIN_WI_MI_CSA = "361"
MARTIN_UNION_CITY_TN_CSA = "362"
MAYAGUEZ_SAN_GERMAN_PR_CSA = "364"
MCALLEN_EDINBURG_TX_CSA = "365"
MEDFORD_GRANTS_PASS_OR_CSA = "366"
MEMPHIS_FORREST_CITY_TN_MS_AR_CSA = "368"
MIAMI_PORT_ST_LUCIE_FORT_LAUDERDALE_FL_CSA = "370"
MIDLAND_ODESSA_TX_CSA = "372"
MILWAUKEE_RACINE_WAUKESHA_WI_CSA = "376"
MINNEAPOLIS_ST_PAUL_MN_WI_CSA = "378"
MOBILE_DAPHNE_FAIRHOPE_AL_CSA = "380"
MONROE_RUSTON_LA_CSA = "384"
MONTGOMERY_SELMA_ALEXANDER_CITY_AL_CSA = "388"
MORGANTOWN_FAIRMONT_WV_CSA = "390"
MOSES_LAKE_OTHELLO_WA_CSA = "393"
MOUNT_PLEASANT_ALMA_MI_CSA = "394"
MYRTLE_BEACH_CONWAY_SC_NC_CSA = "396"
NASHVILLE_DAVIDSON_MURFREESBORO_TN_CSA = "400"
NEW_BERN_MOREHEAD_CITY_NC_CSA = "404"
NEW_ORLEANS_METAIRIE_HAMMOND_LA_MS_CSA = "406"
NEW_YORK_NEWARK_NY_NJ_CT_PA_CSA = "408"
NORTH_PORT_SARASOTA_FL_CSA = "412"
OKLAHOMA_CITY_SHAWNEE_OK_CSA = "416"
OMAHA_COUNCIL_BLUFFS_FREMONT_NE_IA_CSA = "420"
ORLANDO_LAKELAND_DELTONA_FL_CSA = "422"
PADUCAH_MAYFIELD_KY_IL_CSA = "424"
PARKERSBURG_MARIETTA_VIENNA_WV_OH_CSA = "425"
PENSACOLA_FERRY_PASS_FL_AL_CSA = "426"
PHILADELPHIA_READING_CAMDEN_PA_NJ_DE_MD_CSA = "428"
PHOENIX_MESA_AZ_CSA = "429"
PITTSBURGH_NEW_CASTLE_WEIRTON_PA_OH_WV_CSA = "430"
PONCE_YAUCO_COAMO_PR_CSA = "434"
PORTLAND_LEWISTON_SOUTH_PORTLAND_ME_CSA = "438"
PORTLAND_VANCOUVER_SALEM_OR_WA_CSA = "440"
PUEBLO_CANON_CITY_CO_CSA = "444"
PULLMAN_MOSCOW_WA_ID_CSA = "446"
QUINCY_HANNIBAL_IL_MO_CSA = "448"
RALEIGH_DURHAM_CARY_NC_CSA = "450"
RAPID_CITY_SPEARFISH_SD_CSA = "452"
REDDING_RED_BLUFF_CA_CSA = "454"
RENO_CARSON_CITY_FERNLEY_NV_CSA = "456"
RICHMOND_CONNERSVILLE_IN_CSA = "458"
ROCHESTER_AUSTIN_MN_CSA = "462"
ROCHESTER_BATAVIA_SENECA_FALLS_NY_CSA = "464"
ROCKFORD_FREEPORT_ROCHELLE_IL_CSA = "466"
ROCKY_MOUNT_WILSON_ROANOKE_RAPIDS_NC_CSA = "468"
SACRAMENTO_ROSEVILLE_CA_CSA = "472"
SAGINAW_MIDLAND_BAY_CITY_MI_CSA = "474"
SALISBURY_CAMBRIDGE_MD_DE_CSA = "480"
SALT_LAKE_CITY_PROVO_OREM_UT_CSA = "482"
SAN_ANTONIO_NEW_BRAUNFELS_PEARSALL_TX_CSA = "484"
SAN_JOSE_SAN_FRANCISCO_OAKLAND_CA_CSA = "488"
SAN_JUAN_BAYAMON_PR_CSA = "490"
SAVANNAH_HINESVILLE_STATESBORO_GA_CSA = "496"
SCOTTSBORO_FORT_PAYNE_AL_CSA = "497"
SEATTLE_TACOMA_WA_CSA = "500"
SHREVEPORT_BOSSIER_CITY_MINDEN_LA_CSA = "508"
SOUTH_BEND_ELKHART_MISHAWAKA_IN_MI_CSA = "515"
SPENCER_SPIRIT_LAKE_IA_CSA = "517"
SPOKANE_SPOKANE_VALLEY_COEUR_DALENE_WA_ID_CSA = "518"
SPRINGFIELD_JACKSONVILLE_LINCOLN_IL_CSA = "522"
ST_LOUIS_ST_CHARLES_FARMINGTON_MO_IL_CSA = "476"
STATE_COLLEGE_DUBOIS_PA_CSA = "524"
STEAMBOAT_SPRINGS_CRAIG_CO_CSA = "525"
SYRACUSE_AUBURN_NY_CSA = "532"
TOLEDO_FINDLAY_TIFFIN_OH_CSA = "534"
TUCSON_NOGALES_AZ_CSA = "536"
TULSA_MUSKOGEE_BARTLESVILLE_OK_CSA = "538"
TUPELO_CORINTH_MS_CSA = "539"
TYLER_JACKSONVILLE_TX_CSA = "540"
VICTORIA_PORT_LAVACA_TX_CSA = "544"
VIRGINIA_BEACH_NORFOLK_VA_NC_CSA = "545"
WASHINGTON_BALTIMORE_ARLINGTON_DC_MD_VA_WV_PA_CSA = "548"
WAUSAU_STEVENS_POINT_WISCONSIN_RAPIDS_WI_CSA = "554"
WICHITA_WINFIELD_KS_CSA = "556"
WILLIAMSPORT_LOCK_HAVEN_PA_CSA = "558"
YOUNGSTOWN_WARREN_OH_PA_CSA = "566"
