# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Oklahoma."""


ADAIR = "001"
ALFALFA = "003"
ATOKA = "005"
BEAVER = "007"
BECKHAM = "009"
BLAINE = "011"
BRYAN = "013"
CADDO = "015"
CANADIAN = "017"
CARTER = "019"
CHEROKEE = "021"
CHOCTAW = "023"
CIMARRON = "025"
CLEVELAND = "027"
COAL = "029"
COMANCHE = "031"
COTTON = "033"
CRAIG = "035"
CREEK = "037"
CUSTER = "039"
DELAWARE = "041"
DEWEY = "043"
ELLIS = "045"
GARFIELD = "047"
GARVIN = "049"
GRADY = "051"
GRANT = "053"
GREER = "055"
HARMON = "057"
HARPER = "059"
HASKELL = "061"
HUGHES = "063"
JACKSON = "065"
JEFFERSON = "067"
JOHNSTON = "069"
KAY = "071"
KINGFISHER = "073"
KIOWA = "075"
LATIMER = "077"
LE_FLORE = "079"
LINCOLN = "081"
LOGAN = "083"
LOVE = "085"
MAJOR = "093"
MARSHALL = "095"
MAYES = "097"
MCCLAIN = "087"
MCCURTAIN = "089"
MCINTOSH = "091"
MURRAY = "099"
MUSKOGEE = "101"
NOBLE = "103"
NOWATA = "105"
OKFUSKEE = "107"
OKLAHOMA = "109"
OKMULGEE = "111"
OSAGE = "113"
OTTAWA = "115"
PAWNEE = "117"
PAYNE = "119"
PITTSBURG = "121"
PONTOTOC = "123"
POTTAWATOMIE = "125"
PUSHMATAHA = "127"
ROGER_MILLS = "129"
ROGERS = "131"
SEMINOLE = "133"
SEQUOYAH = "135"
STEPHENS = "137"
TEXAS = "139"
TILLMAN = "141"
TULSA = "143"
WAGONER = "145"
WASHINGTON = "147"
WASHITA = "149"
WOODS = "151"
WOODWARD = "153"
