# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Arizona."""


APACHE = "001"
COCHISE = "003"
COCONINO = "005"
GILA = "007"
GRAHAM = "009"
GREENLEE = "011"
LA_PAZ = "012"
MARICOPA = "013"
MOHAVE = "015"
NAVAJO = "017"
PIMA = "019"
PINAL = "021"
SANTA_CRUZ = "023"
YAVAPAI = "025"
YUMA = "027"
