# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Arizona."""


AGUILA_CDP = "00730"
AJO_CDP = "00870"
AK_CHIN_CDP = "00940"
AK_CHIN_VILLAGE_CDP = "01090"
ALAMO_LAKE_CDP = "01170"
ALI_CHUK_CDP = "01560"
ALI_CHUKSON_CDP = "01570"
ALI_MOLINA_CDP = "01620"
ALPINE_CDP = "01920"
AMADO_CDP = "01990"
ANEGAM_CDP = "02270"
ANTARES_CDP = "02410"
ANTHEM_CDP = "02430"
APACHE_JUNCTION_CITY = "02830"
ARIVACA_CDP = "03320"
ARIVACA_JUNCTION_CDP = "03380"
ARIZONA_CITY_CDP = "03530"
ARIZONA_VILLAGE_CDP = "03915"
ARLINGTON_CDP = "04020"
ASH_FORK_CDP = "04440"
AVENUE_B_AND_C_CDP = "04710"
AVONDALE_CITY = "04720"
AVRA_VALLEY_CDP = "04880"
AZTEC_CDP = "04930"
BAGDAD_CDP = "05140"
BEAR_FLAT_CDP = "05450"
BEAVER_DAM_CDP = "05490"
BEAVER_VALLEY_CDP = "05495"
BELLEMONT_CDP = "05700"
BENSON_CITY = "05770"
BEYERVILLE_CDP = "05970"
BISBEE_CITY = "06260"
BITTER_SPRINGS_CDP = "06470"
BLACK_CANYON_CITY_CDP = "06610"
BLACKWATER_CDP = "06820"
BLUE_RIDGE_CDP = "06997"
BLUEWATER_CDP = "07025"
BOUSE_CDP = "07310"
BOWIE_CDP = "07380"
BRENDA_CDP = "07590"
BRYCE_CDP = "07915"
BUCKEYE_CITY = "07940"
BUCKSHOT_CDP = "08020"
BULLHEAD_CITY_CITY = "08220"
BURNSIDE_CDP = "08535"
BYLAS_CDP = "08710"
CACTUS_FLATS_CDP = "08920"
CACTUS_FOREST_CDP = "08990"
CAMERON_CDP = "09340"
CAMP_VERDE_TOWN = "09690"
CAMPO_BONITO_CDP = "09580"
CANE_BEDS_CDP = "09900"
CANYON_DAY_CDP = "10040"
CAREFREE_TOWN = "10180"
CARRIZO_CDP = "10320"
CASA_BLANCA_CDP = "10460"
CASA_GRANDE_CITY = "10530"
CASAS_ADOBES_CDP = "10670"
CATALINA_CDP = "11160"
CATALINA_FOOTHILLS_CDP = "11230"
CAVE_CREEK_TOWN = "11300"
CEDAR_CREEK_CDP = "11370"
CENTENNIAL_PARK_CDP = "11500"
CENTRAL_CDP = "11580"
CENTRAL_HEIGHTS_MIDLAND_CITY_CDP = "11720"
CHANDLER_CITY = "12000"
CHARCO_CDP = "12150"
CHIAWULI_TAK_CDP = "12560"
CHILCHINBITO_CDP = "12630"
CHINLE_CDP = "12770"
CHINO_VALLEY_TOWN = "12840"
CHLORIDE_CDP = "12910"
CHRISTOPHER_CREEK_CDP = "13140"
CHUICHU_CDP = "13190"
CIBECUE_CDP = "13400"
CIBOLA_CDP = "13470"
CIENEGA_SPRINGS_CDP = "13540"
CIRCLE_CITY_CDP = "13610"
CITRUS_PARK_CDP = "13820"
CLACKS_CANYON_CDP = "13850"
CLARKDALE_TOWN = "13890"
CLAY_SPRINGS_CDP = "14030"
CLAYPOOL_CDP = "13960"
CLIFTON_TOWN = "14380"
COLORADO_CITY_TOWN = "14870"
COMOBABI_CDP = "15080"
CONCHO_CDP = "15150"
CONGRESS_CDP = "15220"
COOLIDGE_CITY = "15500"
COPPER_HILL_CDP = "15600"
CORDES_LAKES_CDP = "15765"
CORNFIELDS_CDP = "15850"
CORNVILLE_CDP = "15920"
CORONA_DE_TUCSON_CDP = "16030"
COTTONWOOD_CDP = "16360"
COTTONWOOD_CITY = "16410"
COWLIC_CDP = "16830"
CROZIER_CDP = "17460"
CRYSTAL_BEACH_CDP = "17500"
CUTTER_CDP = "17810"
DATELAND_CDP = "18160"
DEER_CREEK_CDP = "18448"
DEL_MUERTO_CDP = "18490"
DENNEHOTSO_CDP = "18580"
DESERT_HILLS_CDP = "18740"
DEWEY_HUMBOLDT_TOWN = "19145"
DILKON_CDP = "19280"
DOLAN_SPRINGS_CDP = "19630"
DONEY_PARK_CDP = "19740"
DONOVAN_ESTATES_CDP = "19790"
DOUGLAS_CITY = "20050"
DRAGOON_CDP = "20330"
DREXEL_HEIGHTS_CDP = "20540"
DRIPPING_SPRINGS_CDP = "20560"
DRYSDALE_CDP = "20570"
DUDLEYVILLE_CDP = "20680"
DUNCAN_TOWN = "20750"
EAGAR_TOWN = "20960"
EAST_FORK_CDP = "21310"
EAST_GLOBE_CDP = "21410"
EAST_VERDE_ESTATES_CDP = "21545"
EHRENBERG_CDP = "21800"
EL_CAPITAN_CDP = "21900"
EL_MIRAGE_CITY = "22220"
EL_PRADO_ESTATES_CDP = "22400"
ELEPHANT_HEAD_CDP = "21980"
ELFRIDA_CDP = "22080"
ELGIN_CDP = "22150"
ELOY_CITY = "22360"
FIRST_MESA_CDP = "23512"
FLAGSTAFF_CITY = "23620"
FLORENCE_TOWN = "23760"
FLOWING_SPRINGS_CDP = "23955"
FLOWING_WELLS_CDP = "23960"
FOREST_LAKES_CDP = "24100"
FORT_APACHE_CDP = "24250"
FORT_DEFIANCE_CDP = "24460"
FORT_MOHAVE_CDP = "24895"
FORT_THOMAS_CDP = "24950"
FORT_VALLEY_CDP = "25045"
FORTUNA_FOOTHILLS_CDP = "25030"
FOUNTAIN_HILLS_TOWN = "25300"
FRANKLIN_CDP = "25650"
FREDONIA_TOWN = "25720"
FREEDOM_ACRES_CDP = "25735"
GADSDEN_CDP = "26070"
GANADO_CDP = "26210"
GERONIMO_ESTATES_CDP = "26780"
GILA_BEND_TOWN = "27050"
GILA_CROSSING_CDP = "27260"
GILBERT_TOWN = "27400"
GISELA_CDP = "27540"
GLENDALE_CITY = "27820"
GLOBE_CITY = "28030"
GOLD_CANYON_CDP = "28140"
GOLDEN_SHORES_CDP = "28190"
GOLDEN_VALLEY_CDP = "28195"
GOODYEAR_VILLAGE_CDP = "28465"
GOODYEAR_CITY = "28380"
GRAND_CANYON_VILLAGE_CDP = "28981"
GRAND_CANYON_WEST_CDP = "28985"
GREASEWOOD_CDP = "29430"
GREEN_VALLEY_CDP = "29710"
GREENEHAVEN_CDP = "29603"
GREER_CDP = "29850"
GU_OIDAK_CDP = "30550"
GUADALUPE_TOWN = "30270"
HACKBERRY_CDP = "30830"
HAIGLER_CREEK_CDP = "30840"
HAIVANA_NAKYA_CDP = "30850"
HARD_ROCK_CDP = "31182"
HAYDEN_TOWN = "32020"
HEBER_OVERGAARD_CDP = "32310"
HOLBROOK_CITY = "33280"
HONDAH_CDP = "33440"
HOTEVILLA_BACAVI_CDP = "33945"
HOUCK_CDP = "33980"
HUACHUCA_CITY_TOWN = "34120"
HUNTER_CREEK_CDP = "34700"
ICEHOUSE_CANYON_CDP = "34980"
INDIAN_WELLS_CDP = "35310"
J_SIX_RANCHETTES_CDP = "36440"
JAKES_CORNER_CDP = "36010"
JEDDITO_CDP = "36150"
JEROME_TOWN = "36290"
JOSEPH_CITY_CDP = "36430"
KACHINA_VILLAGE_CDP = "36475"
KAIBAB_CDP = "36500"
KAIBAB_ESTATES_WEST_CDP = "36535"
KAIBITO_CDP = "36640"
KAKA_CDP = "36780"
KATHERINE_CDP = "36920"
KAYENTA_CDP = "36990"
KEAMS_CANYON_CDP = "37130"
KEARNY_TOWN = "37200"
KINGMAN_CITY = "37620"
KINO_SPRINGS_CDP = "37935"
KLAGETOH_CDP = "38250"
KLEINDALE_CDP = "38290"
KO_VAYA_CDP = "38950"
KOHATK_CDP = "38530"
KOHLS_RANCH_CDP = "38600"
KOMATKE_CDP = "38655"
KYKOTSMOVI_VILLAGE_CDP = "39100"
LA_PAZ_VALLEY_CDP = "40160"
LAKE_HAVASU_CITY_CITY = "39370"
LAKE_MONTEZUMA_CDP = "39720"
LAKE_OF_THE_WOODS_CDP = "39790"
LAZY_Y_U_CDP = "40400"
LECHEE_CDP = "40415"
LEUPP_CDP = "40630"
LINDEN_CDP = "41085"
LITCHFIELD_PARK_CITY = "41330"
LITTLEFIELD_CDP = "41470"
LOW_MOUNTAIN_CDP = "42590"
LOWER_SANTAN_VILLAGE_CDP = "42460"
LUKACHUKAI_CDP = "42660"
LUPTON_CDP = "42940"
MAISH_VAYA_CDP = "43920"
MAMMOTH_TOWN = "43990"
MANY_FARMS_CDP = "44200"
MARANA_TOWN = "44270"
MARICOPA_COLONY_CDP = "44450"
MARICOPA_CITY = "44410"
MARTINEZ_LAKE_CDP = "44830"
MAYER_CDP = "45180"
MCCONNICO_CDP = "43150"
MCNARY_CDP = "43430"
MCNEAL_CDP = "43570"
MEAD_RANCH_CDP = "45275"
MEADVIEW_CDP = "45285"
MESA_CITY = "46000"
MESA_DEL_CABALLO_CDP = "46005"
MESCAL_CDP = "46070"
MESQUITE_CREEK_CDP = "46087"
MIAMI_TOWN = "46350"
MIRACLE_VALLEY_CDP = "46840"
MOCCASIN_CDP = "47190"
MOENKOPI_CDP = "47330"
MOHAVE_VALLEY_CDP = "47400"
MOJAVE_RANCH_ESTATES_CDP = "47495"
MORENCI_CDP = "47610"
MORMON_LAKE_CDP = "47680"
MORRISTOWN_CDP = "47750"
MOUNTAIN_VIEW_RANCHES_CDP = "47925"
MOUNTAINAIRE_CDP = "47820"
MUNDS_PARK_CDP = "48170"
NACO_CDP = "48310"
NAZLINI_CDP = "49010"
NELSON_CDP = "49100"
NEW_KINGMAN_BUTLER_CDP = "49270"
NEW_RIVER_CDP = "49360"
NOGALES_CITY = "49640"
NOLIC_CDP = "49710"
NORTH_FORK_CDP = "50000"
NUTRIOSO_CDP = "50340"
OAK_CREEK_CANYON_CDP = "50362"
OAK_SPRINGS_CDP = "50480"
OATMAN_CDP = "50620"
OLJATO_MONUMENT_VALLEY_CDP = "51142"
ORACLE_CDP = "51180"
ORANGE_GROVE_MOBILE_MANOR_CDP = "51465"
ORO_VALLEY_TOWN = "51600"
OXBOW_ESTATES_CDP = "51775"
PADRE_RANCHITOS_CDP = "51800"
PAGE_CITY = "51810"
PALOMINAS_CDP = "52230"
PARADISE_VALLEY_TOWN = "52930"
PARKER_STRIP_CDP = "53210"
PARKER_TOWN = "53070"
PARKS_CDP = "53350"
PATAGONIA_TOWN = "53490"
PAULDEN_CDP = "53560"
PAYSON_TOWN = "53700"
PEACH_SPRINGS_CDP = "53770"
PEEPLES_VALLEY_CDP = "53910"
PEORIA_CITY = "54050"
PERIDOT_CDP = "54190"
PHOENIX_CITY = "55000"
PICACHO_CDP = "55210"
PICTURE_ROCKS_CDP = "55300"
PIMA_TOWN = "55560"
PINAL_CDP = "55630"
PINE_CDP = "55700"
PINE_LAKE_CDP = "55845"
PINEDALE_CDP = "55840"
PINETOP_COUNTRY_CLUB_CDP = "55880"
PINETOP_LAKESIDE_TOWN = "55980"
PINION_PINES_CDP = "55983"
PINON_CDP = "56120"
PIRTLEVILLE_CDP = "56400"
PISINEMO_CDP = "56470"
POSTON_CDP = "57170"
PRESCOTT_VALLEY_TOWN = "57450"
PRESCOTT_CITY = "57380"
QUARTZSITE_TOWN = "58010"
QUEEN_CREEK_TOWN = "58150"
QUEEN_VALLEY_CDP = "58290"
RAINBOW_CITY_CDP = "58620"
RANCHO_MESA_VERDE_CDP = "58870"
RED_LAKE_CDP = "59372"
RED_MESA_CDP = "59550"
RED_ROCK_CDP_APACHE_COUNTY = "59690"
RED_ROCK_CDP_PINAL_COUNTY = "59760"
RILLITO_CDP = "59900"
RINCON_VALLEY_CDP = "60120"
RIO_RICO_CDP = "60180"
RIO_VERDE_CDP = "60250"
ROCK_HOUSE_CDP = "60770"
ROCK_POINT_CDP = "60880"
ROOSEVELT_CDP = "61300"
ROOSEVELT_ESTATES_CDP = "61302"
ROUGH_ROCK_CDP = "61370"
ROUND_ROCK_CDP = "61440"
ROUND_VALLEY_CDP = "61448"
RYE_CDP = "61690"
SACATE_VILLAGE_CDP = "61715"
SACATON_CDP = "61720"
SACATON_FLATS_VILLAGE_CDP = "61800"
SADDLEBROOKE_CDP = "61940"
SAFFORD_CITY = "62000"
SAHUARITA_TOWN = "62140"
SALOME_CDP = "62700"
SAN_CARLOS_CDP = "62910"
SAN_JOSE_CDP = "63260"
SAN_LUIS_CITY = "63470"
SAN_MANUEL_CDP = "63540"
SAN_MIGUEL_CDP = "63610"
SAN_SIMON_CDP = "63820"
SAN_TAN_VALLEY_CDP = "64210"
SANDERS_CDP = "63050"
SANTA_CRUZ_CDP = "63960"
SANTA_ROSA_CDP = "64310"
SAWMILL_CDP = "64590"
SCENIC_CDP = "64650"
SCOTTSDALE_CITY = "65000"
SEBA_DALKAI_CDP = "65167"
SECOND_MESA_CDP = "65280"
SEDONA_CITY = "65350"
SEHILI_CDP = "65400"
SELIGMAN_CDP = "65420"
SELLS_CDP = "65490"
SEVEN_MILE_CDP = "65780"
SHONGOPOVI_CDP = "66190"
SHONTO_CDP = "66260"
SHOW_LOW_CITY = "66470"
SHUMWAY_CDP = "66540"
SIERRA_VISTA_SOUTHEAST_CDP = "66845"
SIERRA_VISTA_CITY = "66820"
SIX_SHOOTER_CANYON_CDP = "67295"
SNOWFLAKE_TOWN = "67800"
SO_HI_CDP = "67920"
SOLOMON_CDP = "68010"
SOMERTON_CITY = "68080"
SONOITA_CDP = "68220"
SOUTH_KOMELIK_CDP = "68670"
SOUTH_TUCSON_CITY = "68850"
SPRING_VALLEY_CDP = "69060"
SPRINGERVILLE_TOWN = "68990"
ST_DAVID_CDP = "62280"
ST_JOHNS_CDP = "62362"
ST_JOHNS_CITY = "62350"
ST_MICHAELS_CDP = "62420"
STANFIELD_CDP = "69130"
STAR_VALLEY_TOWN = "69480"
STEAMBOAT_CDP = "69585"
STOTONIC_VILLAGE_CDP = "69872"
STRAWBERRY_CDP = "70040"
SUMMERHAVEN_CDP = "70175"
SUMMIT_CDP = "70240"
SUN_CITY_CDP = "70320"
SUN_CITY_WEST_CDP = "70355"
SUN_LAKES_CDP = "70530"
SUN_VALLEY_CDP = "71160"
SUNIZONA_CDP = "70460"
SUNSITES_CDP = "71020"
SUNWEST_CDP = "71220"
SUPAI_CDP = "71230"
SUPERIOR_TOWN = "71300"
SURPRISE_CITY = "71510"
SWEET_WATER_VILLAGE_CDP = "71642"
SWIFT_TRAIL_JUNCTION_CDP = "71650"
TACNA_CDP = "71790"
TANQUE_VERDE_CDP = "72000"
TAT_MOMOLI_CDP = "72280"
TAYLOR_TOWN = "72420"
TEEC_NOS_POS_CDP = "72560"
TEES_TOH_CDP = "72630"
TEMPE_CITY = "73000"
THATCHER_TOWN = "73420"
THEBA_CDP = "73490"
THREE_POINTS_CDP = "73700"
TIMBERLINE_FERNWOOD_CDP = "73890"
TOLANI_LAKE_CDP = "74120"
TOLLESON_CITY = "74190"
TOMBSTONE_CITY = "74400"
TONALEA_CDP = "74470"
TONOPAH_CDP = "74540"
TONTO_BASIN_CDP = "74610"
TONTO_VILLAGE_CDP = "74665"
TOP_OF_THE_WORLD_CDP = "74820"
TOPAWA_CDP = "74680"
TOPOCK_CDP = "74750"
TOYEI_CDP = "75310"
TRUXTON_CDP = "75590"
TSAILE_CDP = "75660"
TUBA_CITY_CDP = "76010"
TUBAC_CDP = "75940"
TUCSON_ESTATES_CDP = "77035"
TUCSON_MOUNTAINS_CDP = "77179"
TUCSON_CITY = "77000"
TUMACACORI_CARMEN_CDP = "77367"
TURKEY_CREEK_CDP = "77415"
TUSAYAN_TOWN = "77490"
UPPER_SANTAN_VILLAGE_CDP = "78300"
UTTING_CDP = "78400"
VAIL_CDP = "78540"
VAIVA_VO_CDP = "78680"
VALENCIA_WEST_CDP = "78760"
VALENTINE_CDP = "78820"
VALLE_CDP = "78855"
VALLE_VISTA_CDP = "78865"
VENTANA_CDP = "79590"
VERDE_VILLAGE_CDP = "79830"
VERNON_CDP = "79870"
VICKSBURG_CDP = "79940"
VILLAGE_OF_OAK_CREEK_BIG_PARK_CDP = "80095"
WAGON_WHEEL_CDP = "80380"
WAHAK_HOTRONTK_CDP = "80430"
WALL_LANE_CDP = "80790"
WALNUT_CREEK_CDP = "80825"
WASHINGTON_PARK_CDP = "81175"
WELLTON_HILLS_CDP = "81490"
WELLTON_TOWN = "81480"
WENDEN_CDP = "81550"
WET_CAMP_VILLAGE_CDP = "82060"
WHEATFIELDS_CDP = "82120"
WHETSTONE_CDP = "82156"
WHISPERING_PINES_CDP = "82270"
WHITE_HILLS_CDP = "82425"
WHITE_MOUNTAIN_LAKE_CDP = "82450"
WHITECONE_CDP = "82390"
WHITERIVER_CDP = "82530"
WHY_CDP = "82670"
WICKENBURG_TOWN = "82740"
WIDE_RUINS_CDP = "82810"
WIKIEUP_CDP = "82880"
WILHOIT_CDP = "82950"
WILLCOX_CITY = "83090"
WILLIAMS_CITY = "83160"
WILLIAMSON_CDP = "83388"
WILLOW_CANYON_CDP = "83475"
WILLOW_VALLEY_CDP = "83570"
WINDOW_ROCK_CDP = "83720"
WINKELMAN_TOWN = "83790"
WINSLOW_WEST_CDP = "83960"
WINSLOW_CITY = "83930"
WINTERSBURG_CDP = "84000"
WITTMANN_CDP = "84140"
WOODRUFF_CDP = "84350"
YARNELL_CDP = "84980"
YORK_CDP = "85260"
YOUNG_CDP = "85330"
YOUNGTOWN_TOWN = "85400"
YUCCA_CDP = "85470"
YUMA_PROVING_GROUND_CDP = "85680"
YUMA_CITY = "85540"
