# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Nevada."""


ALAMO_CDP = "00500"
AMARGOSA_VALLEY_CDP = "01000"
AUSTIN_CDP = "03700"
BAKER_CDP = "04100"
BATTLE_MOUNTAIN_CDP = "04900"
BEATTY_CDP = "05100"
BEAVERDAM_CDP = "05125"
BENNETT_SPRINGS_CDP = "05275"
BLUE_DIAMOND_CDP = "05700"
BOULDER_CITY_CITY = "06500"
BUNKERVILLE_CDP = "08100"
CAL_NEV_ARI_CDP = "08600"
CALIENTE_CITY = "08500"
CARLIN_CITY = "08900"
CARSON_CITY = "09700"
CARTER_SPRINGS_CDP = "10200"
COLD_SPRINGS_CDP = "14090"
CRESCENT_VALLEY_CDP = "16300"
CRYSTAL_BAY_CDP = "16700"
DAYTON_CDP = "17500"
DENIO_CDP = "18500"
DOUBLE_SPRING_CDP = "19150"
DRY_VALLEY_CDP = "19800"
DYER_CDP = "20700"
EAST_VALLEY_CDP = "21520"
ELKO_CITY = "22500"
ELY_CITY = "23500"
EMPIRE_CDP = "23700"
ENTERPRISE_CDP = "23770"
EUREKA_CDP = "23900"
FALLON_STATION_CDP = "24500"
FALLON_CITY = "24100"
FERNLEY_CITY = "24900"
FISH_SPRINGS_CDP = "25000"
FORT_MCDERMITT_CDP = "25490"
GABBS_CDP = "25900"
GARDNERVILLE_CDP = "26300"
GARDNERVILLE_RANCHOS_CDP = "26500"
GENOA_CDP = "27100"
GERLACH_CDP = "27300"
GLENBROOK_CDP = "27900"
GOLCONDA_CDP = "28500"
GOLDEN_VALLEY_CDP = "28860"
GOLDFIELD_CDP = "28900"
GOODSPRINGS_CDP = "29500"
GRASS_VALLEY_CDP = "30220"
HAWTHORNE_CDP = "31300"
HENDERSON_CITY = "31900"
HIKO_CDP = "32900"
HUMBOLDT_RIVER_RANCH_CDP = "34100"
IMLAY_CDP = "34700"
INCLINE_VILLAGE_CDP = "35100"
INDIAN_HILLS_CDP = "35275"
INDIAN_SPRINGS_CDP = "35300"
JACKPOT_CDP = "36500"
JOHNSON_LANE_CDP = "37190"
KINGSBURY_CDP = "38000"
KINGSTON_CDP = "38100"
LAKERIDGE_CDP = "39100"
LAMOILLE_CDP = "39300"
LAS_VEGAS_CITY = "40000"
LAUGHLIN_CDP = "41000"
LEMMON_VALLEY_CDP = "41800"
LOGAN_CREEK_CDP = "42350"
LOVELOCK_CITY = "43000"
LUND_CDP = "43400"
MCDERMITT_CDP = "44000"
MCGILL_CDP = "44200"
MESQUITE_CITY = "46000"
MINA_CDP = "46800"
MINDEN_CDP = "47000"
MOAPA_TOWN_CDP = "47840"
MOAPA_VALLEY_CDP = "47880"
MOGUL_CDP = "48000"
MONTELLO_CDP = "48400"
MOUNT_CHARLESTON_CDP = "49310"
MOUNT_WILSON_CDP = "49425"
MOUNTAIN_CITY_CDP = "49200"
NELLIS_AFB_CDP = "50400"
NELSON_CDP = "50600"
NIXON_CDP = "51200"
NORTH_LAS_VEGAS_CITY = "51800"
OASIS_CDP = "52200"
OROVADA_CDP = "53000"
OSINO_CDP = "53200"
OWYHEE_CDP = "53600"
PAHRUMP_CDP = "53800"
PANACA_CDP = "54200"
PARADISE_CDP = "54600"
PARADISE_VALLEY_CDP = "55400"
PIOCHE_CDP = "57400"
PRESTON_CDP = "58000"
RACHEL_CDP = "58820"
RENO_CITY = "60600"
ROUND_HILL_VILLAGE_CDP = "62170"
RUHENSTROTH_CDP = "63450"
RUTH_CDP = "63800"
SANDY_VALLEY_CDP = "64600"
SCHURZ_CDP = "65400"
SEARCHLIGHT_CDP = "65600"
SILVER_CITY_CDP = "66800"
SILVER_PEAK_CDP = "67000"
SILVER_SPRINGS_CDP = "67200"
SKYLAND_CDP = "67600"
SMITH_VALLEY_CDP = "68050"
SPANISH_SPRINGS_CDP = "68350"
SPARKS_CITY = "68400"
SPRING_CREEK_CDP = "68550"
SPRING_VALLEY_CDP = "68585"
STAGECOACH_CDP = "68800"
STATELINE_CDP = "69200"
SUMMERLIN_SOUTH_CDP = "70900"
SUN_VALLEY_CDP = "71600"
SUNRISE_MANOR_CDP = "71400"
SUTCLIFFE_CDP = "71800"
TONOPAH_CDP = "73600"
TOPAZ_LAKE_CDP = "74200"
TOPAZ_RANCH_ESTATES_CDP = "74400"
UNIONVILLE_CDP = "76400"
URSINE_CDP = "77200"
VALMY_CDP = "78200"
VERDI_CDP = "79400"
VIRGINIA_CITY_CDP = "80000"
WADSWORTH_CDP = "81000"
WALKER_LAKE_CDP = "81100"
WASHOE_VALLEY_CDP = "82250"
WELLS_CITY = "83000"
WEST_WENDOVER_CITY = "83730"
WHITNEY_CDP = "83800"
WINCHESTER_CDP = "84600"
WINNEMUCCA_CITY = "84800"
YERINGTON_CITY = "85400"
ZEPHYR_COVE_CDP = "86200"
