# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Rhode Island."""


ASHAWAY_CDP = "03520"
BRADFORD_CDP = "08020"
CAROLINA_CDP = "12340"
CENTRAL_FALLS_CITY = "14140"
CHARLESTOWN_CDP = "14320"
CHEPACHET_CDP = "14860"
CLAYVILLE_CDP = "15940"
CRANSTON_CITY = "19180"
CUMBERLAND_HILL_CDP = "20260"
EAST_PROVIDENCE_CITY = "22960"
FOSTER_CENTER_CDP = "27640"
GREENE_CDP = "31240"
GREENVILLE_CDP = "31600"
HARMONY_CDP = "33040"
HARRISVILLE_CDP = "33400"
HOPE_VALLEY_CDP = "34660"
HOPKINTON_CDP = "35200"
KINGSTON_CDP = "38980"
MELVILLE_CDP = "45010"
MISQUAMICUT_CDP = "46000"
NARRAGANSETT_PIER_CDP = "48700"
NEWPORT_EAST_CDP = "50140"
NEWPORT_CITY = "49960"
PASCOAG_CDP = "54460"
PAWTUCKET_CITY = "54640"
PROVIDENCE_CITY = "59000"
QUONOCHONTAUG_CDP = "60260"
TIVERTON_CDP = "70700"
VALLEY_FALLS_CDP = "72500"
WAKEFIELD_PEACE_DALE_CDP = "73132"
WARWICK_CITY = "74300"
WATCH_HILL_CDP = "75200"
WEEKAPAUG_CDP = "75920"
WESTERLY_CDP = "76820"
WOONSOCKET_CITY = "80780"
WYOMING_CDP = "80960"
