# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Vermont."""


ALBANY_VILLAGE = "00400"
ALBURGH_VILLAGE = "00850"
ALGIERS_CDP = "01035"
ARLINGTON_CDP = "01375"
ASCUTNEY_CDP = "01750"
BAKERSFIELD_CDP = "02425"
BARNET_CDP = "02800"
BARRE_CITY = "03175"
BARTON_VILLAGE = "03475"
BEECHER_FALLS_CDP = "04150"
BELLOWS_FALLS_VILLAGE = "04225"
BENNINGTON_CDP = "04750"
BENSON_CDP = "05125"
BETHEL_CDP = "05725"
BOLTON_CDP = "06475"
BOLTON_VALLEY_CDP = "06700"
BRADFORD_CDP = "07225"
BRANDON_CDP = "07675"
BRATTLEBORO_CDP = "07975"
BRISTOL_CDP = "08950"
BURLINGTON_CITY = "10675"
CABOT_CDP = "11050"
CAMBRIDGE_VILLAGE = "11425"
CANAAN_CDP = "11725"
CASTLETON_CDP = "11875"
CASTLETON_FOUR_CORNERS_CDP = "12062"
CAVENDISH_CDP = "12175"
CHELSEA_CDP = "13450"
CHESTER_CDP = "13600"
CHIMNEY_HILL_CDP = "13860"
CHITTENDEN_CDP = "14275"
CONCORD_CDP = "15175"
COVENTRY_CDP = "16075"
DANBY_CDP = "16750"
DANVILLE_CDP = "17050"
DERBY_CENTER_VILLAGE = "17425"
DERBY_LINE_VILLAGE = "17500"
DORSET_CDP = "17650"
EAST_BARRE_CDP = "19075"
EAST_BURKE_CDP = "19600"
EAST_CHARLOTTE_CDP = "19975"
EAST_DORSET_CDP = "20350"
EAST_MIDDLEBURY_CDP = "21700"
EAST_MONTPELIER_CDP = "21850"
EAST_POULTNEY_CDP = "22300"
ENOSBURG_FALLS_VILLAGE = "24025"
ESSEX_JUNCTION_VILLAGE = "24400"
FAIR_HAVEN_CDP = "25450"
FAIRFAX_CDP = "24850"
FAIRLEE_CDP = "25600"
GILMAN_CDP = "27925"
GLOVER_CDP = "28000"
GRAFTON_CDP = "28825"
GRANITEVILLE_CDP = "29425"
GREENSBORO_BEND_CDP = "30325"
GREENSBORO_CDP = "30100"
GROTON_CDP = "30475"
HANKSVILLE_CDP = "31600"
HARDWICK_CDP = "31750"
HARMONYVILLE_CDP = "32050"
HARTFORD_VILLAGE_CDP = "32205"
HARTLAND_CDP = "32350"
HIGHGATE_CENTER_CDP = "33175"
HIGHGATE_SPRINGS_CDP = "33325"
HINESBURG_CDP = "33400"
HUNTINGTON_CDP = "34525"
HUNTINGTON_CENTER_CDP = "34675"
HYDE_PARK_VILLAGE = "34975"
IRASBURG_CDP = "35500"
ISLAND_POND_CDP = "35725"
JACKSONVILLE_VILLAGE = "36025"
JAMAICA_CDP = "36100"
JEFFERSONVILLE_VILLAGE = "36475"
JERICHO_VILLAGE = "36625"
JOHNSON_VILLAGE = "37000"
KILLINGTON_VILLAGE_CDP = "37750"
LINCOLN_CDP = "40000"
LONDONDERRY_CDP = "40150"
LOWELL_CDP = "40450"
LUDLOW_VILLAGE = "41200"
LUNENBURG_CDP = "41350"
LYNDON_CDP = "41650"
LYNDON_CENTER_CDP = "41800"
LYNDONVILLE_VILLAGE = "41950"
MANCHESTER_CENTER_CDP = "42925"
MANCHESTER_VILLAGE = "42700"
MARSHFIELD_VILLAGE = "43525"
MIDDLEBURY_CDP = "44275"
MIDDLETOWN_SPRINGS_CDP = "44725"
MILTON_CDP = "45175"
MONTPELIER_CITY = "46000"
MORRISVILLE_VILLAGE = "46825"
NEW_HAVEN_CDP = "48550"
NEWBURY_VILLAGE = "48100"
NEWFANE_VILLAGE = "48325"
NEWPORT_CENTER_CDP = "49000"
NEWPORT_CITY = "48850"
NORTH_BENNINGTON_VILLAGE = "49075"
NORTH_CLARENDON_CDP = "49450"
NORTH_HARTLAND_CDP = "50500"
NORTH_HYDE_PARK_CDP = "50725"
NORTH_POWNAL_CDP = "51325"
NORTH_SPRINGFIELD_CDP = "51925"
NORTH_TROY_VILLAGE = "52075"
NORTH_WESTMINSTER_CDP = "52375"
NORTHFIELD_CDP = "50200"
NORWICH_CDP = "52825"
OLD_BENNINGTON_VILLAGE = "53125"
ORLEANS_VILLAGE = "53575"
PAWLET_CDP = "54175"
PEACHAM_CDP = "54325"
PITTSFORD_CDP = "55525"
PLAINFIELD_CDP = "55750"
POULTNEY_VILLAGE = "56800"
POWNAL_CDP = "56950"
POWNAL_CENTER_CDP = "57100"
PROCTOR_CDP = "57246"
PROCTORSVILLE_CDP = "57400"
PUTNEY_CDP = "57625"
QUECHEE_CDP = "57775"
RANDOLPH_CDP = "58000"
READSBORO_CDP = "58525"
RICHFORD_CDP = "59050"
RICHMOND_CDP = "59200"
ROCHESTER_CDP = "60025"
RUTLAND_CITY = "61225"
SAXTONS_RIVER_VILLAGE = "62950"
SHEFFIELD_CDP = "64000"
SHELBURNE_CDP = "64225"
SOUTH_BARRE_CDP = "66025"
SOUTH_BURLINGTON_CITY = "66175"
SOUTH_HERO_CDP = "66925"
SOUTH_LINCOLN_CDP = "67150"
SOUTH_LONDONDERRY_CDP = "67225"
SOUTH_ROYALTON_CDP = "68050"
SOUTH_SHAFTSBURY_CDP = "68200"
SOUTH_WOODSTOCK_CDP = "69250"
SPRINGFIELD_CDP = "69475"
ST_ALBANS_CITY = "61675"
ST_GEORGE_CDP = "62046"
ST_JOHNSBURY_CDP = "62125"
STAMFORD_CDP = "69700"
STOWE_CDP = "70450"
STRATTON_MOUNTAIN_CDP = "70825"
SUTTON_CDP = "71500"
SWANTON_VILLAGE = "71650"
TOWNSHEND_CDP = "73225"
TROY_CDP = "73450"
UNDERHILL_CENTER_CDP = "74050"
UNDERHILL_FLATS_CDP = "74125"
VERGENNES_CITY = "74650"
WAITSFIELD_CDP = "75250"
WALLINGFORD_CDP = "75850"
WARDSBORO_CDP = "76150"
WATERBURY_CDP = "76900"
WATERBURY_CENTER_CDP = "77050"
WEBSTERVILLE_CDP = "77800"
WELLS_CDP = "77875"
WELLS_RIVER_VILLAGE = "78025"
WEST_BRATTLEBORO_CDP = "78850"
WEST_BURKE_VILLAGE = "79150"
WEST_CHARLOTTE_CDP = "79335"
WEST_DUMMERSTON_CDP = "79750"
WEST_PAWLET_CDP = "82150"
WEST_RUTLAND_CDP = "82375"
WEST_WOODSTOCK_CDP = "83125"
WESTFORD_CDP = "80275"
WESTMINSTER_VILLAGE = "81325"
WESTON_CDP = "81925"
WHITE_RIVER_JUNCTION_CDP = "83575"
WHITINGHAM_CDP = "83875"
WILDER_CDP = "84025"
WILLIAMSTOWN_CDP = "84100"
WILMINGTON_CDP = "84625"
WINDSOR_CDP = "85000"
WINOOSKI_CITY = "85150"
WOLCOTT_CDP = "85300"
WOODSTOCK_VILLAGE = "85900"
WORCESTER_CDP = "86050"
