# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Mississippi."""


ABBEVILLE_TOWN = "00100"
ABERDEEN_CITY = "00180"
ACKERMAN_TOWN = "00300"
AGRICOLA_CDP = "00460"
ALCORN_STATE_UNIVERSITY_CDP = "00680"
ALGOMA_TOWN = "00820"
ALLIGATOR_TOWN = "00940"
AMORY_CITY = "01260"
ANGUILLA_TOWN = "01500"
ARCOLA_TOWN = "01820"
ARKABUTLA_CDP = "01940"
ARNOLD_LINE_CDP = "02060"
ARTESIA_TOWN = "02100"
ASHLAND_TOWN = "02140"
AUSTIN_CDP = "02380"
BALDWYN_CITY = "02700"
BASSFIELD_TOWN = "03580"
BATESVILLE_CITY = "03620"
BAXTERVILLE_CDP = "03940"
BAY_SPRINGS_CITY = "04060"
BAY_ST_LOUIS_CITY = "03980"
BEAUMONT_TOWN = "04500"
BEAUREGARD_VILLAGE = "04540"
BEECHWOOD_CDP = "04705"
BELMONT_TOWN = "05100"
BELZONI_CITY = "05140"
BENNDALE_CDP = "05180"
BENOIT_TOWN = "05220"
BENTON_CDP = "05340"
BENTONIA_TOWN = "05380"
BETHLEHEM_CDP = "05780"
BEULAH_TOWN = "05820"
BIG_CREEK_VILLAGE = "06060"
BIG_POINT_CDP = "06180"
BIGGERSVILLE_CDP = "06100"
BILOXI_CITY = "06220"
BLUE_MOUNTAIN_TOWN = "07060"
BLUE_SPRINGS_VILLAGE = "07100"
BOBO_CDP = "07220"
BOGUE_CHITTO_CDP_KEMPER_AND_NESHOBA_COUNTIES = "07330"
BOGUE_CHITTO_CDP_LINCOLN_COUNTY = "07322"
BOLIVAR_CDP = "07460"
BOLTON_TOWN = "07540"
BOND_CDP = "07620"
BOONEVILLE_CITY = "07780"
BOVINA_CDP = "07900"
BOYLE_TOWN = "08180"
BRANDON_CITY = "08300"
BRAXTON_VILLAGE = "08460"
BRIDGETOWN_CDP = "08655"
BROOKHAVEN_CITY = "08820"
BROOKSVILLE_TOWN = "08980"
BRUCE_TOWN = "09180"
BUCKATUNNA_CDP = "09380"
BUDE_TOWN = "09460"
BURNSVILLE_TOWN = "09820"
BYHALIA_TOWN = "10060"
BYRAM_CITY = "10140"
CALEDONIA_TOWN = "10460"
CALHOUN_CITY_TOWN = "10580"
CANTON_CITY = "11100"
CARROLLTON_TOWN = "11580"
CARTHAGE_CITY = "11780"
CARY_TOWN = "11820"
CENTREVILLE_TOWN = "12740"
CHALYBEATE_CDP = "12780"
CHARLESTON_CITY = "12900"
CHUNKY_TOWN = "13580"
CLARA_CDP = "13700"
CLARKSDALE_CITY = "13820"
CLEARY_CDP = "14140"
CLEVELAND_CITY = "14260"
CLINTON_CITY = "14420"
CLOVERDALE_CDP = "14540"
COAHOMA_TOWN = "14580"
COFFEEVILLE_TOWN = "14740"
COLDWATER_TOWN = "14900"
COLLINS_CITY = "15140"
COLLINSVILLE_CDP = "15180"
COLUMBIA_CITY = "15340"
COLUMBUS_AFB_CDP = "15420"
COLUMBUS_CITY = "15380"
COMO_TOWN = "15500"
CONEHATTA_CDP = "15540"
CORINTH_CITY = "15700"
COURTLAND_TOWN = "15980"
CRAWFORD_TOWN = "16420"
CRENSHAW_TOWN = "16460"
CROSBY_TOWN = "16620"
CROWDER_TOWN = "16940"
CRUGER_TOWN = "16980"
CRYSTAL_SPRINGS_CITY = "17060"
DIBERVILLE_CITY = "19180"
DLO_TOWN = "19340"
DARLING_CDP = "17700"
DE_KALB_TOWN = "18340"
DE_SOTO_CDP = "18980"
DELISLE_CDP = "18420"
DECATUR_TOWN = "18180"
DELTA_CITY_CDP = "18500"
DENNIS_CDP = "18700"
DERMA_TOWN = "18940"
DIAMONDHEAD_CITY = "19100"
DODDSVILLE_TOWN = "19420"
DREW_CITY = "20020"
DUBLIN_CDP = "20220"
DUCK_HILL_TOWN = "20260"
DUMAS_TOWN = "20340"
DUNCAN_TOWN = "20380"
DUNDEE_CDP = "20420"
DURANT_CITY = "20500"
EAGLE_BEND_CDP = "20610"
EASTABUCHIE_CDP = "20740"
ECRU_TOWN = "21340"
EDEN_VILLAGE = "21420"
EDWARDS_TOWN = "21580"
ELIZABETH_CDP = "21860"
ELLIOTT_CDP = "21940"
ELLISVILLE_CITY = "22020"
ENTERPRISE_TOWN = "22580"
ESCATAWPA_CDP = "22900"
ETHEL_TOWN = "23220"
EUDORA_CDP = "23340"
EUPORA_CITY = "23420"
FALCON_TOWN = "24180"
FALKNER_TOWN = "24220"
FARMINGTON_TOWN = "24420"
FARRELL_CDP = "24460"
FAYETTE_CITY = "24500"
FERNWOOD_CDP = "24740"
FLORA_TOWN = "24940"
FLORENCE_CITY = "24980"
FLOWOOD_CITY = "25100"
FOREST_CITY = "25340"
FOXWORTH_CDP = "25740"
FRENCH_CAMP_TOWN = "26020"
FRIARS_POINT_TOWN = "26060"
FULTON_CITY = "26300"
GATTMAN_VILLAGE = "26780"
GAUTIER_CITY = "26860"
GEORGETOWN_TOWN = "26980"
GLEN_ALLAN_CDP = "27580"
GLEN_TOWN = "27540"
GLENDALE_CDP = "27620"
GLENDORA_VILLAGE = "27660"
GLOSTER_TOWN = "27820"
GLUCKSTADT_CDP = "27900"
GOLDEN_TOWN = "27940"
GOODMAN_TOWN = "28220"
GRACE_CDP = "28500"
GREENVILLE_CITY = "29180"
GREENWOOD_CITY = "29340"
GRENADA_CITY = "29460"
GULF_HILLS_CDP = "29620"
GULF_PARK_ESTATES_CDP = "29660"
GULFPORT_CITY = "29700"
GUNNISON_TOWN = "29900"
GUNTOWN_TOWN = "29940"
HAMILTON_CDP = "30220"
HARPERVILLE_CDP = "30780"
HATLEY_TOWN = "30980"
HATTIESBURG_CITY = "31020"
HAZLEHURST_CITY = "31220"
HEIDELBERG_TOWN = "31420"
HELENA_CDP = "31460"
HENDERSON_POINT_CDP = "31540"
HERMANVILLE_CDP = "31740"
HERNANDO_CITY = "31780"
HICKORY_FLAT_TOWN = "32020"
HICKORY_TOWN = "31980"
HIDE_A_WAY_LAKE_CDP = "32110"
HILLSBORO_CDP = "32460"
HOLCOMB_CDP = "32820"
HOLLANDALE_CITY = "32900"
HOLLY_SPRINGS_CITY = "33100"
HORN_LAKE_CITY = "33700"
HOUSTON_CITY = "33900"
HURLEY_CDP = "34340"
INDEPENDENCE_CDP = "34700"
INDIANOLA_CITY = "34740"
INVERNESS_TOWN = "35020"
ISOLA_TOWN = "35220"
ITTA_BENA_CITY = "35260"
IUKA_CITY = "35300"
JACINTO_CDP = "35340"
JACKSON_CITY = "36000"
JONESTOWN_TOWN = "36800"
JUMPERTOWN_TOWN = "37040"
KEARNEY_PARK_CDP = "37190"
KILMICHAEL_TOWN = "37560"
KILN_CDP = "37600"
KIRKVILLE_CDP = "37840"
KOKOMO_CDP = "38160"
KOSCIUSKO_CITY = "38320"
KOSSUTH_VILLAGE = "38360"
LAKE_TOWN = "38600"
LAKEVIEW_CDP = "38910"
LAMAR_CDP = "39000"
LAMBERT_TOWN = "39080"
LATIMER_CDP = "39520"
LAUDERDALE_CDP = "39600"
LAUREL_CITY = "39640"
LEAF_CDP = "39800"
LEAKESVILLE_TOWN = "39840"
LEARNED_TOWN = "39880"
LELAND_CITY = "40280"
LENA_TOWN = "40360"
LEXINGTON_CITY = "40600"
LIBERTY_TOWN = "40640"
LONG_BEACH_CITY = "41680"
LONGVIEW_CDP = "41960"
LOUIN_TOWN = "42200"
LOUISE_TOWN = "42240"
LOUISVILLE_CITY = "42280"
LUCEDALE_CITY = "42440"
LULA_TOWN = "42600"
LUMBERTON_CITY = "42640"
LYMAN_CDP = "42800"
LYNCHBURG_CDP = "42840"
LYON_TOWN = "42960"
MABEN_TOWN = "42980"
MACON_CITY = "44240"
MADISON_CITY = "44520"
MAGEE_CITY = "44600"
MAGNOLIA_CITY = "44680"
MANTACHIE_TOWN = "44920"
MANTEE_VILLAGE = "44960"
MARIETTA_TOWN = "45120"
MARION_TOWN = "45160"
MARKS_CITY = "45240"
MATHISTON_TOWN = "45720"
MAYERSVILLE_TOWN = "46000"
MCCOMB_CITY = "43280"
MCCOOL_TOWN = "43400"
MCLAIN_TOWN = "43840"
MEADVILLE_TOWN = "46200"
MENDENHALL_CITY = "46600"
MERIDIAN_STATION_CDP = "46680"
MERIDIAN_CITY = "46640"
MERIGOLD_TOWN = "46720"
METCALFE_TOWN = "46880"
MISSISSIPPI_STATE_CDP = "48030"
MISSISSIPPI_VALLEY_STATE_UNIVERSITY_CDP = "48120"
MIZE_TOWN = "48240"
MONTICELLO_TOWN = "48560"
MONTROSE_TOWN = "48640"
MOOREVILLE_CDP = "48720"
MOORHEAD_CITY = "48760"
MORGAN_CITY_TOWN = "48800"
MORGANTOWN_CDP = "48880"
MORTON_CITY = "49080"
MOSELLE_CDP = "49160"
MOSS_POINT_CITY = "49240"
MOUND_BAYOU_CITY = "49320"
MOUNT_OLIVE_TOWN = "49520"
MOUNT_PLEASANT_CDP = "49640"
MYRTLE_TOWN = "50280"
NATCHEZ_CITY = "50440"
NELLIEBURG_CDP = "50720"
NETTLETON_CITY = "50880"
NEW_ALBANY_CITY = "51000"
NEW_AUGUSTA_TOWN = "51040"
NEW_HAMILTON_CDP = "51240"
NEW_HEBRON_TOWN = "51360"
NEW_HOPE_CDP = "51400"
NEW_HOULKA_TOWN = "51420"
NEW_SITE_CDP = "51680"
NEWTON_CITY = "51720"
NICHOLSON_CDP = "51840"
NITTA_YUMA_CDP = "51960"
NORTH_CARROLLTON_TOWN = "52400"
NORTH_TUNICA_CDP = "52680"
NOXAPATER_TOWN = "52880"
OAK_GROVE_CDP = "53080"
OAKLAND_TOWN = "53200"
OCEAN_SPRINGS_CITY = "53520"
OKOLONA_CITY = "53680"
OLIVE_BRANCH_CITY = "54040"
OSYKA_TOWN = "54640"
OVETT_CDP = "54680"
OXFORD_CITY = "54840"
PACE_TOWN = "54920"
PACHUTA_TOWN = "54960"
PADEN_VILLAGE = "55000"
PANTHER_BURN_CDP = "55160"
PARIS_CDP = "55280"
PASCAGOULA_CITY = "55360"
PASS_CHRISTIAN_CITY = "55400"
PATTISON_CDP = "55560"
PEARL_RIVER_CDP = "55930"
PEARL_CITY = "55760"
PEARLINGTON_CDP = "55920"
PELAHATCHIE_TOWN = "56200"
PETAL_CITY = "56800"
PHEBA_CDP = "56920"
PHILADELPHIA_CITY = "56960"
PICAYUNE_CITY = "57160"
PICKENS_TOWN = "57200"
PITTSBORO_VILLAGE = "58360"
PLANTERSVILLE_TOWN = "58440"
POLKVILLE_TOWN = "58960"
PONTOTOC_CITY = "59160"
POPE_VILLAGE = "59240"
POPLARVILLE_CITY = "59480"
PORT_GIBSON_CITY = "59560"
PORTERVILLE_CDP = "59520"
POTTS_CAMP_TOWN = "59720"
PRENTISS_TOWN = "59920"
PUCKETT_VILLAGE = "60360"
PURVIS_CITY = "60480"
QUITMAN_CITY = "60720"
RALEIGH_TOWN = "60840"
RANDOLPH_CDP = "60880"
RAWLS_SPRINGS_CDP = "61080"
RAYMOND_CITY = "61160"
RED_BANKS_CDP = "61240"
REDWATER_CDP = "61400"
REDWOOD_CDP = "61440"
RENA_LARA_CDP = "61840"
RENOVA_TOWN = "61890"
RICHLAND_CITY = "62400"
RICHTON_TOWN = "62480"
RIDGELAND_CITY = "62520"
RIENZI_TOWN = "62560"
RIPLEY_CITY = "62600"
ROBINHOOD_CDP = "62900"
ROLLING_FORK_CITY = "63560"
ROSEDALE_CITY = "63720"
ROXIE_TOWN = "64080"
RULEVILLE_CITY = "64200"
RUNNELSTOWN_CDP = "64240"
SALLIS_TOWN = "64800"
SALTILLO_CITY = "64840"
SANDERSVILLE_TOWN = "64920"
SARDIS_TOWN = "65560"
SATARTIA_VILLAGE = "65680"
SAUCIER_CDP = "65720"
SCHLATER_TOWN = "66080"
SCOOBA_TOWN = "66160"
SCOTT_CDP = "66240"
SEBASTOPOL_TOWN = "66280"
SEMINARY_TOWN = "66400"
SENATOBIA_CITY = "66440"
SHANNON_TOWN = "66720"
SHARON_CDP = "66840"
SHAW_CITY = "67000"
SHELBY_CITY = "67040"
SHERMAN_TOWN = "67200"
SHUBUTA_TOWN = "67520"
SHUQUALAK_TOWN = "67640"
SIDON_TOWN = "67840"
SILVER_CITY_TOWN = "67920"
SILVER_CREEK_TOWN = "67960"
SKENE_CDP = "68200"
SLATE_SPRINGS_VILLAGE = "68320"
SLEDGE_TOWN = "68400"
SMITHVILLE_TOWN = "68720"
SNOW_LAKE_SHORES_TOWN = "68960"
SOSO_TOWN = "69160"
SOUTHAVEN_CITY = "69280"
ST_MARTIN_CDP = "64680"
STANDING_PINE_CDP = "70120"
STARKVILLE_CITY = "70240"
STATE_LINE_TOWN = "70320"
STEWART_CDP = "70640"
STONEVILLE_CDP = "70720"
STONEWALL_TOWN = "70760"
STRAYHORN_CDP = "71040"
STURGIS_TOWN = "71320"
SUMMIT_TOWN = "71480"
SUMNER_TOWN = "71520"
SUMRALL_TOWN = "71560"
SUNFLOWER_TOWN = "71600"
SYLVARENA_VILLAGE = "72040"
SYMONDS_CDP = "72080"
TAYLOR_VILLAGE = "72360"
TAYLORSVILLE_TOWN = "72400"
TCHULA_TOWN = "72440"
TERRY_TOWN = "72680"
THAXTON_TOWN = "72760"
TILLATOBA_TOWN = "73440"
TISHOMINGO_TOWN = "73720"
TOCCOPOLA_TOWN = "73760"
TOOMSUBA_CDP = "73880"
TREMONT_TOWN = "74400"
TUCKER_CDP = "74675"
TULA_CDP = "74720"
TUNICA_RESORTS_CDP = "74820"
TUNICA_TOWN = "74760"
TUPELO_CITY = "74840"
TUTWILER_TOWN = "75040"
TYLERTOWN_TOWN = "75160"
UNION_TOWN = "75360"
UNIVERSITY_CDP = "75520"
UTICA_TOWN = "75760"
VAIDEN_TOWN = "75880"
VALLEY_PARK_CDP = "76040"
VAN_VLEET_CDP = "76240"
VANCLEAVE_CDP = "76200"
VARDAMAN_TOWN = "76320"
VERONA_CITY = "76560"
VICKSBURG_CITY = "76720"
VICTORIA_CDP = "76760"
WADE_CDP = "77080"
WALLS_TOWN = "77400"
WALNUT_GROVE_TOWN = "77520"
WALNUT_TOWN = "77480"
WALTHALL_VILLAGE = "77640"
WATER_VALLEY_CITY = "78000"
WATERFORD_CDP = "77880"
WAVELAND_CITY = "78200"
WAYNESBORO_CITY = "78360"
WEBB_TOWN = "78480"
WEIR_TOWN = "78520"
WESSON_TOWN = "78640"
WEST_HATTIESBURG_CDP = "78890"
WEST_POINT_CITY = "79120"
WEST_TOWN = "78680"
WHEELER_CDP = "79280"
WHITE_OAK_CDP = "79620"
WIGGINS_CITY = "80160"
WINONA_CITY = "80760"
WINSTONVILLE_TOWN = "80800"
WINTERVILLE_CDP = "80840"
WOODLAND_VILLAGE = "81000"
WOODVILLE_TOWN = "81120"
YAZOO_CITY_CITY = "81520"
