# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Utah."""


ALPINE_CITY = "00540"
ALTA_TOWN = "00650"
ALTAMONT_TOWN = "00760"
ALTON_TOWN = "00870"
AMALGA_TOWN = "01090"
AMERICAN_FORK_CITY = "01310"
ANETH_CDP = "01530"
ANNABELLA_TOWN = "01750"
ANTIMONY_TOWN = "01860"
APPLE_VALLEY_TOWN = "01905"
AURORA_CITY = "02740"
AVON_CDP = "02960"
BALLARD_TOWN = "03345"
BEAR_RIVER_CITY_CITY = "03950"
BEAVER_CITY = "04060"
BENJAMIN_CDP = "04720"
BENSON_CDP = "05050"
BERYL_JUNCTION_CDP = "05380"
BICKNELL_TOWN = "05490"
BIG_WATER_TOWN = "05534"
BLANDING_CITY = "06370"
BLUEBELL_CDP = "06590"
BLUFF_TOWN = "06700"
BLUFFDALE_CITY = "06810"
BONANZA_CDP = "06920"
BOULDER_TOWN = "07470"
BOUNTIFUL_CITY = "07690"
BRIAN_HEAD_TOWN = "08020"
BRIGHAM_CITY_CITY = "08460"
BRIGHTON_TOWN = "08570"
BRYCE_CANYON_CITY_TOWN = "08787"
CACHE_CDP = "09725"
CANNONVILLE_TOWN = "10330"
CARBONVILLE_CDP = "10440"
CASTLE_DALE_CITY = "10660"
CASTLE_VALLEY_TOWN = "11000"
CEDAR_CITY_CITY = "11320"
CEDAR_FORT_TOWN = "11430"
CEDAR_HIGHLANDS_CDP = "11435"
CEDAR_HILLS_CITY = "11440"
CENTERFIELD_TOWN = "11870"
CENTERVILLE_CITY = "11980"
CENTRAL_CDP = "12200"
CENTRAL_VALLEY_TOWN = "12260"
CHARLESTON_TOWN = "12420"
CIRCLEVILLE_TOWN = "12970"
CLARKSTON_TOWN = "13190"
CLAWSON_TOWN = "13300"
CLEAR_CREEK_CDP = "13740"
CLEARFIELD_CITY = "13850"
CLEVELAND_TOWN = "14070"
CLINTON_CITY = "14290"
COALVILLE_CITY = "14840"
COPPERTON_METRO_TOWNSHIP = "15720"
CORINNE_CITY = "15830"
CORNISH_TOWN = "15940"
COTTONWOOD_HEIGHTS_CITY = "16270"
COVE_CDP = "16490"
DAMMERON_VALLEY_CDP = "18090"
DANIEL_TOWN = "18140"
DELTA_CITY = "18910"
DESERET_CDP = "19020"
DEWEYVILLE_TOWN = "19680"
DRAPER_CITY = "20120"
DUCHESNE_CITY = "20340"
DUGWAY_CDP = "20450"
DUTCH_JOHN_TOWN = "20780"
EAGLE_MOUNTAIN_CITY = "20810"
EAST_BASIN_CDP = "20850"
EAST_CARBON_CITY = "20890"
ECHO_CDP = "21880"
EDEN_CDP = "21990"
ELBERTA_CDP = "22210"
ELK_RIDGE_CITY = "22370"
ELMO_TOWN = "22540"
ELSINORE_TOWN = "22650"
ELWOOD_TOWN = "22760"
EMERY_TOWN = "22870"
EMIGRATION_CANYON_METRO_TOWNSHIP = "22875"
ENOCH_CITY = "23200"
ENTERPRISE_CDP = "23310"
ENTERPRISE_CITY = "23420"
EPHRAIM_CITY = "23530"
ERDA_CDP = "23640"
ESCALANTE_CITY = "23750"
EUREKA_CITY = "24080"
FAIRFIELD_TOWN = "24410"
FAIRVIEW_CITY = "24630"
FARMINGTON_CITY = "24740"
FARR_WEST_CITY = "24850"
FAYETTE_TOWN = "25070"
FERRON_CITY = "25180"
FIELDING_TOWN = "25290"
FILLMORE_CITY = "25510"
FLAMING_GORGE_CDP = "25910"
FORT_DUCHESNE_CDP = "26610"
FOUNTAIN_GREEN_CITY = "26720"
FRANCIS_TOWN = "26940"
FREMONT_CDP = "27270"
FRUIT_HEIGHTS_CITY = "27490"
GARDEN_CDP = "27902"
GARDEN_CITY_TOWN = "27930"
GARLAND_CITY = "28150"
GENOLA_TOWN = "28810"
GLENDALE_TOWN = "29360"
GLENWOOD_TOWN = "29580"
GOSHEN_TOWN = "30130"
GRANITE_CDP = "30900"
GRANTSVILLE_CITY = "31120"
GREEN_RIVER_CITY = "31670"
GUNNISON_CITY = "32660"
HALCHITA_CDP = "33002"
HALLS_CROSSING_CDP = "33027"
HANKSVILLE_TOWN = "33100"
HARRISVILLE_CITY = "33540"
HATCH_TOWN = "33760"
HEBER_CITY = "34200"
HELPER_CITY = "34530"
HENEFER_TOWN = "34640"
HENRIEVILLE_TOWN = "34750"
HERRIMAN_CITY = "34970"
HIDEOUT_TOWN = "35120"
HIGHLAND_CITY = "35190"
HILDALE_CITY = "35300"
HINCKLEY_TOWN = "35740"
HOBBLE_CREEK_CDP = "35823"
HOLDEN_TOWN = "35960"
HOLLADAY_CITY = "36070"
HONEYVILLE_CITY = "36290"
HOOPER_CITY = "36400"
HOWELL_TOWN = "36620"
HOYTSVILLE_CDP = "36730"
HUNTINGTON_CITY = "36950"
HUNTSVILLE_TOWN = "37060"
HURRICANE_CITY = "37170"
HYDE_PARK_CITY = "37390"
HYRUM_CITY = "37500"
INDEPENDENCE_TOWN = "37690"
INTERLAKEN_TOWN = "37924"
IVINS_CITY = "38710"
JENSEN_CDP = "39040"
JOSEPH_TOWN = "39370"
JUNCTION_TOWN = "39590"
KAMAS_CITY = "39810"
KANAB_CITY = "39920"
KANARRAVILLE_TOWN = "40030"
KANOSH_TOWN = "40250"
KAYSVILLE_CITY = "40360"
KEARNS_METRO_TOWNSHIP = "40470"
KENILWORTH_CDP = "41020"
KINGSTON_TOWN = "41350"
KOOSHAREM_TOWN = "41680"
LA_SAL_CDP = "43110"
LA_VERKIN_CITY = "43440"
LAKE_SHORE_CDP = "42230"
LAKETOWN_TOWN = "42560"
LAPOINT_CDP = "42890"
LAYTON_CITY = "43660"
LEAMINGTON_TOWN = "43880"
LEEDS_TOWN = "44100"
LEHI_CITY = "44320"
LEVAN_TOWN = "44650"
LEWISTON_CITY = "44760"
LIBERTY_CDP = "44870"
LINDON_CITY = "45090"
LOA_TOWN = "45530"
LOGAN_CITY = "45860"
LYMAN_TOWN = "46410"
LYNNDYL_TOWN = "46740"
MAESER_CDP = "47180"
MAGNA_METRO_TOWNSHIP = "47290"
MANILA_TOWN = "47620"
MANTI_CITY = "47730"
MANTUA_TOWN = "47840"
MAPLETON_CITY = "47950"
MARION_CDP = "48170"
MARRIOTT_SLATERVILLE_CITY = "48300"
MARYSVALE_TOWN = "48610"
MAYFIELD_TOWN = "48720"
MEADOW_TOWN = "48830"
MENDON_CITY = "49160"
MEXICAN_HAT_CDP = "49380"
MIDVALE_CITY = "49710"
MIDWAY_CITY = "49820"
MILFORD_CITY = "50040"
MILLCREEK_CITY = "50150"
MILLVILLE_CITY = "50370"
MINERSVILLE_TOWN = "50590"
MOAB_CITY = "50700"
MODENA_CDP = "50810"
MONA_CITY = "51140"
MONROE_CITY = "51360"
MONTEZUMA_CREEK_CDP = "51470"
MONTICELLO_CITY = "51580"
MORGAN_CITY = "51910"
MORONI_CITY = "52130"
MOUNT_PLEASANT_CITY = "53010"
MOUNTAIN_GREEN_CDP = "52460"
MURRAY_CITY = "53230"
MYTON_CITY = "53340"
NAPLES_CITY = "53560"
NAVAJO_MOUNTAIN_CDP = "53890"
NEOLA_CDP = "54110"
NEPHI_CITY = "54220"
NEW_HARMONY_TOWN = "54440"
NEWCASTLE_CDP = "54330"
NEWTON_TOWN = "54550"
NIBLEY_CITY = "54660"
NORTH_LOGAN_CITY = "54990"
NORTH_OGDEN_CITY = "55100"
NORTH_SALT_LAKE_CITY = "55210"
OAK_CITY_TOWN = "55430"
OAKLEY_CITY = "55650"
OASIS_CDP = "55760"
OGDEN_CITY = "55980"
OLJATO_MONUMENT_VALLEY_CDP = "56440"
OPHIR_CDP = "56750"
ORANGEVILLE_CITY = "56860"
ORDERVILLE_TOWN = "57080"
OREM_CITY = "57300"
PALMYRA_CDP = "57630"
PANGUITCH_CITY = "57740"
PARADISE_TOWN = "57850"
PARAGONAH_TOWN = "57960"
PARK_CITY_CITY = "58070"
PAROWAN_CITY = "58510"
PAYSON_CITY = "58730"
PEOA_CDP = "59280"
PERRY_CITY = "59390"
PETER_CDP = "59555"
PINE_VALLEY_CDP = "60270"
PLAIN_CITY_CITY = "60710"
PLEASANT_GROVE_CITY = "60930"
PLEASANT_VIEW_CITY = "61150"
PLYMOUTH_TOWN = "61260"
PORTAGE_TOWN = "61590"
PRICE_CITY = "62030"
PROVIDENCE_CITY = "62360"
PROVO_CITY = "62470"
RANDLETT_CDP = "62910"
RANDOLPH_TOWN = "63020"
REDMOND_TOWN = "63240"
RICHFIELD_CITY = "63570"
RICHMOND_CITY = "63680"
RIVER_HEIGHTS_CITY = "64120"
RIVERDALE_CITY = "64010"
RIVERSIDE_CDP = "64230"
RIVERTON_CITY = "64340"
ROCKVILLE_TOWN = "64560"
ROCKY_RIDGE_TOWN = "64590"
ROOSEVELT_CITY = "64670"
ROY_CITY = "65110"
RUSH_VALLEY_TOWN = "65240"
SALEM_CITY = "65770"
SALINA_CITY = "65880"
SALT_LAKE_CITY_CITY = "67000"
SAMAK_CDP = "67400"
SANDY_CITY = "67440"
SANTA_CLARA_CITY = "67660"
SANTAQUIN_CITY = "67770"
SARATOGA_SPRINGS_CITY = "67825"
SCIPIO_TOWN = "67880"
SCOFIELD_TOWN = "67990"
SIGURD_TOWN = "68650"
SILVER_SUMMIT_CDP = "69280"
SMITHFIELD_CITY = "69640"
SNOWVILLE_TOWN = "69970"
SNYDERVILLE_CDP = "70190"
SOUTH_JORDAN_CITY = "70850"
SOUTH_OGDEN_CITY = "70960"
SOUTH_SALT_LAKE_CITY = "71070"
SOUTH_WEBER_CITY = "71180"
SOUTH_WILLARD_CDP = "71255"
SPANISH_FORK_CITY = "71290"
SPANISH_VALLEY_CDP = "71455"
SPRING_CITY_CITY = "71730"
SPRING_GLEN_CDP = "72060"
SPRING_LAKE_CDP = "72170"
SPRINGDALE_TOWN = "71840"
SPRINGVILLE_CITY = "72280"
ST_GEORGE_CITY = "65330"
STANSBURY_PARK_CDP = "72720"
STERLING_TOWN = "72940"
STOCKTON_TOWN = "73050"
SUMMIT_CDP = "74040"
SUMMIT_PARK_CDP = "74095"
SUNDANCE_CDP = "74260"
SUNSET_CITY = "74480"
SUTHERLAND_CDP = "74590"
SYRACUSE_CITY = "74810"
TABIONA_TOWN = "74920"
TAYLORSVILLE_CITY = "75360"
TEASDALE_CDP = "75470"
THATCHER_CDP = "75800"
THOMPSON_SPRINGS_CDP = "76180"
TIMBER_LAKES_CDP = "76280"
TOOELE_CITY = "76680"
TOQUERVILLE_CITY = "76900"
TORREY_TOWN = "77010"
TREMONTON_CITY = "77120"
TRENTON_TOWN = "77230"
TROPIC_TOWN = "77560"
TSELAKAI_DEZZA_CDP = "77697"
UINTAH_TOWN = "77890"
VERNAL_CITY = "80090"
VERNON_TOWN = "80200"
VEYO_CDP = "80310"
VINEYARD_TOWN = "80420"
VIRGIN_TOWN = "80530"
WALES_TOWN = "80860"
WALLSBURG_TOWN = "80970"
WANSHIP_CDP = "81190"
WASHINGTON_TERRACE_CITY = "82070"
WASHINGTON_CITY = "81960"
WELLINGTON_CITY = "82510"
WELLSVILLE_CITY = "82620"
WENDOVER_CITY = "82730"
WEST_BOUNTIFUL_CITY = "82840"
WEST_HAVEN_CITY = "82930"
WEST_JORDAN_CITY = "82950"
WEST_MOUNTAIN_CDP = "83252"
WEST_POINT_CITY = "83390"
WEST_VALLEY_CITY_CITY = "83470"
WEST_WOOD_CDP = "83730"
WHITE_CITY_METRO_TOWNSHIP = "84050"
WHITE_MESA_CDP = "84095"
WHITEROCKS_CDP = "84160"
WILLARD_CITY = "84710"
WOLF_CREEK_CDP = "84950"
WOODLAND_CDP = "85040"
WOODLAND_HILLS_CITY = "85050"
WOODRUFF_TOWN = "85260"
WOODS_CROSS_CITY = "85370"
