# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Washington."""


ABERDEEN_GARDENS_CDP = "00135"
ABERDEEN_CITY = "00100"
ACME_CDP = "00275"
ADDY_CDP = "00380"
AHTANUM_CDP = "00800"
AIRWAY_HEIGHTS_CITY = "00905"
ALBION_TOWN = "01010"
ALDER_CDP = "01045"
ALDERTON_CDP = "01150"
ALDERWOOD_MANOR_CDP = "01185"
ALGER_CDP = "01255"
ALGONA_CITY = "01290"
ALLYN_CDP = "01430"
ALMIRA_TOWN = "01500"
ALTOONA_CDP = "01745"
AMANDA_PARK_CDP = "01780"
AMBOY_CDP = "01850"
AMES_LAKE_CDP = "01920"
ANACORTES_CITY = "01990"
ANATONE_CDP = "02025"
ANDERSON_ISLAND_CDP = "02060"
ARLINGTON_HEIGHTS_CDP = "02620"
ARLINGTON_CITY = "02585"
ARTONDALE_CDP = "02910"
ASHFORD_CDP = "03005"
ASOTIN_CITY = "03075"
AUBURN_CITY = "03180"
BAINBRIDGE_ISLAND_CITY = "03736"
BANGOR_BASE_CDP = "04100"
BANKS_LAKE_SOUTH_CDP = "04125"
BARBERTON_CDP = "04195"
BARING_CDP = "04300"
BARNEYS_JUNCTION_CDP = "04347"
BARSTOW_CDP = "04370"
BASIN_CITY_CDP = "04405"
BATTLE_GROUND_CITY = "04475"
BAY_CENTER_CDP = "04615"
BAY_VIEW_CDP = "04790"
BEACON_HILL_CDP = "04825"
BEAUX_ARTS_VILLAGE_TOWN = "04895"
BELFAIR_CDP = "05140"
BELL_HILL_CDP = "05245"
BELLEVUE_CITY = "05210"
BELLINGHAM_CITY = "05280"
BENTON_CITY_CITY = "05560"
BETHEL_CDP = "05735"
BEVERLY_CDP = "05770"
BICKLETON_CDP = "05980"
BIG_LAKE_CDP = "06050"
BINGEN_CITY = "06085"
BIRCH_BAY_CDP = "06190"
BLACK_DIAMOND_CITY = "06330"
BLAINE_CITY = "06505"
BLYN_CDP = "06855"
BONNEY_LAKE_CITY = "07170"
BOTHELL_EAST_CDP = "07390"
BOTHELL_WEST_CDP = "07395"
BOTHELL_CITY = "07380"
BOULEVARD_PARK_CDP = "07397"
BOW_CDP = "07450"
BOYDS_CDP = "07485"
BRADY_CDP = "07590"
BREMERTON_CITY = "07695"
BREWSTER_CITY = "07835"
BRIDGEPORT_CITY = "07870"
BRIER_CITY = "07940"
BRINNON_CDP = "08080"
BROWNS_POINT_CDP = "08325"
BRUSH_PRAIRIE_CDP = "08465"
BRYANT_CDP = "08500"
BRYN_MAWR_SKYWAY_CDP = "08552"
BUCKLEY_CITY = "08570"
BUCODA_TOWN = "08605"
BUENA_CDP = "08640"
BUNK_FOSS_CDP = "08770"
BURBANK_CDP = "08780"
BURIEN_CITY = "08850"
BURLEY_CDP = "08885"
BURLINGTON_CITY = "08920"
CAMANO_CDP = "09365"
CAMAS_CITY = "09480"
CANTERWOOD_CDP = "09810"
CANYON_CREEK_CDP = "09820"
CARBONADO_TOWN = "09970"
CARLSBORG_CDP = "10075"
CARNATION_CITY = "10215"
CARSON_CDP = "10320"
CASCADE_VALLEY_CDP = "10455"
CASHMERE_CITY = "10495"
CASTLE_ROCK_CITY = "10565"
CATHCART_CDP = "10600"
CATHLAMET_TOWN = "10635"
CAVALERO_CDP = "10645"
CENTERVILLE_CDP = "11090"
CENTRAL_PARK_CDP = "11195"
CENTRALIA_CITY = "11160"
CHAIN_LAKE_CDP = "11325"
CHEHALIS_CITY = "11475"
CHELAN_FALLS_CDP = "11685"
CHELAN_CITY = "11615"
CHENEY_CITY = "11825"
CHERRY_GROVE_CDP = "12015"
CHEWELAH_CITY = "12140"
CHICO_CDP = "12175"
CHINOOK_CDP = "12315"
CLALLAM_BAY_CDP = "12525"
CLARKSTON_HEIGHTS_VINELAND_CDP = "12680"
CLARKSTON_CITY = "12630"
CLAYTON_CDP = "12735"
CLE_ELUM_CITY = "12945"
CLEAR_LAKE_CDP_PIERCE_COUNTY = "12820"
CLEAR_LAKE_CDP_SKAGIT_COUNTY = "12840"
CLEARVIEW_CDP = "12875"
CLIFFDELL_CDP = "13015"
CLINTON_CDP = "13155"
CLOVER_CREEK_CDP = "13215"
CLYDE_HILL_CITY = "13365"
COHASSETT_BEACH_CDP = "13595"
COLFAX_CITY = "13785"
COLLEGE_PLACE_CITY = "13855"
COLTON_TOWN = "13890"
COLVILLE_CITY = "14170"
CONCONULLY_TOWN = "14310"
CONCRETE_TOWN = "14380"
CONNELL_CITY = "14485"
CONWAY_CDP = "14520"
COPALIS_BEACH_CDP = "14660"
COSMOPOLIS_CITY = "14870"
COTTAGE_LAKE_CDP = "14940"
COUGAR_CDP = "15010"
COULEE_CITY_TOWN = "15080"
COULEE_DAM_TOWN = "15115"
COUNTRY_HOMES_CDP = "15150"
COUPEVILLE_TOWN = "15185"
COVINGTON_CITY = "15290"
COWICHE_CDP = "15325"
CRESCENT_BAR_CDP = "15603"
CRESTON_TOWN = "15710"
CROCKER_CDP = "15780"
CURLEW_CDP = "16165"
CURLEW_LAKE_CDP = "16170"
CUSICK_TOWN = "16340"
CUSTER_CDP = "16375"
DALLESPORT_CDP = "16550"
DANVILLE_CDP = "16585"
DARRINGTON_TOWN = "16690"
DASH_POINT_CDP = "16760"
DAVENPORT_CITY = "16795"
DAYTON_CITY = "16970"
DEEP_RIVER_CDP = "17215"
DEER_PARK_CITY = "17320"
DEMING_CDP = "17495"
DES_MOINES_CITY = "17635"
DESERT_AIRE_CDP = "17617"
DISAUTEL_CDP = "17880"
DIXIE_CDP = "18055"
DOLLARS_CORNER_CDP = "18198"
DONALD_CDP = "18265"
DUPONT_CITY = "18965"
DULUTH_CDP = "18775"
DUVALL_CITY = "19035"
EAST_CATHLAMET_CDP = "19290"
EAST_PORT_ORCHARD_CDP = "19770"
EAST_RENTON_HIGHLANDS_CDP = "19857"
EAST_WENATCHEE_CITY = "20155"
EASTMONT_CDP = "19630"
EASTON_CDP = "19700"
EATONVILLE_TOWN = "20260"
EDGEWOOD_CITY = "20645"
EDISON_CDP = "20680"
EDMONDS_CITY = "20750"
ELBE_CDP = "20890"
ELECTRIC_CITY_CITY = "21030"
ELK_PLAIN_CDP = "21205"
ELLENSBURG_CITY = "21240"
ELMA_CITY = "21450"
ELMER_CITY_TOWN = "21485"
ENDICOTT_TOWN = "21730"
ENETAI_CDP = "21800"
ENTIAT_CITY = "22010"
ENUMCLAW_CITY = "22045"
EPHRATA_CITY = "22080"
ERLANDS_POINT_CDP = "22115"
ESCHBACH_CDP = "22150"
ESPERANCE_CDP = "22255"
EVERETT_CITY = "22640"
EVERSON_CITY = "22745"
FAIRCHILD_AFB_CDP = "22955"
FAIRFIELD_TOWN = "22990"
FAIRWOOD_CDP_KING_COUNTY = "23160"
FAIRWOOD_CDP_SPOKANE_COUNTY = "23165"
FALL_CITY_CDP = "23200"
FARMINGTON_TOWN = "23340"
FEDERAL_WAY_CITY = "23515"
FELIDA_CDP = "23550"
FERN_PRAIRIE_CDP = "23690"
FERNDALE_CITY = "23620"
FIFE_HEIGHTS_CDP = "23830"
FIFE_CITY = "23795"
FINLEY_CDP = "23865"
FIRCREST_CITY = "23970"
FIVE_CORNERS_CDP = "24188"
FOBES_HILL_CDP = "24425"
FORDS_PRAIRIE_CDP = "24565"
FORKS_CITY = "24810"
FORT_LEWIS_CDP = "24915"
FOUR_LAKES_CDP = "25300"
FOX_ISLAND_CDP = "25370"
FREDERICKSON_CDP = "25475"
FREELAND_CDP = "25510"
FRIDAY_HARBOR_TOWN = "25615"
GARFIELD_TOWN = "26140"
GARRETT_CDP = "26245"
GENEVA_CDP = "26420"
GEORGE_CITY = "26455"
GIG_HARBOR_CITY = "26735"
GLACIER_CDP = "26875"
GLEED_CDP = "26945"
GLENWOOD_CDP = "27225"
GOLD_BAR_CITY = "27365"
GOLDENDALE_CITY = "27435"
GORST_CDP = "27680"
GRAHAM_CDP = "27785"
GRAND_COULEE_CITY = "27855"
GRAND_MOUND_CDP = "27890"
GRANDVIEW_CITY = "27925"
GRANGER_CITY = "27960"
GRANITE_FALLS_CITY = "27995"
GRAPEVIEW_CDP = "28135"
GRAYLAND_CDP = "28345"
GRAYS_RIVER_CDP = "28450"
GREEN_BLUFF_CDP = "28590"
GREENWATER_CDP = "28695"
HAMILTON_TOWN = "29255"
HANSVILLE_CDP = "29430"
HARRAH_TOWN = "29710"
HARRINGTON_CITY = "29745"
HARTLINE_TOWN = "29920"
HAT_ISLAND_CDP = "30030"
HATTON_TOWN = "30060"
HAZEL_DELL_CDP = "30305"
HERRON_ISLAND_CDP = "30690"
HIGH_BRIDGE_CDP = "30750"
HOBART_CDP = "31495"
HOCKINSON_CDP = "31530"
HOGANS_CORNER_CDP = "31540"
HOME_CDP = "31985"
HOODSPORT_CDP = "32125"
HOQUIAM_CITY = "32300"
HUMPTULIPS_CDP = "32650"
HUNTS_POINT_TOWN = "32755"
ILWACO_CITY = "33000"
INCHELIUM_CDP = "33105"
INDEX_TOWN = "33175"
INDIANOLA_CDP = "33280"
IONE_TOWN = "33560"
ISSAQUAH_CITY = "33805"
JAMESTOWN_CDP = "33890"
KAHLOTUS_CITY = "34575"
KALAMA_CITY = "34645"
KAPOWSIN_CDP = "34890"
KAYAK_POINT_CDP = "34915"
KELLER_CDP = "34960"
KELSO_CITY = "35065"
KENDALL_CDP = "35135"
KENMORE_CITY = "35170"
KENNEWICK_CITY = "35275"
KENT_CITY = "35415"
KETRON_ISLAND_CDP = "35450"
KETTLE_FALLS_CITY = "35485"
KEY_CENTER_CDP = "35555"
KEYPORT_CDP = "35625"
KINGSTON_CDP = "35870"
KIRKLAND_CITY = "35940"
KITSAP_LAKE_CDP = "36010"
KITTITAS_CITY = "36045"
KLICKITAT_CDP = "36115"
KRUPP_TOWN = "36395"
LA_CENTER_CITY = "36710"
LA_CONNER_TOWN = "36780"
LA_GRANDE_CDP = "36920"
LACROSSE_TOWN = "36850"
LACEY_CITY = "36745"
LAKE_BOSWORTH_CDP = "37077"
LAKE_CASSIDY_CDP = "37100"
LAKE_CAVANAUGH_CDP = "37105"
LAKE_FOREST_PARK_CITY = "37270"
LAKE_GOODWIN_CDP = "37287"
LAKE_HOLM_CDP = "37345"
LAKE_KETCHUM_CDP = "37415"
LAKE_MARCEL_STILLWATER_CDP = "37538"
LAKE_MCMURRAY_CDP = "37526"
LAKE_MORTON_BERRYDALE_CDP = "37567"
LAKE_ROESIGER_CDP = "37672"
LAKE_SHORE_CDP = "37830"
LAKE_STEVENS_CITY = "37900"
LAKE_STICKNEY_CDP = "37917"
LAKE_TAPPS_CDP = "37920"
LAKELAND_NORTH_CDP = "37420"
LAKELAND_SOUTH_CDP = "37430"
LAKEVIEW_CDP = "37926"
LAKEWOOD_CITY = "38038"
LAMONT_TOWN = "38215"
LANGLEY_CITY = "38355"
LARCH_WAY_CDP = "38420"
LATAH_TOWN = "38495"
LAURIER_CDP = "38705"
LEAVENWORTH_CITY = "38845"
LEBAM_CDP = "38880"
LEWISVILLE_CDP = "39212"
LEXINGTON_CDP = "39230"
LIBERTY_LAKE_CITY = "39335"
LIND_TOWN = "39510"
LOCHSLOY_CDP = "39860"
LOFALL_CDP = "39930"
LONG_BEACH_CITY = "40070"
LONGBRANCH_CDP = "40105"
LONGVIEW_HEIGHTS_CDP = "40270"
LONGVIEW_CITY = "40245"
LOOMIS_CDP = "40350"
LOON_LAKE_CDP = "40385"
LOWER_ELOCHOMAN_CDP = "40570"
LYLE_CDP = "40735"
LYMAN_TOWN = "40770"
LYNDEN_CITY = "40805"
LYNNWOOD_CITY = "40840"
MABTON_CITY = "40980"
MACHIAS_CDP = "41470"
MALDEN_TOWN = "42275"
MALO_CDP = "42310"
MALONE_CDP = "42345"
MALOTT_CDP = "42380"
MALTBY_CDP = "42415"
MANCHESTER_CDP = "42450"
MANSFIELD_TOWN = "42800"
MANSON_CDP = "42835"
MAPLE_FALLS_CDP = "43010"
MAPLE_HEIGHTS_LAKE_DESIRE_CDP = "43062"
MAPLE_VALLEY_CITY = "43150"
MAPLEWOOD_CDP = "43255"
MARBLEMOUNT_CDP = "43325"
MARCUS_TOWN = "43395"
MARIETTA_ALDERWOOD_CDP = "43491"
MARINE_VIEW_CDP = "43552"
MARKHAM_CDP = "43640"
MARROWSTONE_CDP = "43762"
MARTHA_LAKE_CDP = "43815"
MARYHILL_CDP = "43885"
MARYSVILLE_CITY = "43955"
MATTAWA_CITY = "44165"
MAY_CREEK_CDP = "44260"
MCCHORD_AFB_CDP = "41155"
MCCLEARY_CITY = "41225"
MCKENNA_CDP = "41645"
MCMILLIN_CDP = "41785"
MEAD_CDP = "44480"
MEADOW_GLADE_CDP = "44620"
MEADOWDALE_CDP = "44585"
MEDICAL_LAKE_CITY = "44690"
MEDINA_CITY = "44725"
MERCER_ISLAND_CITY = "45005"
MESA_CITY = "45180"
METALINE_FALLS_TOWN = "45320"
METALINE_TOWN = "45285"
METHOW_CDP = "45355"
MIDLAND_CDP = "45495"
MILL_CREEK_EAST_CDP = "45870"
MILL_CREEK_CITY = "45865"
MILLWOOD_CITY = "45985"
MILTON_CITY = "46020"
MINERAL_CDP = "46090"
MINNEHAHA_CDP = "46125"
MIRRORMONT_CDP = "46215"
MOCLIPS_CDP = "46405"
MONROE_NORTH_CDP = "46725"
MONROE_CITY = "46685"
MONTESANO_CITY = "46895"
MORTON_CITY = "47175"
MOSES_LAKE_NORTH_CDP = "47280"
MOSES_LAKE_CITY = "47245"
MOSSYROCK_CITY = "47315"
MOUNT_VERNON_CITY = "47560"
MOUNT_VISTA_CDP = "47630"
MOUNTLAKE_TERRACE_CITY = "47490"
MOXEE_CITY = "47665"
MUKILTEO_CITY = "47735"
NACHES_TOWN = "47805"
NAPAVINE_CITY = "47980"
NASELLE_CDP = "48015"
NAVY_YARD_CITY_CDP = "48225"
NEAH_BAY_CDP = "48295"
NEILTON_CDP = "48330"
NESPELEM_COMMUNITY_CDP = "48550"
NESPELEM_TOWN = "48540"
NEWCASTLE_CITY = "48645"
NEWPORT_CITY = "48820"
NILE_CDP = "49030"
NISQUALLY_INDIAN_COMMUNITY_CDP = "49193"
NOOKSACK_CITY = "49275"
NORMANDY_PARK_CITY = "49415"
NORTH_BEND_CITY = "49485"
NORTH_BONNEVILLE_CITY = "49555"
NORTH_FORT_LEWIS_CDP = "49765"
NORTH_LYNNWOOD_CDP = "49940"
NORTH_OMAK_CDP = "50007"
NORTH_PUYALLUP_CDP = "50115"
NORTH_SULTAN_CDP = "50183"
NORTH_YELM_CDP = "50210"
NORTHPORT_TOWN = "50045"
NORTHWEST_STANWOOD_CDP = "50195"
OAK_HARBOR_CITY = "50360"
OAKESDALE_TOWN = "50325"
OAKVILLE_CITY = "50430"
OCEAN_CITY_CDP = "50500"
OCEAN_PARK_CDP = "50535"
OCEAN_SHORES_CITY = "50570"
OCOSTA_CDP = "50675"
ODESSA_TOWN = "50745"
OKANOGAN_CITY = "50920"
OLYMPIA_CITY = "51300"
OMAK_CITY = "51340"
ONALASKA_CDP = "51410"
ORCHARDS_CDP = "51795"
ORIENT_CDP = "51830"
OROVILLE_CITY = "51970"
ORTING_CITY = "52005"
OSO_CDP = "52110"
OTHELLO_CITY = "52215"
OTIS_ORCHARDS_EAST_FARMS_CDP = "52267"
OUTLOOK_CDP = "52285"
OYEHUT_CDP = "52378"
PACIFIC_BEACH_CDP = "52530"
PACIFIC_CITY = "52495"
PACKWOOD_CDP = "52600"
PALOUSE_CITY = "52950"
PARKER_CDP = "53265"
PARKLAND_CDP = "53335"
PARKWOOD_CDP = "53440"
PASCO_CITY = "53545"
PATAHA_CDP = "53660"
PATEROS_CITY = "53720"
PE_ELL_TOWN = "53930"
PEACEFUL_VALLEY_CDP = "53800"
PICNIC_POINT_CDP = "54213"
PINE_GROVE_CDP = "54405"
POINT_ROBERTS_CDP = "55015"
POMEROY_CITY = "55120"
PORT_ANGELES_EAST_CDP = "55400"
PORT_ANGELES_CITY = "55365"
PORT_GAMBLE_TRIBAL_COMMUNITY_CDP = "55612"
PORT_HADLOCK_IRONDALE_CDP = "55620"
PORT_LUDLOW_CDP = "55645"
PORT_ORCHARD_CITY = "55785"
PORT_TOWNSEND_CITY = "55855"
PORTER_CDP = "55540"
POULSBO_CITY = "55995"
PRAIRIE_HEIGHTS_CDP = "56150"
PRAIRIE_RIDGE_CDP = "56170"
PRESCOTT_CITY = "56240"
PROSSER_CITY = "56450"
PUGET_ISLAND_CDP = "56555"
PULLMAN_CITY = "56625"
PURDY_CDP = "56660"
PUYALLUP_CITY = "56695"
QUEETS_CDP = "56905"
QUI_NAI_ELT_VILLAGE_CDP = "57030"
QUILCENE_CDP = "56975"
QUINCY_CITY = "57115"
RAFT_ISLAND_CDP = "57140"
RAINIER_CITY = "57220"
RAVENSDALE_CDP = "57395"
RAYMOND_CITY = "57430"
REARDAN_TOWN = "57465"
REDMOND_CITY = "57535"
RENTON_CITY = "57745"
REPUBLIC_CITY = "57850"
RICHLAND_CITY = "58235"
RIDGEFIELD_CITY = "58410"
RITZVILLE_CITY = "58725"
RIVER_ROAD_CDP = "58777"
RIVERBEND_CDP = "58742"
RIVERPOINT_CDP = "58768"
RIVERSIDE_TOWN = "58795"
ROCHE_HARBOR_CDP = "59075"
ROCHESTER_CDP = "59110"
ROCK_ISLAND_CITY = "59180"
ROCKFORD_TOWN = "59145"
ROCKPORT_CDP = "59250"
ROCKY_POINT_CDP = "59390"
RONALD_CDP = "59635"
ROOSEVELT_CDP = "59705"
ROSALIA_TOWN = "59775"
ROSBURG_CDP = "59845"
ROSEDALE_CDP = "59880"
ROSLYN_CITY = "60055"
ROY_CITY = "60160"
ROYAL_CITY_CITY = "60230"
RUSTON_CITY = "60510"
RYDERWOOD_CDP = "60580"
SALMON_CREEK_CDP = "61000"
SAMMAMISH_CITY = "61115"
SANTIAGO_CDP = "61235"
SATSOP_CDP = "61350"
SCHWANA_CDP = "61925"
SEATAC_CITY = "62288"
SEABECK_CDP = "62120"
SEATTLE_CITY = "63000"
SEDRO_WOOLLEY_CITY = "63210"
SEKIU_CDP = "63245"
SELAH_CITY = "63280"
SEQUIM_CITY = "63385"
SHADOW_LAKE_CDP = "63545"
SHELTON_CITY = "63735"
SHORELINE_CITY = "63960"
SILVANA_CDP = "64190"
SILVER_FIRS_CDP = "64380"
SILVERDALE_CDP = "64365"
SISCO_HEIGHTS_CDP = "64610"
SKAMOKAWA_VALLEY_CDP = "64755"
SKOKOMISH_CDP = "64775"
SKYKOMISH_TOWN = "64855"
SNOHOMISH_CITY = "65170"
SNOQUALMIE_PASS_CDP = "65275"
SNOQUALMIE_CITY = "65205"
SOAP_LAKE_CITY = "65345"
SOUTH_BEND_CITY = "65625"
SOUTH_CLE_ELUM_TOWN = "65765"
SOUTH_CREEK_CDP = "65810"
SOUTH_HILL_CDP = "65922"
SOUTH_PRAIRIE_TOWN = "66045"
SOUTH_WENATCHEE_CDP = "66185"
SOUTHWORTH_CDP = "66220"
SPANAWAY_CDP = "66255"
SPANGLE_CITY = "66290"
SPOKANE_VALLEY_CITY = "67167"
SPOKANE_CITY = "67000"
SPRAGUE_CITY = "67175"
SPRINGDALE_TOWN = "67210"
ST_JOHN_TOWN = "60860"
STANSBERRY_LAKE_CDP = "67435"
STANWOOD_CITY = "67455"
STARBUCK_TOWN = "67490"
STARTUP_CDP = "67595"
STEILACOOM_TOWN = "67770"
STEPTOE_CDP = "67805"
STEVENSON_CITY = "67875"
SUDDEN_VALLEY_CDP = "68200"
SULTAN_CITY = "68260"
SUMAS_CITY = "68330"
SUMMIT_CDP = "68365"
SUMMIT_VIEW_CDP = "68410"
SUMMITVIEW_CDP = "68417"
SUMNER_CITY = "68435"
SUNCREST_CDP = "68460"
SUNDAY_LAKE_CDP = "68480"
SUNLAND_ESTATES_CDP = "68557"
SUNNYSIDE_CITY = "68750"
SUNNYSLOPE_CDP = "68785"
SUQUAMISH_CDP = "69170"
SWEDE_HEAVEN_CDP = "69280"
TACOMA_CITY = "70000"
TAHOLAH_CDP = "70175"
TAMPICO_CDP = "70245"
TANGLEWILDE_CDP = "70280"
TEHALEH_CDP = "70543"
TEKOA_CITY = "70560"
TENINO_CITY = "70630"
TERRACE_HEIGHTS_CDP = "70805"
THORP_CDP = "71225"
THREE_LAKES_CDP = "71330"
TIETON_CITY = "71400"
TOKELAND_CDP = "71680"
TOLEDO_CITY = "71785"
TONASKET_CITY = "71890"
TOPPENISH_CITY = "71960"
TORBOY_CDP = "71995"
TOUCHET_CDP = "72030"
TOWN_AND_COUNTRY_CDP = "72170"
TRACYTON_CDP = "72205"
TROUT_LAKE_CDP = "72450"
TUKWILA_CITY = "72625"
TUMWATER_CITY = "72905"
TWIN_LAKES_CDP = "73065"
TWISP_TOWN = "73080"
UNION_CDP = "73255"
UNION_GAP_CITY = "73290"
UNION_HILL_NOVELTY_HILL_CDP = "73307"
UNIONTOWN_TOWN = "73360"
UNIVERSITY_PLACE_CITY = "73465"
UPPER_ELOCHOMAN_CDP = "73580"
VADER_CITY = "73780"
VALLEY_CDP = "73885"
VANCOUVER_CITY = "74060"
VANTAGE_CDP = "74200"
VASHON_CDP = "74305"
VAUGHN_CDP = "74445"
VENERSBORG_CDP = "74585"
VERLOT_CDP = "74760"
WAITSBURG_CITY = "75565"
WALLA_WALLA_EAST_CDP = "75810"
WALLA_WALLA_CITY = "75775"
WALLER_CDP = "75905"
WALLULA_CDP = "75985"
WAPATO_CITY = "76125"
WARDEN_CITY = "76160"
WARM_BEACH_CDP = "76195"
WASHOUGAL_CITY = "76405"
WASHTUCNA_TOWN = "76440"
WATERVILLE_TOWN = "76510"
WAUNA_CDP = "76615"
WAVERLY_TOWN = "76720"
WENATCHEE_CITY = "77105"
WEST_CLARKSTON_HIGHLAND_CDP = "77297"
WEST_PASCO_CDP = "77612"
WEST_RICHLAND_CITY = "77665"
WESTPORT_CITY = "77630"
WHEELER_CDP = "78050"
WHIDBEY_ISLAND_STATION_CDP = "78155"
WHITE_CENTER_CDP = "78225"
WHITE_SALMON_CITY = "78330"
WHITE_SWAN_CDP = "78365"
WILBUR_TOWN = "78680"
WILDERNESS_RIM_CDP = "78780"
WILKESON_TOWN = "78925"
WILLAPA_CDP = "78995"
WILSON_CREEK_TOWN = "79135"
WINLOCK_CITY = "79275"
WINTHROP_TOWN = "79380"
WISHRAM_CDP = "79485"
WOLLOCHET_CDP = "79555"
WOODINVILLE_CITY = "79590"
WOODLAND_CITY = "79625"
WOODS_CREEK_CDP = "79825"
WOODWAY_CITY = "79835"
YACOLT_TOWN = "79975"
YAKIMA_CITY = "80010"
YARROW_POINT_TOWN = "80150"
YELM_CITY = "80220"
ZILLAH_CITY = "80500"
