# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Texas."""


ANDERSON = "001"
ANDREWS = "003"
ANGELINA = "005"
ARANSAS = "007"
ARCHER = "009"
ARMSTRONG = "011"
ATASCOSA = "013"
AUSTIN = "015"
BAILEY = "017"
BANDERA = "019"
BASTROP = "021"
BAYLOR = "023"
BEE = "025"
BELL = "027"
BEXAR = "029"
BLANCO = "031"
BORDEN = "033"
BOSQUE = "035"
BOWIE = "037"
BRAZORIA = "039"
BRAZOS = "041"
BREWSTER = "043"
BRISCOE = "045"
BROOKS = "047"
BROWN = "049"
BURLESON = "051"
BURNET = "053"
CALDWELL = "055"
CALHOUN = "057"
CALLAHAN = "059"
CAMERON = "061"
CAMP = "063"
CARSON = "065"
CASS = "067"
CASTRO = "069"
CHAMBERS = "071"
CHEROKEE = "073"
CHILDRESS = "075"
CLAY = "077"
COCHRAN = "079"
COKE = "081"
COLEMAN = "083"
COLLIN = "085"
COLLINGSWORTH = "087"
COLORADO = "089"
COMAL = "091"
COMANCHE = "093"
CONCHO = "095"
COOKE = "097"
CORYELL = "099"
COTTLE = "101"
CRANE = "103"
CROCKETT = "105"
CROSBY = "107"
CULBERSON = "109"
DALLAM = "111"
DALLAS = "113"
DAWSON = "115"
DEWITT = "123"
DEAF_SMITH = "117"
DELTA = "119"
DENTON = "121"
DICKENS = "125"
DIMMIT = "127"
DONLEY = "129"
DUVAL = "131"
EASTLAND = "133"
ECTOR = "135"
EDWARDS = "137"
EL_PASO = "141"
ELLIS = "139"
ERATH = "143"
FALLS = "145"
FANNIN = "147"
FAYETTE = "149"
FISHER = "151"
FLOYD = "153"
FOARD = "155"
FORT_BEND = "157"
FRANKLIN = "159"
FREESTONE = "161"
FRIO = "163"
GAINES = "165"
GALVESTON = "167"
GARZA = "169"
GILLESPIE = "171"
GLASSCOCK = "173"
GOLIAD = "175"
GONZALES = "177"
GRAY = "179"
GRAYSON = "181"
GREGG = "183"
GRIMES = "185"
GUADALUPE = "187"
HALE = "189"
HALL = "191"
HAMILTON = "193"
HANSFORD = "195"
HARDEMAN = "197"
HARDIN = "199"
HARRIS = "201"
HARRISON = "203"
HARTLEY = "205"
HASKELL = "207"
HAYS = "209"
HEMPHILL = "211"
HENDERSON = "213"
HIDALGO = "215"
HILL = "217"
HOCKLEY = "219"
HOOD = "221"
HOPKINS = "223"
HOUSTON = "225"
HOWARD = "227"
HUDSPETH = "229"
HUNT = "231"
HUTCHINSON = "233"
IRION = "235"
JACK = "237"
JACKSON = "239"
JASPER = "241"
JEFF_DAVIS = "243"
JEFFERSON = "245"
JIM_HOGG = "247"
JIM_WELLS = "249"
JOHNSON = "251"
JONES = "253"
KARNES = "255"
KAUFMAN = "257"
KENDALL = "259"
KENEDY = "261"
KENT = "263"
KERR = "265"
KIMBLE = "267"
KING = "269"
KINNEY = "271"
KLEBERG = "273"
KNOX = "275"
LA_SALLE = "283"
LAMAR = "277"
LAMB = "279"
LAMPASAS = "281"
LAVACA = "285"
LEE = "287"
LEON = "289"
LIBERTY = "291"
LIMESTONE = "293"
LIPSCOMB = "295"
LIVE_OAK = "297"
LLANO = "299"
LOVING = "301"
LUBBOCK = "303"
LYNN = "305"
MADISON = "313"
MARION = "315"
MARTIN = "317"
MASON = "319"
MATAGORDA = "321"
MAVERICK = "323"
MCCULLOCH = "307"
MCLENNAN = "309"
MCMULLEN = "311"
MEDINA = "325"
MENARD = "327"
MIDLAND = "329"
MILAM = "331"
MILLS = "333"
MITCHELL = "335"
MONTAGUE = "337"
MONTGOMERY = "339"
MOORE = "341"
MORRIS = "343"
MOTLEY = "345"
NACOGDOCHES = "347"
NAVARRO = "349"
NEWTON = "351"
NOLAN = "353"
NUECES = "355"
OCHILTREE = "357"
OLDHAM = "359"
ORANGE = "361"
PALO_PINTO = "363"
PANOLA = "365"
PARKER = "367"
PARMER = "369"
PECOS = "371"
POLK = "373"
POTTER = "375"
PRESIDIO = "377"
RAINS = "379"
RANDALL = "381"
REAGAN = "383"
REAL = "385"
RED_RIVER = "387"
REEVES = "389"
REFUGIO = "391"
ROBERTS = "393"
ROBERTSON = "395"
ROCKWALL = "397"
RUNNELS = "399"
RUSK = "401"
SABINE = "403"
SAN_AUGUSTINE = "405"
SAN_JACINTO = "407"
SAN_PATRICIO = "409"
SAN_SABA = "411"
SCHLEICHER = "413"
SCURRY = "415"
SHACKELFORD = "417"
SHELBY = "419"
SHERMAN = "421"
SMITH = "423"
SOMERVELL = "425"
STARR = "427"
STEPHENS = "429"
STERLING = "431"
STONEWALL = "433"
SUTTON = "435"
SWISHER = "437"
TARRANT = "439"
TAYLOR = "441"
TERRELL = "443"
TERRY = "445"
THROCKMORTON = "447"
TITUS = "449"
TOM_GREEN = "451"
TRAVIS = "453"
TRINITY = "455"
TYLER = "457"
UPSHUR = "459"
UPTON = "461"
UVALDE = "463"
VAL_VERDE = "465"
VAN_ZANDT = "467"
VICTORIA = "469"
WALKER = "471"
WALLER = "473"
WARD = "475"
WASHINGTON = "477"
WEBB = "479"
WHARTON = "481"
WHEELER = "483"
WICHITA = "485"
WILBARGER = "487"
WILLACY = "489"
WILLIAMSON = "491"
WILSON = "493"
WINKLER = "495"
WISE = "497"
WOOD = "499"
YOAKUM = "501"
YOUNG = "503"
ZAPATA = "505"
ZAVALA = "507"
