# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Oregon."""


BAKER = "001"
BENTON = "003"
CLACKAMAS = "005"
CLATSOP = "007"
COLUMBIA = "009"
COOS = "011"
CROOK = "013"
CURRY = "015"
DESCHUTES = "017"
DOUGLAS = "019"
GILLIAM = "021"
GRANT = "023"
HARNEY = "025"
HOOD_RIVER = "027"
JACKSON = "029"
JEFFERSON = "031"
JOSEPHINE = "033"
KLAMATH = "035"
LAKE = "037"
LANE = "039"
LINCOLN = "041"
LINN = "043"
MALHEUR = "045"
MARION = "047"
MORROW = "049"
MULTNOMAH = "051"
POLK = "053"
SHERMAN = "055"
TILLAMOOK = "057"
UMATILLA = "059"
UNION = "061"
WALLOWA = "063"
WASCO = "065"
WASHINGTON = "067"
WHEELER = "069"
YAMHILL = "071"
