# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Mississippi."""


ADAMS = "001"
ALCORN = "003"
AMITE = "005"
ATTALA = "007"
BENTON = "009"
BOLIVAR = "011"
CALHOUN = "013"
CARROLL = "015"
CHICKASAW = "017"
CHOCTAW = "019"
CLAIBORNE = "021"
CLARKE = "023"
CLAY = "025"
COAHOMA = "027"
COPIAH = "029"
COVINGTON = "031"
DESOTO = "033"
FORREST = "035"
FRANKLIN = "037"
GEORGE = "039"
GREENE = "041"
GRENADA = "043"
HANCOCK = "045"
HARRISON = "047"
HINDS = "049"
HOLMES = "051"
HUMPHREYS = "053"
ISSAQUENA = "055"
ITAWAMBA = "057"
JACKSON = "059"
JASPER = "061"
JEFFERSON = "063"
JEFFERSON_DAVIS = "065"
JONES = "067"
KEMPER = "069"
LAFAYETTE = "071"
LAMAR = "073"
LAUDERDALE = "075"
LAWRENCE = "077"
LEAKE = "079"
LEE = "081"
LEFLORE = "083"
LINCOLN = "085"
LOWNDES = "087"
MADISON = "089"
MARION = "091"
MARSHALL = "093"
MONROE = "095"
MONTGOMERY = "097"
NESHOBA = "099"
NEWTON = "101"
NOXUBEE = "103"
OKTIBBEHA = "105"
PANOLA = "107"
PEARL_RIVER = "109"
PERRY = "111"
PIKE = "113"
PONTOTOC = "115"
PRENTISS = "117"
QUITMAN = "119"
RANKIN = "121"
SCOTT = "123"
SHARKEY = "125"
SIMPSON = "127"
SMITH = "129"
STONE = "131"
SUNFLOWER = "133"
TALLAHATCHIE = "135"
TATE = "137"
TIPPAH = "139"
TISHOMINGO = "141"
TUNICA = "143"
UNION = "145"
WALTHALL = "147"
WARREN = "149"
WASHINGTON = "151"
WAYNE = "153"
WEBSTER = "155"
WILKINSON = "157"
WINSTON = "159"
YALOBUSHA = "161"
YAZOO = "163"
