# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Maryland."""


ALLEGANY = "001"
ANNE_ARUNDEL = "003"
BALTIMORE = "005"
BALTIMORE_CITY = "510"
CALVERT = "009"
CAROLINE = "011"
CARROLL = "013"
CECIL = "015"
CHARLES = "017"
DORCHESTER = "019"
FREDERICK = "021"
GARRETT = "023"
HARFORD = "025"
HOWARD = "027"
KENT = "029"
MONTGOMERY = "031"
PRINCE_GEORGES = "033"
QUEEN_ANNES = "035"
SOMERSET = "039"
ST_MARYS = "037"
TALBOT = "041"
WASHINGTON = "043"
WICOMICO = "045"
WORCESTER = "047"
