# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in New Jersey."""


ATLANTIC = "001"
BERGEN = "003"
BURLINGTON = "005"
CAMDEN = "007"
CAPE_MAY = "009"
CUMBERLAND = "011"
ESSEX = "013"
GLOUCESTER = "015"
HUDSON = "017"
HUNTERDON = "019"
MERCER = "021"
MIDDLESEX = "023"
MONMOUTH = "025"
MORRIS = "027"
OCEAN = "029"
PASSAIC = "031"
SALEM = "033"
SOMERSET = "035"
SUSSEX = "037"
UNION = "039"
WARREN = "041"
