# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Georgia."""


ABBEVILLE_CITY = "00184"
ACWORTH_CITY = "00408"
ADAIRSVILLE_CITY = "00436"
ADEL_CITY = "00576"
ADRIAN_CITY = "00660"
AILEY_CITY = "00828"
ALAMO_TOWN = "00996"
ALAPAHA_TOWN = "01024"
ALBANY_CITY = "01052"
ALDORA_TOWN = "01248"
ALLENHURST_CITY = "01472"
ALLENTOWN_CITY = "01500"
ALMA_CITY = "01612"
ALPHARETTA_CITY = "01696"
ALSTON_TOWN = "01808"
ALTO_TOWN = "01948"
AMBROSE_CITY = "02060"
AMERICUS_CITY = "02116"
ANDERSONVILLE_CITY = "02256"
ANTIOCH_CDP = "02364"
APPLING_CDP = "02536"
ARABI_TOWN = "02564"
ARAGON_CITY = "02592"
ARCADE_CITY = "02648"
ARGYLE_TOWN = "02844"
ARLINGTON_CITY = "02928"
ARNOLDSVILLE_CITY = "03124"
ASHBURN_CITY = "03236"
ATHENS_CLARKE_COUNTY_UNIFIED_GOVERNMENT_BALANCE = "03440"
ATLANTA_CITY = "04000"
ATTAPULGUS_CITY = "04084"
AUBURN_CITY = "04140"
AUGUSTA_RICHMOND_COUNTY_CONSOLIDATED_GOVERNMENT_BALANCE = "04204"
AUSTELL_CITY = "04252"
AVALON_TOWN = "04392"
AVERA_CITY = "04448"
AVONDALE_ESTATES_CITY = "04644"
AXSON_CDP = "04700"
BACONTON_CITY = "04840"
BAINBRIDGE_CITY = "04896"
BALDWIN_CITY = "04980"
BALL_GROUND_CITY = "05036"
BARNESVILLE_CITY = "05344"
BARTOW_TOWN = "05680"
BARWICK_CITY = "05708"
BAXLEY_CITY = "06016"
BELLVILLE_CITY = "06688"
BELVEDERE_PARK_CDP = "06884"
BEMISS_CDP = "06968"
BERKELEY_LAKE_CITY = "07248"
BERLIN_CITY = "07304"
BERRY_COLLEGE_CDP = "07380"
BETHLEHEM_TOWN = "07612"
BETWEEN_TOWN = "07640"
BISHOP_TOWN = "08200"
BLACKSHEAR_CITY = "08284"
BLAIRSVILLE_CITY = "08480"
BLAKELY_CITY = "08536"
BLOOMINGDALE_CITY = "08844"
BLUE_RIDGE_CITY = "08928"
BLUFFTON_TOWN = "08956"
BLYTHE_CITY = "09040"
BOGART_TOWN = "09068"
BOLINGBROKE_CDP = "09152"
BONANZA_CDP = "09272"
BOSTON_CITY = "09460"
BOSTWICK_CITY = "09488"
BOWDON_CITY = "09544"
BOWERSVILLE_TOWN = "09656"
BOWMAN_CITY = "09712"
BOX_SPRINGS_CDP = "09768"
BOYKIN_CDP = "09852"
BRASELTON_TOWN = "10076"
BRASWELL_TOWN = "10104"
BREMEN_CITY = "10132"
BRINSON_TOWN = "10608"
BRISTOL_CDP = "10664"
BRONWOOD_TOWN = "10860"
BROOKHAVEN_CITY = "10944"
BROOKLET_CITY = "11000"
BROOKS_TOWN = "11056"
BROXTON_CITY = "11504"
BRUNSWICK_CITY = "11560"
BUCHANAN_CITY = "11616"
BUCKHEAD_CDP = "11626"
BUCKHEAD_TOWN = "11672"
BUENA_VISTA_CITY = "11728"
BUFORD_CITY = "11784"
BUTLER_CITY = "12120"
BYROMVILLE_TOWN = "12232"
BYRON_CITY = "12260"
CADWELL_TOWN = "12344"
CAIRO_CITY = "12400"
CALHOUN_CITY = "12456"
CALVARY_CDP = "12484"
CAMAK_TOWN = "12512"
CAMILLA_CITY = "12624"
CANDLER_MCAFEE_CDP = "12834"
CANON_CITY = "12932"
CANOOCHEE_CDP = "12960"
CANTON_CITY = "12988"
CARL_TOWN = "13184"
CARLTON_CITY = "13212"
CARNESVILLE_CITY = "13352"
CARROLLTON_CITY = "13492"
CARTERSVILLE_CITY = "13688"
CATAULA_CDP = "14024"
CAVE_SPRING_CITY = "14108"
CECIL_CITY = "14192"
CEDAR_SPRINGS_CDP = "14472"
CEDARTOWN_CITY = "14500"
CENTERVILLE_CITY = "14920"
CENTRALHATCHEE_TOWN = "15026"
CHAMBLEE_CITY = "15172"
CHATSWORTH_CITY = "15508"
CHATTAHOOCHEE_HILLS_CITY = "15552"
CHATTANOOGA_VALLEY_CDP = "15585"
CHAUNCEY_CITY = "15648"
CHERRY_LOG_CDP = "15844"
CHESTER_TOWN = "15900"
CHICKAMAUGA_CITY = "15984"
CLARKESVILLE_CITY = "16460"
CLARKSTON_CITY = "16544"
CLAXTON_CITY = "16600"
CLAYTON_CITY = "16656"
CLERMONT_TOWN = "16796"
CLEVELAND_CITY = "16824"
CLIMAX_CITY = "16908"
CLYATTVILLE_CDP = "17132"
COBBTOWN_CITY = "17272"
COCHRAN_CITY = "17328"
COGDELL_CDP = "17468"
COHUTTA_CITY = "17496"
COLBERT_CITY = "17552"
COLEMAN_CDP = "17580"
COLLEGE_PARK_CITY = "17776"
COLLINS_CITY = "17832"
COLQUITT_CITY = "18000"
COLUMBUS_CITY = "19000"
COMER_CITY = "19084"
COMMERCE_CITY = "19112"
CONCORD_CITY = "19168"
CONLEY_CDP = "19280"
CONYERS_CITY = "19336"
COOLIDGE_CITY = "19392"
CORDELE_CITY = "19616"
CORNELIA_CITY = "19728"
COUNTRY_CLUB_ESTATES_CDP = "19830"
COVINGTON_CITY = "20064"
CRAWFORD_CITY = "20288"
CRAWFORDVILLE_CITY = "20316"
CRESCENT_CDP = "20372"
CROOKED_CREEK_CDP = "20550"
CULLODEN_CITY = "20848"
CUMMING_CITY = "20932"
CUSSETA_CHATTAHOOCHEE_COUNTY_UNIFIED_GOVERNMENT = "21017"
CUTHBERT_CITY = "21072"
DACULA_CITY = "21184"
DAHLONEGA_CITY = "21240"
DAISY_CITY = "21268"
DALLAS_CITY = "21324"
DALTON_CITY = "21380"
DAMASCUS_CITY = "21436"
DANIELSVILLE_CITY = "21632"
DANVILLE_TOWN = "21688"
DARIEN_CITY = "21716"
DASHER_TOWN = "21744"
DAVISBORO_CITY = "21800"
DAWSON_CITY = "21912"
DAWSONVILLE_CITY = "21940"
DE_SOTO_CITY = "22472"
DEARING_TOWN = "22024"
DECATUR_CITY = "22052"
DEENWOOD_CDP = "22080"
DEEPSTEP_TOWN = "22108"
DEMOREST_CITY = "22304"
DENTON_CITY = "22388"
DEWY_ROSE_CDP = "22724"
DEXTER_TOWN = "22752"
DILLARD_CITY = "22976"
DIXIE_CDP = "23060"
DIXIE_UNION_CDP = "23144"
DOCK_JUNCTION_CDP = "23200"
DOERUN_CITY = "23284"
DONALSONVILLE_CITY = "23368"
DOOLING_TOWN = "23480"
DORAVILLE_CITY = "23536"
DOUGLAS_CITY = "23872"
DOUGLASVILLE_CITY = "23900"
DRUID_HILLS_CDP = "24264"
DU_PONT_TOWN = "24796"
DUBLIN_CITY = "24376"
DUDLEY_CITY = "24488"
DULUTH_CITY = "24600"
DUNWOODY_CITY = "24768"
DUTCH_ISLAND_CDP = "24876"
EAGLE_GROVE_CDP = "24964"
EAST_DUBLIN_CITY = "25300"
EAST_ELLIJAY_CITY = "25356"
EAST_GRIFFIN_CDP = "25440"
EAST_NEWNAN_CDP = "25692"
EAST_POINT_CITY = "25720"
EASTMAN_CITY = "25552"
EATONTON_CITY = "26084"
ECHOLS_COUNTY_CONSOLIDATED_GOVERNMENT = "26156"
EDGE_HILL_CITY = "26224"
EDISON_CITY = "26448"
ELBERTON_CITY = "26616"
ELLAVILLE_CITY = "26980"
ELLENTON_TOWN = "27008"
ELLERSLIE_CDP = "27064"
ELLIJAY_CITY = "27092"
EMERSON_CITY = "27344"
EMPIRE_CDP = "27512"
ENIGMA_TOWN = "27596"
EPHESUS_CITY = "27708"
EPWORTH_CDP = "27736"
ETON_CITY = "27932"
EUHARLEE_CITY = "27988"
EULONIA_CDP = "28016"
EVANS_CDP = "28044"
EVERETT_CDP = "28100"
EXPERIMENT_CDP = "28296"
FACEVILLE_CDP = "28324"
FAIR_OAKS_CDP = "28520"
FAIRBURN_CITY = "28380"
FAIRFIELD_PLANTATION_CDP = "28440"
FAIRMOUNT_CITY = "28492"
FAIRPLAY_CDP = "28548"
FAIRVIEW_CDP = "28632"
FARGO_CITY = "28744"
FAYETTEVILLE_CITY = "28968"
FITZGERALD_CITY = "29528"
FLEMINGTON_CITY = "30088"
FLOVILLA_CITY = "30312"
FLOWERY_BRANCH_CITY = "30340"
FOLKSTON_CITY = "30424"
FOREST_PARK_CITY = "30536"
FORSYTH_CITY = "30732"
FORT_GAINES_CITY = "30816"
FORT_OGLETHORPE_CITY = "30956"
FORT_STEWART_CDP = "31068"
FORT_VALLEY_CITY = "31096"
FRANKLIN_SPRINGS_CITY = "31320"
FRANKLIN_CITY = "31292"
FUNSTON_CITY = "31684"
GAINESVILLE_CITY = "31908"
GARDEN_CITY_CITY = "32048"
GARDI_CDP = "32132"
GARFIELD_CITY = "32188"
GAY_TOWN = "32384"
GENEVA_TOWN = "32412"
GEORGETOWN_CDP = "32482"
GEORGETOWN_QUITMAN_COUNTY_UNIFIED_GOVERNMENT = "32528"
GIBSON_CITY = "32748"
GILLSVILLE_CITY = "32860"
GIRARD_TOWN = "32916"
GLENN_CDP = "33280"
GLENNVILLE_CITY = "33336"
GLENWOOD_CITY = "33392"
GODFREY_CDP = "33672"
GOOD_HOPE_CITY = "33896"
GORDON_CITY = "33980"
GOUGH_CDP = "34176"
GRAHAM_CITY = "34260"
GRANTVILLE_CITY = "34428"
GRAY_CITY = "34512"
GRAYSON_CITY = "34596"
GREENSBORO_CITY = "34876"
GREENVILLE_CITY = "35016"
GRESHAM_PARK_CDP = "35240"
GRIFFIN_CITY = "35324"
GROVETOWN_CITY = "35716"
GUMBRANCH_CITY = "35800"
GUMLOG_CDP = "35814"
GUYTON_CITY = "35884"
HAGAN_CITY = "36024"
HAHIRA_CITY = "36052"
HAMILTON_CITY = "36220"
HAMPTON_CITY = "36276"
HANNAHS_MILL_CDP = "36416"
HAPEVILLE_CITY = "36472"
HARALSON_TOWN = "36528"
HARDWICK_CDP = "36668"
HARLEM_CITY = "36696"
HARRISON_TOWN = "36920"
HARTWELL_CITY = "37144"
HAWKINSVILLE_CITY = "37396"
HAZLEHURST_CITY = "37564"
HELEN_CITY = "37788"
HENDERSON_CDP = "37910"
HEPHZIBAH_CITY = "38040"
HERON_BAY_CDP = "38105"
HIAWASSEE_CITY = "38124"
HICKOX_CDP = "38292"
HIGGSTON_TOWN = "38348"
HILLTOP_CDP = "38866"
HILTONIA_TOWN = "38920"
HINESVILLE_CITY = "38964"
HIRAM_CITY = "39076"
HOBOKEN_CITY = "39216"
HOGANSVILLE_CITY = "39244"
HOLLY_SPRINGS_CITY = "39524"
HOMELAND_CITY = "39692"
HOMER_TOWN = "39720"
HOMERVILLE_CITY = "39748"
HORTENSE_CDP = "40028"
HOSCHTON_CITY = "40056"
HOWARD_CDP = "40196"
HULL_CITY = "40532"
IDEAL_CITY = "40812"
ILA_CITY = "40840"
INDIAN_SPRINGS_CDP = "41036"
IRON_CITY_TOWN = "41344"
IRONDALE_CDP = "41347"
IRWINTON_CITY = "41400"
ISLE_OF_HOPE_CDP = "41484"
IVEY_CITY = "41540"
JACKSON_CITY = "41596"
JACKSONVILLE_CITY = "41708"
JAKIN_CITY = "41792"
JASPER_CITY = "41932"
JEFFERSON_CITY = "41988"
JEFFERSONVILLE_CITY = "42100"
JEKYLL_ISLAND_CDP = "42128"
JENKINSBURG_CITY = "42156"
JERSEY_CITY = "42184"
JESUP_CITY = "42268"
JOHNS_CREEK_CITY = "42425"
JONESBORO_CITY = "42604"
JULIETTE_CDP = "42772"
JUNCTION_CITY_TOWN = "42800"
KENNESAW_STATE_UNIVERSITY_CDP = "43210"
KENNESAW_CITY = "43192"
KEYSVILLE_CITY = "43360"
KINGS_BAY_BASE_CDP = "43580"
KINGSLAND_CITY = "43640"
KINGSTON_CITY = "43668"
KITE_CITY = "43892"
KNOXVILLE_CDP = "44060"
LAFAYETTE_CITY = "44312"
LAGRANGE_CITY = "44340"
LAKE_CITY_CITY = "44508"
LAKE_PARK_CITY = "44704"
LAKELAND_CITY = "44592"
LAKEVIEW_CDP = "44900"
LAKEVIEW_ESTATES_CDP = "44956"
LAVONIA_CITY = "45460"
LAWRENCEVILLE_CITY = "45488"
LEARY_CITY = "45600"
LEESBURG_CITY = "45768"
LENOX_TOWN = "45936"
LESLIE_CITY = "46020"
LEXINGTON_CITY = "46188"
LILBURN_CITY = "46356"
LILLY_CITY = "46384"
LINCOLN_PARK_CDP = "46524"
LINCOLNTON_CITY = "46552"
LINDALE_CDP = "46580"
LITHIA_SPRINGS_CDP = "46832"
LITHONIA_CITY = "46860"
LOCUST_GROVE_CITY = "47140"
LOGANVILLE_CITY = "47196"
LONE_OAK_TOWN = "47252"
LOOKOUT_MOUNTAIN_CITY = "47336"
LOUISVILLE_CITY = "47560"
LOVEJOY_CITY = "47616"
LUDOWICI_CITY = "47784"
LULA_CITY = "47896"
LUMBER_CITY_CITY = "47952"
LUMPKIN_CITY = "47980"
LUTHERSVILLE_CITY = "48008"
LYERLY_TOWN = "48092"
LYONS_CITY = "48232"
MABLETON_CDP = "48288"
MACON_BIBB_COUNTY = "49008"
MADISON_CITY = "49196"
MANASSAS_CITY = "49504"
MANCHESTER_CITY = "49532"
MANOR_CDP = "49588"
MANSFIELD_CITY = "49616"
MARIETTA_CITY = "49756"
MARSHALLVILLE_CITY = "49924"
MARTIN_TOWN = "50008"
MARTINEZ_CDP = "50036"
MATTHEWS_CDP = "50176"
MAXEYS_TOWN = "50260"
MAYSVILLE_TOWN = "50484"
MCCAYSVILLE_CITY = "48428"
MCDONOUGH_CITY = "48624"
MCINTYRE_TOWN = "48848"
MCRAE_HELENA_CITY = "49100"
MEANSVILLE_CITY = "50596"
MEIGS_CITY = "50680"
MENDES_CDP = "50820"
MENLO_CITY = "50848"
MERSHON_CDP = "50960"
METTER_CITY = "51072"
MIDVILLE_CITY = "51240"
MIDWAY_CITY = "51352"
MILAN_CITY = "51408"
MILLEDGEVILLE_CITY = "51492"
MILLEN_CITY = "51520"
MILLWOOD_CDP = "51576"
MILNER_CITY = "51604"
MILSTEAD_CDP = "51660"
MILTON_CITY = "51670"
MINERAL_BLUFF_CDP = "51744"
MITCHELL_TOWN = "51968"
MOLENA_CITY = "52108"
MONROE_CITY = "52192"
MONTEZUMA_CITY = "52304"
MONTGOMERY_CDP = "52332"
MONTICELLO_CITY = "52416"
MONTROSE_TOWN = "52500"
MOODY_AFB_CDP = "52556"
MORELAND_TOWN = "52668"
MORGAN_CITY = "52696"
MORGANTON_CITY = "52724"
MORROW_CITY = "53004"
MORVEN_CITY = "53032"
MOULTRIE_CITY = "53060"
MOUNT_AIRY_TOWN = "53284"
MOUNT_VERNON_CITY = "53508"
MOUNT_ZION_CITY = "53620"
MOUNTAIN_CITY_TOWN = "53116"
MOUNTAIN_PARK_CDP = "53186"
MOUNTAIN_PARK_CITY = "53172"
MUSELLA_CDP = "54012"
NAHUNTA_CITY = "54124"
NASHVILLE_CITY = "54264"
NAYLOR_CDP = "54404"
NELSON_CITY = "54572"
NEW_ENGLAND_CDP = "54768"
NEWBORN_TOWN = "54656"
NEWINGTON_TOWN = "54992"
NEWNAN_CITY = "55020"
NEWTON_CITY = "55244"
NICHOLLS_CITY = "55440"
NICHOLSON_CITY = "55468"
NORCROSS_CITY = "55776"
NORMAN_PARK_CITY = "55860"
NORRISTOWN_CDP = "55944"
NORTH_DECATUR_CDP = "56112"
NORTH_DRUID_HILLS_CDP = "56168"
NORTH_HIGH_SHOALS_TOWN = "56308"
NORWOOD_CITY = "56560"
NUNEZ_CITY = "56644"
OAK_PARK_TOWN = "57232"
OAKWOOD_CITY = "57260"
OCHLOCKNEE_TOWN = "57372"
OCILLA_CITY = "57428"
OCONEE_CITY = "57456"
ODUM_CITY = "57540"
OFFERMAN_CITY = "57568"
OGLETHORPE_CITY = "57736"
OHOOPEE_CDP = "57876"
OLIVER_CITY = "58100"
OMEGA_CITY = "58184"
ORCHARD_HILL_TOWN = "58296"
OXFORD_CITY = "58744"
PALMETTO_CITY = "58884"
PANTHERSVILLE_CDP = "59080"
PARROTT_TOWN = "59416"
PATTERSON_CITY = "59500"
PAVO_CITY = "59556"
PEACHTREE_CITY_CITY = "59724"
PEACHTREE_CORNERS_CITY = "59735"
PEARSON_CITY = "59808"
PELHAM_CITY = "59976"
PEMBROKE_CITY = "60004"
PENDERGRASS_TOWN = "60032"
PERKINS_CDP = "60312"
PERRY_CITY = "60340"
PHILLIPSBURG_CDP = "60508"
PINE_LAKE_CITY = "61040"
PINE_MOUNTAIN_TOWN = "61124"
PINEHURST_CITY = "60984"
PINEVIEW_TOWN = "61320"
PINEY_GROVE_CDP = "61376"
PITTS_CITY = "61544"
PLAINS_CITY = "61628"
PLAINVILLE_CITY = "61684"
POOLER_CITY = "62104"
PORT_WENTWORTH_CITY = "62328"
PORTAL_TOWN = "62216"
PORTERDALE_CITY = "62244"
POULAN_CITY = "62496"
POWDER_SPRINGS_CITY = "62524"
PULASKI_TOWN = "63000"
PUTNEY_CDP = "63084"
QUITMAN_CITY = "63224"
RANGER_TOWN = "63560"
RAOUL_CDP = "63588"
RAY_CITY_CITY = "63728"
RAYLE_TOWN = "63756"
REBECCA_TOWN = "63840"
REDAN_CDP = "63952"
REED_CREEK_CDP = "64288"
REGISTER_TOWN = "64372"
REIDSVILLE_CITY = "64512"
REMERTON_CITY = "64596"
RENTZ_CITY = "64680"
RESACA_TOWN = "64736"
REST_HAVEN_TOWN = "64792"
REYNOLDS_CITY = "64876"
RHINE_TOWN = "64932"
RICEBORO_CITY = "64960"
RICHLAND_CITY = "65016"
RICHMOND_HILL_CITY = "65044"
RIDDLEVILLE_TOWN = "65156"
RINCON_CITY = "65296"
RINGGOLD_CITY = "65324"
RIVERDALE_CITY = "65464"
ROBERTA_CITY = "65856"
ROBINS_AFB_CDP = "65968"
ROCHELLE_CITY = "66024"
ROCK_SPRING_CDP = "66304"
ROCKINGHAM_CDP = "66220"
ROCKMART_CITY = "66276"
ROCKY_FORD_TOWN = "66444"
ROME_CITY = "66668"
ROOPVILLE_TOWN = "66696"
ROSSVILLE_CITY = "67256"
ROSWELL_CITY = "67284"
ROYSTON_CITY = "67452"
RUSSELL_CDP = "67676"
RUTLEDGE_CITY = "67760"
SALE_CITY_CITY = "68096"
SALEM_CDP = "68129"
SANDERSVILLE_CITY = "68208"
SANDY_SPRINGS_CITY = "68516"
SANTA_CLAUS_CITY = "68600"
SARDIS_CITY = "68740"
SASSER_TOWN = "68796"
SATILLA_CDP = "68805"
SAUTEE_NACOOCHEE_CDP = "68880"
SAVANNAH_CITY = "69000"
SCOTLAND_CITY = "69336"
SCOTTDALE_CDP = "69392"
SCREVEN_CITY = "69448"
SENOIA_CITY = "69672"
SEVILLE_CDP = "69728"
SHADY_DALE_TOWN = "69784"
SHANNON_CDP = "69868"
SHARON_CITY = "69896"
SHARPSBURG_TOWN = "69980"
SHELLMAN_CITY = "70120"
SHILOH_CITY = "70428"
SILOAM_TOWN = "70932"
SKIDAWAY_ISLAND_CDP = "71184"
SKY_VALLEY_CITY = "71282"
SMARR_CDP = "71296"
SMITHVILLE_CITY = "71464"
SMYRNA_CITY = "71492"
SNELLVILLE_CITY = "71604"
SOCIAL_CIRCLE_CITY = "71660"
SOPERTON_CITY = "71772"
SOUTH_FULTON_CITY = "72122"
SPARKS_TOWN = "72556"
SPARTA_CITY = "72584"
SPRINGFIELD_CITY = "72780"
ST_MARYS_CITY = "67984"
ST_SIMONS_CDP = "68040"
STAPLETON_CITY = "73004"
STATESBORO_CITY = "73256"
STATHAM_CITY = "73312"
STERLING_CDP = "73452"
STILLMORE_CITY = "73620"
STOCKBRIDGE_CITY = "73704"
STOCKTON_CDP = "73760"
STONE_MOUNTAIN_CITY = "73816"
STONECREST_CITY = "73784"
SUGAR_HILL_CITY = "74180"
SUMMERTOWN_CITY = "74348"
SUMMERVILLE_CITY = "74376"
SUMNER_TOWN = "74432"
SUNNY_SIDE_CITY = "74572"
SUNNYSIDE_CDP = "74628"
SUNSET_VILLAGE_CDP = "74768"
SURRENCY_TOWN = "74852"
SUWANEE_CITY = "74936"
SWAINSBORO_CITY = "74964"
SYCAMORE_CITY = "75104"
SYLVANIA_CITY = "75160"
SYLVESTER_CITY = "75188"
TALAHI_ISLAND_CDP = "75239"
TALBOTTON_CITY = "75244"
TALKING_ROCK_TOWN = "75272"
TALLAPOOSA_CITY = "75300"
TALLULAH_FALLS_TOWN = "75328"
TALMO_TOWN = "75412"
TARRYTOWN_TOWN = "75496"
TATE_CITY_CDP = "75580"
TAYLORSVILLE_TOWN = "75664"
TAZEWELL_CDP = "75692"
TEMPLE_CITY = "75832"
TENNILLE_CITY = "75888"
THE_ROCK_CDP = "76112"
THOMASTON_CITY = "76168"
THOMASVILLE_CITY = "76224"
THOMSON_CITY = "76280"
THUNDERBOLT_TOWN = "76364"
TIFTON_CITY = "76476"
TIGER_TOWN = "76504"
TIGNALL_TOWN = "76532"
TOCCOA_CITY = "76756"
TOOMSBORO_CITY = "76952"
TRENTON_CITY = "77372"
TRION_TOWN = "77540"
TUCKER_CITY = "77652"
TUNNEL_HILL_CITY = "77736"
TURIN_TOWN = "77764"
TWIN_CITY_CITY = "77988"
TY_TY_CITY = "78100"
TYBEE_ISLAND_CITY = "78036"
TYRONE_TOWN = "78044"
UNADILLA_CITY = "78156"
UNION_CITY_CITY = "78324"
UNION_POINT_CITY = "78380"
UNIONVILLE_CDP = "78464"
UVALDA_CITY = "78744"
VALDOSTA_CITY = "78800"
VARNELL_CITY = "78996"
VERNONBURG_TOWN = "79164"
VIDALIA_CITY = "79388"
VIDETTE_CITY = "79416"
VIENNA_CITY = "79444"
VILLA_RICA_CITY = "79528"
VININGS_CDP = "79612"
WACO_CITY = "79808"
WADLEY_CITY = "79864"
WALESKA_CITY = "79948"
WALNUT_GROVE_CITY = "80228"
WALTHOURVILLE_CITY = "80256"
WARESBORO_CDP = "80368"
WARM_SPRINGS_CITY = "80480"
WARNER_ROBINS_CITY = "80508"
WARRENTON_CITY = "80592"
WARTHEN_CDP = "80648"
WARWICK_CITY = "80676"
WASHINGTON_CITY = "80704"
WATKINSVILLE_CITY = "80788"
WAVERLY_CDP = "80816"
WAVERLY_HALL_TOWN = "80844"
WAYCROSS_CITY = "80956"
WAYNESBORO_CITY = "80984"
WAYNESVILLE_CDP = "81012"
WEBSTER_COUNTY_UNIFIED_GOVERNMENT = "81128"
WENONA_CDP = "81208"
WEST_BROW_CDP = "81488"
WEST_POINT_CITY = "82132"
WHIGHAM_CITY = "82412"
WHITE_PLAINS_CITY = "82692"
WHITE_CITY = "82468"
WHITEMARSH_ISLAND_CDP = "82636"
WHITESBURG_CITY = "82720"
WILDWOOD_CDP = "82916"
WILLACOOCHEE_CITY = "82972"
WILLIAMSON_CITY = "83084"
WILMINGTON_ISLAND_CDP = "83168"
WINDER_CITY = "83420"
WINTERVILLE_CITY = "83728"
WOODBINE_CITY = "83868"
WOODBURY_CITY = "83896"
WOODLAND_CITY = "83952"
WOODSTOCK_CITY = "84176"
WOODVILLE_CITY = "84260"
WOOLSEY_TOWN = "84288"
WRENS_CITY = "84456"
WRIGHTSVILLE_CITY = "84512"
YATESVILLE_TOWN = "84708"
YONAH_CDP = "84832"
YOUNG_HARRIS_CITY = "84960"
ZEBULON_CITY = "85128"
