# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Colorado."""


ACRES_GREEN_CDP = "00320"
AETNA_ESTATES_CDP = "00620"
AGUILAR_TOWN = "00760"
AIR_FORCE_ACADEMY_CDP = "00870"
AKRON_TOWN = "00925"
ALAMOSA_EAST_CDP = "01145"
ALAMOSA_CITY = "01090"
ALLENSPARK_CDP = "01420"
ALMA_TOWN = "01530"
ALPINE_CDP = "01640"
ALTONA_CDP = "01740"
AMHERST_CDP = "01915"
ANTONITO_TOWN = "02355"
APPLEWOOD_CDP = "02575"
ARAPAHOE_CDP = "02850"
ARBOLES_CDP = "02905"
ARISTOCRAT_RANCHETTES_CDP = "03015"
ARRIBA_TOWN = "03235"
ARVADA_CITY = "03455"
ASPEN_PARK_CDP = "03730"
ASPEN_CITY = "03620"
ATWOOD_CDP = "03840"
AULT_TOWN = "03950"
AURORA_CITY = "04000"
AVON_TOWN = "04110"
AVONDALE_CDP = "04165"
BARK_RANCH_CDP = "04620"
BASALT_TOWN = "04935"
BATTLEMENT_MESA_CDP = "05120"
BAYFIELD_TOWN = "05265"
BENNETT_TOWN = "06090"
BERKLEY_CDP = "06172"
BERTHOUD_TOWN = "06255"
BETHUNE_TOWN = "06530"
BEULAH_VALLEY_CDP = "06602"
BLACK_FOREST_CDP = "06970"
BLACK_HAWK_CITY = "07025"
BLANCA_TOWN = "07190"
BLENDE_CDP = "07245"
BLUE_RIVER_TOWN = "07410"
BLUE_SKY_CDP = "07420"
BLUE_VALLEY_CDP = "07455"
BONANZA_MOUNTAIN_ESTATES_CDP = "07580"
BONANZA_TOWN = "07571"
BOONE_TOWN = "07795"
BOULDER_CITY = "07850"
BOW_MAR_TOWN = "08070"
BRANDON_CDP = "08290"
BRANSON_TOWN = "08345"
BRECKENRIDGE_TOWN = "08400"
BRICK_CENTER_CDP = "08530"
BRIGGSDALE_CDP = "08620"
BRIGHTON_CITY = "08675"
BROOK_FOREST_CDP = "08950"
BROOKSIDE_TOWN = "09115"
BROOMFIELD_CITY = "09280"
BRUSH_CITY = "09555"
BUENA_VISTA_TOWN = "10105"
BURLINGTON_CITY = "10600"
BYERS_CDP = "10985"
CALHAN_TOWN = "11260"
CAMPO_TOWN = "11645"
CAPULIN_CDP = "11975"
CARBONATE_TOWN = "12030"
CARBONDALE_TOWN = "12045"
CASCADE_CHIPITA_PARK_CDP = "12325"
CASTLE_PINES_VILLAGE_CDP = "12393"
CASTLE_PINES_CITY = "12387"
CASTLE_ROCK_TOWN = "12415"
CATHEDRAL_CDP = "12450"
CATHERINE_CDP = "12460"
CATTLE_CREEK_CDP = "12470"
CANON_CITY_CITY = "11810"
CEDAREDGE_TOWN = "12635"
CENTENNIAL_CITY = "12815"
CENTER_TOWN = "12855"
CENTRAL_CITY_CITY = "12910"
CHACRA_CDP = "12945"
CHERAW_TOWN = "13460"
CHERRY_CREEK_CDP = "13590"
CHERRY_HILLS_VILLAGE_CITY = "13845"
CHEYENNE_WELLS_TOWN = "14175"
CIMARRON_HILLS_CDP = "14587"
CITY_OF_CREEDE_TOWN = "14765"
CLIFTON_CDP = "15165"
COAL_CREEK_CDP = "15302"
COAL_CREEK_TOWN = "15330"
COALDALE_CDP = "15440"
COKEDALE_TOWN = "15550"
COLLBRAN_TOWN = "15605"
COLONA_CDP = "15825"
COLORADO_CITY_CDP = "15935"
COLORADO_SPRINGS_CITY = "16000"
COLUMBINE_CDP = "16110"
COLUMBINE_VALLEY_TOWN = "16385"
COMANCHE_CREEK_CDP = "16465"
COMMERCE_CITY_CITY = "16495"
CONEJOS_CDP = "16715"
COPE_CDP = "17100"
COPPER_MOUNTAIN_CDP = "17150"
CORTEZ_CITY = "17375"
COTOPAXI_CDP = "17485"
CRAIG_CITY = "17760"
CRAWFORD_TOWN = "17925"
CRESTED_BUTTE_TOWN = "18310"
CRESTONE_TOWN = "18420"
CRIPPLE_CREEK_CITY = "18530"
CRISMAN_CDP = "18585"
CROOK_TOWN = "18640"
CROWLEY_TOWN = "18750"
DACONO_CITY = "19080"
DAKOTA_RIDGE_CDP = "19150"
DE_BEQUE_TOWN = "19355"
DEER_TRAIL_TOWN = "19630"
DEL_NORTE_TOWN = "19795"
DELTA_CITY = "19850"
DENVER_CITY = "20000"
DERBY_CDP = "20275"
DILLON_TOWN = "20440"
DINOSAUR_TOWN = "20495"
DIVIDE_CDP = "20605"
DOLORES_TOWN = "20770"
DOTSERO_CDP = "21155"
DOVE_CREEK_TOWN = "21265"
DOVE_VALLEY_CDP = "21330"
DOWNIEVILLE_LAWSON_DUMONT_CDP = "21390"
DURANGO_CITY = "22035"
EADS_TOWN = "22145"
EAGLE_TOWN = "22200"
EAST_PLEASANT_VIEW_CDP = "22575"
EATON_TOWN = "22860"
ECHO_HILLS_CDP = "22882"
ECKLEY_TOWN = "23025"
EDGEWATER_CITY = "23135"
EDWARDS_CDP = "23300"
EL_JEBEL_CDP = "23795"
EL_MORO_CDP = "24290"
ELBERT_CDP = "23520"
ELDORA_CDP = "23575"
ELDORADO_SPRINGS_CDP = "23630"
ELIZABETH_TOWN = "23740"
ELLICOTT_CDP = "24235"
EMPIRE_TOWN = "24620"
ENGLEWOOD_CITY = "24785"
ERIE_TOWN = "24950"
ESTES_PARK_TOWN = "25115"
EVANS_CITY = "25280"
EVERGREEN_CDP = "25390"
FAIRMOUNT_CDP = "25550"
FAIRPLAY_TOWN = "25610"
FEDERAL_HEIGHTS_CITY = "26270"
FIRESTONE_TOWN = "26600"
FLAGLER_TOWN = "26765"
FLEMING_TOWN = "26875"
FLORENCE_CITY = "27040"
FLORISSANT_CDP = "27095"
FLOYD_HILL_CDP = "27175"
FORT_CARSON_CDP = "27370"
FORT_COLLINS_CITY = "27425"
FORT_GARLAND_CDP = "27535"
FORT_LUPTON_CITY = "27700"
FORT_MORGAN_CITY = "27810"
FOUNTAIN_CITY = "27865"
FOUR_SQUARE_MILE_CDP = "27950"
FOWLER_TOWN = "27975"
FOXFIELD_TOWN = "28105"
FRANKTOWN_CDP = "28250"
FRASER_TOWN = "28305"
FREDERICK_TOWN = "28360"
FRISCO_TOWN = "28690"
FRUITA_CITY = "28745"
FRUITVALE_CDP = "28800"
FULFORD_CDP = "28830"
GARDEN_CITY_TOWN = "29185"
GARDNER_CDP = "29240"
GARFIELD_CDP = "29295"
GENESEE_CDP = "29625"
GENOA_TOWN = "29680"
GEORGETOWN_TOWN = "29735"
GERRARD_CDP = "29845"
GILCREST_TOWN = "29955"
GLENDALE_CDP = "30350"
GLENDALE_CITY = "30340"
GLENEAGLE_CDP = "30420"
GLENWOOD_SPRINGS_CITY = "30780"
GOLD_HILL_CDP = "30945"
GOLDEN_CITY = "30835"
GOLDFIELD_CDP = "30890"
GRANADA_TOWN = "31550"
GRANBY_TOWN = "31605"
GRAND_JUNCTION_CITY = "31660"
GRAND_LAKE_TOWN = "31715"
GRAND_VIEW_ESTATES_CDP = "31935"
GREELEY_CITY = "32155"
GREEN_MOUNTAIN_FALLS_TOWN = "32650"
GREENWOOD_VILLAGE_CITY = "33035"
GROVER_TOWN = "33310"
GUFFEY_CDP = "33420"
GUNBARREL_CDP = "33502"
GUNNISON_CITY = "33640"
GYPSUM_TOWN = "33695"
HARTMAN_TOWN = "34520"
HARTSEL_CDP = "34630"
HASTY_CDP = "34685"
HASWELL_TOWN = "34740"
HAXTUN_TOWN = "34960"
HAYDEN_TOWN = "35070"
HEENEY_CDP = "35400"
HIDDEN_LAKE_CDP = "35860"
HIGHLANDS_RANCH_CDP = "36410"
HILLROSE_TOWN = "36610"
HOEHNE_CDP = "36940"
HOLLY_HILLS_CDP = "37220"
HOLLY_TOWN = "37215"
HOLYOKE_CITY = "37270"
HOOPER_TOWN = "37380"
HOT_SULPHUR_SPRINGS_TOWN = "37600"
HOTCHKISS_TOWN = "37545"
HOWARD_CDP = "37655"
HUDSON_TOWN = "37820"
HUGO_TOWN = "37875"
IDAHO_SPRINGS_CITY = "38370"
IDALIA_CDP = "38425"
IDLEDALE_CDP = "38480"
IGNACIO_TOWN = "38535"
ILIFF_TOWN = "38590"
INDIAN_HILLS_CDP = "38810"
INVERNESS_CDP = "38910"
JACKSON_LAKE_CDP = "39160"
JAMESTOWN_TOWN = "39195"
JANSEN_CDP = "39250"
JOES_CDP = "39745"
JOHNSON_VILLAGE_CDP = "39800"
JOHNSTOWN_TOWN = "39855"
JULESBURG_TOWN = "39965"
KEENESBURG_TOWN = "40185"
KEN_CARYL_CDP = "40377"
KERSEY_TOWN = "40515"
KEYSTONE_CDP = "40550"
KIM_TOWN = "40570"
KIOWA_TOWN = "40790"
KIRK_CDP = "40900"
KIT_CARSON_TOWN = "41010"
KITTREDGE_CDP = "41065"
KREMMLING_TOWN = "41560"
LA_JARA_TOWN = "42055"
LA_JUNTA_GARDENS_CDP = "42165"
LA_JUNTA_CITY = "42110"
LA_SALLE_TOWN = "43605"
LA_VETA_TOWN = "44100"
LAFAYETTE_CITY = "41835"
LAIRD_CDP = "42000"
LAKE_CITY_TOWN = "42330"
LAKESIDE_TOWN = "42495"
LAKEWOOD_CITY = "43000"
LAMAR_CITY = "43110"
LAPORTE_CDP = "43220"
LARKSPUR_TOWN = "43550"
LAS_ANIMAS_CITY = "43660"
LAZEAR_CDP = "44265"
LAZY_ACRES_CDP = "44270"
LEADVILLE_NORTH_CDP = "44375"
LEADVILLE_CITY = "44320"
LEWIS_CDP = "44595"
LEYNER_CDP = "44695"
LIMON_TOWN = "44980"
LINCOLN_PARK_CDP = "45145"
LITTLETON_CITY = "45255"
LOCHBUIE_TOWN = "45530"
LOG_LANE_VILLAGE_TOWN = "45695"
LOGHILL_VILLAGE_CDP = "45680"
LOMA_CDP = "45750"
LONE_TREE_CITY = "45955"
LONGMONT_CITY = "45970"
LOUISVILLE_CITY = "46355"
LOUVIERS_CDP = "46410"
LOVELAND_CITY = "46465"
LYNN_CDP = "47015"
LYONS_TOWN = "47070"
MANASSA_TOWN = "48060"
MANCOS_TOWN = "48115"
MANITOU_SPRINGS_CITY = "48445"
MANZANOLA_TOWN = "48500"
MARBLE_TOWN = "48555"
MARVEL_CDP = "48940"
MATHESON_CDP = "49215"
MAYBELL_CDP = "49325"
MAYSVILLE_CDP = "49490"
MCCLAVE_CDP = "47235"
MCCOY_CDP = "47345"
MEAD_TOWN = "49600"
MEEKER_TOWN = "49875"
MERIDIAN_CDP = "50012"
MERIDIAN_VILLAGE_CDP = "50026"
MERINO_TOWN = "50040"
MIDLAND_CDP = "50380"
MILLIKEN_TOWN = "50480"
MINTURN_TOWN = "50920"
MOFFAT_TOWN = "51250"
MONTE_VISTA_CITY = "51635"
MONTEZUMA_TOWN = "51690"
MONTROSE_CITY = "51745"
MONUMENT_TOWN = "51800"
MORGAN_HEIGHTS_CDP = "51975"
MORRISON_TOWN = "52075"
MOUNT_CRESTED_BUTTE_TOWN = "52570"
MOUNTAIN_MEADOWS_CDP = "52210"
MOUNTAIN_VIEW_TOWN = "52350"
MOUNTAIN_VILLAGE_TOWN = "52550"
MULFORD_CDP = "52820"
NATHROP_CDP = "53010"
NATURITA_TOWN = "53120"
NEDERLAND_TOWN = "53175"
NEW_CASTLE_TOWN = "53395"
NIWOT_CDP = "53780"
NO_NAME_CDP = "53875"
NORRIE_CDP = "53945"
NORTH_LA_JUNTA_CDP = "54495"
NORTH_WASHINGTON_CDP = "54750"
NORTHGLENN_CITY = "54330"
NORWOOD_TOWN = "54880"
NUCLA_TOWN = "54935"
NUNN_TOWN = "55045"
OAK_CREEK_TOWN = "55155"
OLATHE_TOWN = "55540"
OLNEY_SPRINGS_TOWN = "55705"
OPHIR_TOWN = "55870"
ORCHARD_CDP = "55925"
ORCHARD_CITY_TOWN = "55980"
ORCHARD_MESA_CDP = "56035"
ORDWAY_TOWN = "56145"
OTIS_TOWN = "56365"
OURAY_CITY = "56420"
OVID_TOWN = "56475"
PADRONI_CDP = "56695"
PAGOSA_SPRINGS_TOWN = "56860"
PALISADE_TOWN = "56970"
PALMER_LAKE_TOWN = "57025"
PAOLI_TOWN = "57245"
PAONIA_TOWN = "57300"
PARACHUTE_TOWN = "57400"
PARAGON_ESTATES_CDP = "57445"
PARK_CENTER_CDP = "57465"
PARKER_TOWN = "57630"
PARSHALL_CDP = "57850"
PEETZ_TOWN = "58235"
PENROSE_CDP = "58400"
PEORIA_CDP = "58510"
PERRY_PARK_CDP = "58592"
PEYTON_CDP = "58675"
PHIPPSBURG_CDP = "58785"
PIEDRA_CDP = "58960"
PIERCE_TOWN = "59005"
PINE_BROOK_HILL_CDP = "59240"
PINE_VALLEY_CDP = "59520"
PITKIN_TOWN = "59830"
PLACERVILLE_CDP = "59885"
PLATTEVILLE_TOWN = "60160"
PONCHA_SPRINGS_TOWN = "60600"
PONDEROSA_PARK_CDP = "60655"
PORTLAND_CDP = "60765"
PRITCHETT_TOWN = "61315"
PUEBLO_WEST_CDP = "62220"
PUEBLO_CITY = "62000"
RAMAH_TOWN = "62660"
RANGELY_TOWN = "62880"
RAYMER_NEW_RAYMER_TOWN = "63045"
RED_CLIFF_TOWN = "63265"
RED_FEATHER_LAKES_CDP = "63320"
REDLANDS_CDP = "63375"
REDSTONE_CDP = "63650"
REDVALE_CDP = "63705"
RICO_TOWN = "64090"
RIDGWAY_TOWN = "64200"
RIFLE_CITY = "64255"
ROCK_CREEK_PARK_CDP = "64870"
ROCKVALE_TOWN = "64970"
ROCKY_FORD_CITY = "65190"
ROLLINSVILLE_CDP = "65685"
ROMEO_TOWN = "65740"
ROXBOROUGH_PARK_CDP = "66197"
RYE_TOWN = "66895"
SADDLE_RIDGE_CDP = "66995"
SAGUACHE_TOWN = "67005"
SALIDA_CITY = "67280"
SALT_CREEK_CDP = "67445"
SAN_ACACIO_CDP = "67500"
SAN_LUIS_TOWN = "68105"
SANFORD_TOWN = "67830"
SAWPIT_TOWN = "68655"
SECURITY_WIDEFIELD_CDP = "68847"
SEDALIA_CDP = "68875"
SEDGWICK_TOWN = "68930"
SEGUNDO_CDP = "68985"
SEIBERT_TOWN = "69040"
SEVEN_HILLS_CDP = "69110"
SEVERANCE_TOWN = "69150"
SHAW_HEIGHTS_CDP = "69480"
SHERIDAN_LAKE_TOWN = "69700"
SHERIDAN_CITY = "69645"
SHERRELWOOD_CDP = "69810"
SIERRA_RIDGE_CDP = "70112"
SILT_TOWN = "70195"
SILVER_CLIFF_TOWN = "70250"
SILVER_PLUME_TOWN = "70360"
SILVERTHORNE_TOWN = "70525"
SILVERTON_TOWN = "70580"
SIMLA_TOWN = "70635"
SMELTERTOWN_CDP = "71625"
SNOWMASS_VILLAGE_TOWN = "71755"
SNYDER_CDP = "71790"
SOMERSET_CDP = "71845"
SOUTH_FORK_TOWN = "72395"
SOUTHERN_UTE_CDP = "72320"
SPRINGFIELD_TOWN = "73330"
ST_ANN_HIGHLANDS_CDP = "67040"
ST_MARYS_CDP = "67142"
STARKVILLE_TOWN = "73715"
STEAMBOAT_SPRINGS_CITY = "73825"
STEPPING_STONE_CDP = "73925"
STERLING_RANCH_CDP = "73943"
STERLING_CITY = "73935"
STONEGATE_CDP = "74080"
STONEWALL_GAP_CDP = "74275"
STRASBURG_CDP = "74375"
STRATMOOR_CDP = "74430"
STRATTON_TOWN = "74485"
SUGAR_CITY_TOWN = "74815"
SUGARLOAF_CDP = "74980"
SUNSHINE_CDP = "75585"
SUPERIOR_TOWN = "75640"
SWINK_TOWN = "75970"
TABERNASH_CDP = "76190"
TALL_TIMBER_CDP = "76325"
TELLURIDE_TOWN = "76795"
THE_PINERY_CDP = "77235"
THORNTON_CITY = "77290"
TIMNATH_TOWN = "77510"
TODD_CREEK_CDP = "77757"
TOWAOC_CDP = "78280"
TOWNER_CDP = "78335"
TRAIL_SIDE_CDP = "78345"
TRINIDAD_CITY = "78610"
TWIN_LAKES_CDP_ADAMS_COUNTY = "79100"
TWIN_LAKES_CDP_LAKE_COUNTY = "79105"
TWO_BUTTES_TOWN = "79270"
UPPER_BEAR_CREEK_CDP = "79785"
UPPER_WITTER_GULCH_CDP = "79800"
VAIL_TOWN = "80040"
VALDEZ_CDP = "80095"
VALMONT_CDP = "80370"
VERNON_CDP = "80755"
VICTOR_CITY = "80865"
VILAS_TOWN = "81030"
VINELAND_CDP = "81305"
VONA_TOWN = "81690"
WALDEN_TOWN = "82130"
WALSENBURG_CITY = "82350"
WALSH_TOWN = "82460"
WARD_TOWN = "82735"
WATKINS_CDP = "82900"
WELBY_CDP = "83120"
WELDONA_CDP = "83175"
WELLINGTON_TOWN = "83230"
WEST_PLEASANT_VIEW_CDP = "84042"
WESTCLIFFE_TOWN = "83450"
WESTCREEK_CDP = "83500"
WESTMINSTER_CITY = "83835"
WESTON_CDP = "84000"
WHEAT_RIDGE_CITY = "84440"
WIGGINS_TOWN = "84770"
WILEY_TOWN = "85045"
WILLIAMSBURG_TOWN = "85155"
WINDSOR_TOWN = "85485"
WINTER_PARK_TOWN = "85705"
WOLCOTT_CDP = "85760"
WOODLAND_PARK_CITY = "86090"
WOODMOOR_CDP = "86117"
WOODY_CREEK_CDP = "86200"
WRAY_CITY = "86310"
YAMPA_TOWN = "86475"
YUMA_CITY = "86750"
