# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in North Carolina."""


ALAMANCE = "001"
ALEXANDER = "003"
ALLEGHANY = "005"
ANSON = "007"
ASHE = "009"
AVERY = "011"
BEAUFORT = "013"
BERTIE = "015"
BLADEN = "017"
BRUNSWICK = "019"
BUNCOMBE = "021"
BURKE = "023"
CABARRUS = "025"
CALDWELL = "027"
CAMDEN = "029"
CARTERET = "031"
CASWELL = "033"
CATAWBA = "035"
CHATHAM = "037"
CHEROKEE = "039"
CHOWAN = "041"
CLAY = "043"
CLEVELAND = "045"
COLUMBUS = "047"
CRAVEN = "049"
CUMBERLAND = "051"
CURRITUCK = "053"
DARE = "055"
DAVIDSON = "057"
DAVIE = "059"
DUPLIN = "061"
DURHAM = "063"
EDGECOMBE = "065"
FORSYTH = "067"
FRANKLIN = "069"
GASTON = "071"
GATES = "073"
GRAHAM = "075"
GRANVILLE = "077"
GREENE = "079"
GUILFORD = "081"
HALIFAX = "083"
HARNETT = "085"
HAYWOOD = "087"
HENDERSON = "089"
HERTFORD = "091"
HOKE = "093"
HYDE = "095"
IREDELL = "097"
JACKSON = "099"
JOHNSTON = "101"
JONES = "103"
LEE = "105"
LENOIR = "107"
LINCOLN = "109"
MACON = "113"
MADISON = "115"
MARTIN = "117"
MCDOWELL = "111"
MECKLENBURG = "119"
MITCHELL = "121"
MONTGOMERY = "123"
MOORE = "125"
NASH = "127"
NEW_HANOVER = "129"
NORTHAMPTON = "131"
ONSLOW = "133"
ORANGE = "135"
PAMLICO = "137"
PASQUOTANK = "139"
PENDER = "141"
PERQUIMANS = "143"
PERSON = "145"
PITT = "147"
POLK = "149"
RANDOLPH = "151"
RICHMOND = "153"
ROBESON = "155"
ROCKINGHAM = "157"
ROWAN = "159"
RUTHERFORD = "161"
SAMPSON = "163"
SCOTLAND = "165"
STANLY = "167"
STOKES = "169"
SURRY = "171"
SWAIN = "173"
TRANSYLVANIA = "175"
TYRRELL = "177"
UNION = "179"
VANCE = "181"
WAKE = "183"
WARREN = "185"
WASHINGTON = "187"
WATAUGA = "189"
WAYNE = "191"
WILKES = "193"
WILSON = "195"
YADKIN = "197"
YANCEY = "199"
